@@ -206,6 +206,9 @@ id swapclass(id self,id target);
 
 # 42 "Block.h"
 extern id newBlock(int n,IMP fn,void*data,IMP dtor);
+# 1 "../../util/stdio.h"
+#include <stdio.h>
+
 # 1 "../../util/setjmp.h"
 #include <setjmp.h>
 
@@ -230,7 +233,8 @@ unsigned short objID;
 IMP fn;
 IMP dtor;
 int nVars;
-void**data;};
+void**data;
+id nextBlock;};
 
 # 44 "Block.h"
 extern id  Block;
@@ -240,16 +244,16 @@ extern struct _SHARED _Block;
 extern struct _SHARED __Block;
 
 
-# 52 "Block.m"
+# 53 "Block.m"
 id newBlock(int n,IMP f,void*d,IMP c)
 {
 id objcT0;
 
-# 54 "Block.m"
+# 55 "Block.m"
 return(objcT0=Block,(*(id(*)(id,SEL,int,IMP,void**,IMP))_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0],n,f,(void**)d,c));
 }
 
-# 64 "Block.m"
+# 65 "Block.m"
 static id
 err_fun(id thisBlock,void**data,id msg,id rcv)
 {
@@ -281,7 +285,7 @@ static id c_Block_new(struct Block_PRIVATE *self,SEL _cmd)
 {
 id objcT3;
 
-# 93 "Block.m"
+# 94 "Block.m"
 return(objcT3=(id)self,(*_imp(objcT3,selTransTbl[3]))(objcT3,selTransTbl[3]));
 }
 
@@ -289,7 +293,7 @@ static id i_Block_copy(struct Block_PRIVATE *self,SEL _cmd)
 {
 id objcT4;
 
-# 98 "Block.m"
+# 99 "Block.m"
 return(objcT4=(id)self,(*_imp(objcT4,selTransTbl[3]))(objcT4,selTransTbl[3]));
 }
 
@@ -297,7 +301,7 @@ static id i_Block_deepCopy(struct Block_PRIVATE *self,SEL _cmd)
 {
 id objcT5;
 
-# 103 "Block.m"
+# 104 "Block.m"
 return(objcT5=(id)self,(*_imp(objcT5,selTransTbl[3]))(objcT5,selTransTbl[3]));
 }
 
@@ -305,7 +309,7 @@ static id c_Block_blkc_blkfn_blkv_blkdtor_(struct Block_PRIVATE *self,SEL _cmd,i
 {
 id objcT6,objcT7;
 
-# 108 "Block.m"
+# 109 "Block.m"
 return(objcT6=(objcT7=__Block.clsSuper,(*_impSuper(objcT7,selTransTbl[4]))((id)self,selTransTbl[4])),(*(id(*)(id,SEL,int,IMP,void**,IMP))_imp(objcT6,selTransTbl[0]))(objcT6,selTransTbl[0],n,f,d,c));
 }
 
@@ -313,7 +317,7 @@ static id i_Block_free(struct Block_PRIVATE *self,SEL _cmd)
 {
 id objcT8;
 
-# 113 "Block.m"
+# 114 "Block.m"
 if(self->data)
 ( *((void(*)(void**))self->dtor))(self->data);
 return(objcT8=_Block.clsSuper,(*_impSuper(objcT8,selTransTbl[5]))((id)self,selTransTbl[5]));
@@ -323,133 +327,200 @@ static id i_Block_release(struct Block_PRIVATE *self,SEL _cmd)
 {
 id objcT9;
 
-# 120 "Block.m"
+# 121 "Block.m"
 if(self->data)
 ( *((void(*)(void**))self->dtor))(self->data);
 return(objcT9=_Block.clsSuper,(*_impSuper(objcT9,selTransTbl[6]))((id)self,selTransTbl[6]));
 }
 # 132 "Block.m"
+static id errorHandler;
 static id defaultHandler;
-static int jmpCount=0;
-static id jmpHandlers[32];
-
-static id c_Block_pop(struct Block_PRIVATE *self,SEL _cmd)
-{
-return(jmpCount)?jmpHandlers[ --jmpCount]:(id)0;
-}
-
-static id c_Block_push_(struct Block_PRIVATE *self,SEL _cmd,id aHandler)
-{
-id objcT10,objcT11;
-
-# 143 "Block.m"
-jmpHandlers[jmpCount]=(objcT10=aHandler,(*_imp(objcT10,selTransTbl[7]))(objcT10,selTransTbl[7]));
-if(( ++jmpCount)==32)
-return(objcT11=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT11,selTransTbl[8]))(objcT11,selTransTbl[8],"Increase MAX_JMP."));
-return(id)self;
-}
 
 static id c_Block_errorHandler(struct Block_PRIVATE *self,SEL _cmd)
 {
 if( !defaultHandler)
+{
 defaultHandler=newBlock(2,(IMP)err_fun,NULL,NULL);
+}
+if(errorHandler)
+{
+return errorHandler;
+}
+else
+{
 return defaultHandler;
 }
+}
 
 static id c_Block_errorHandler_(struct Block_PRIVATE *self,SEL _cmd,id aHandler)
 {
-id objcT12;
+id objcT10;
 
-# 158 "Block.m"
+# 153 "Block.m"
 id ret=defaultHandler;
-defaultHandler=(objcT12=aHandler,(*_imp(objcT12,selTransTbl[7]))(objcT12,selTransTbl[7]));
+defaultHandler=(objcT10=aHandler,(*_imp(objcT10,selTransTbl[7]))(objcT10,selTransTbl[7]));
 return ret;
 }
 
+static id c_Block_halt_value_(struct Block_PRIVATE *self,SEL _cmd,id message,id receiver)
+{
+id objcT11,objcT13;
+
+# 160 "Block.m"
+id handler=(objcT11=(id)self,(*_imp(objcT11,selTransTbl[8]))(objcT11,selTransTbl[8]));
+if(errorHandler)
+{
+id objcT12;
+
+# 163 "Block.m"
+errorHandler=(objcT12=errorHandler,(*_imp(objcT12,selTransTbl[9]))(objcT12,selTransTbl[9]));
+
+}
+return(objcT13=handler,(*_imp(objcT13,selTransTbl[10]))(objcT13,selTransTbl[10],message,receiver));
+}
 
 static id i_Block_ifError_(struct Block_PRIVATE *self,SEL _cmd,id aHandler)
 {
-id objcT13,objcT14,objcT15;
+id objcT17,objcT18;
 
-# 166 "Block.m"
+# 171 "Block.m"
 id returnValue;
-(objcT13=Block,(*_imp(objcT13,selTransTbl[9]))(objcT13,selTransTbl[9],aHandler));
-returnValue=(objcT14=(id)self,(*_imp(objcT14,selTransTbl[10]))(objcT14,selTransTbl[10]));
-(objcT15=Block,(*_imp(objcT15,selTransTbl[11]))(objcT15,selTransTbl[11]));
+if(errorHandler)
+{
+id objcT14,objcT15;
+
+# 174 "Block.m"
+errorHandler=(objcT14=errorHandler,(*_imp(objcT14,selTransTbl[11]))(objcT14,selTransTbl[11],(objcT15=aHandler,(*_imp(objcT15,selTransTbl[7]))(objcT15,selTransTbl[7]))));
+}
+else
+{
+id objcT16;
+
+# 178 "Block.m"
+errorHandler=(objcT16=aHandler,(*_imp(objcT16,selTransTbl[7]))(objcT16,selTransTbl[7]));
+}
+returnValue=(objcT17=(id)self,(*_imp(objcT17,selTransTbl[12]))(objcT17,selTransTbl[12]));
+errorHandler=(objcT18=errorHandler,(*_imp(objcT18,selTransTbl[9]))(objcT18,selTransTbl[9]));
 return returnValue;
 }
 
 static id i_Block_value_ifError_(struct Block_PRIVATE *self,SEL _cmd,id anObject,id aHandler)
 {
-id objcT16,objcT17,objcT18;
+id objcT22,objcT23;
 
-# 175 "Block.m"
+# 187 "Block.m"
 id returnValue;
-(objcT16=Block,(*_imp(objcT16,selTransTbl[9]))(objcT16,selTransTbl[9],aHandler));
-returnValue=(objcT17=(id)self,(*_imp(objcT17,selTransTbl[12]))(objcT17,selTransTbl[12],anObject));
-(objcT18=Block,(*_imp(objcT18,selTransTbl[11]))(objcT18,selTransTbl[11]));
+if(errorHandler)
+{
+id objcT19,objcT20;
+
+# 190 "Block.m"
+errorHandler=(objcT19=errorHandler,(*_imp(objcT19,selTransTbl[11]))(objcT19,selTransTbl[11],(objcT20=aHandler,(*_imp(objcT20,selTransTbl[7]))(objcT20,selTransTbl[7]))));
+}
+else
+{
+id objcT21;
+
+# 194 "Block.m"
+errorHandler=(objcT21=aHandler,(*_imp(objcT21,selTransTbl[7]))(objcT21,selTransTbl[7]));
+}
+returnValue=(objcT22=(id)self,(*_imp(objcT22,selTransTbl[13]))(objcT22,selTransTbl[13],anObject));
+(objcT23=aHandler,(*_imp(objcT23,selTransTbl[9]))(objcT23,selTransTbl[9]));
 return returnValue;
 }
 
-# 189 "Block.m"
+static id i_Block_push_(struct Block_PRIVATE *self,SEL _cmd,id aBlock)
+{self->
+nextBlock=aBlock;
+return(id)self;
+}
+
+static id i_Block_pop(struct Block_PRIVATE *self,SEL _cmd)
+{
+return self->nextBlock;
+}
+
+static id i_Block_on_do_(struct Block_PRIVATE *self,SEL _cmd,id aClassOfExceptions,id aHandler)
+{
+id objcT24,objcT25;
+
+# 214 "Block.m"
+id returnValue;
+(objcT24=aClassOfExceptions,(*_imp(objcT24,selTransTbl[14]))(objcT24,selTransTbl[14],aHandler));
+returnValue=(objcT25=(id)self,(*_imp(objcT25,selTransTbl[12]))(objcT25,selTransTbl[12]));
+return returnValue;
+}
+
+static id i_Block_value_on_do_(struct Block_PRIVATE *self,SEL _cmd,id anObject,id aClassOfExceptions,id aHandler)
+{
+id objcT26,objcT27;
+
+# 222 "Block.m"
+id returnValue;
+(objcT26=aClassOfExceptions,(*_imp(objcT26,selTransTbl[14]))(objcT26,selTransTbl[14],aHandler));
+returnValue=(objcT27=(id)self,(*_imp(objcT27,selTransTbl[13]))(objcT27,selTransTbl[13],anObject));
+return returnValue;
+}
+
+# 235 "Block.m"
 static id i_Block_errorNumArgs(struct Block_PRIVATE *self,SEL _cmd)
 {
-id objcT19;
+id objcT28;
 
-# 191 "Block.m"
-return(objcT19=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT19,selTransTbl[8]))(objcT19,selTransTbl[8],"Block has wrong number of arguments."));
+# 237 "Block.m"
+return(objcT28=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT28,selTransTbl[15]))(objcT28,selTransTbl[15],"Block has wrong number of arguments."));
 }
 
 static id i_Block_errorGoodHandler(struct Block_PRIVATE *self,SEL _cmd)
 {
-id objcT20;
+id objcT29;
 
-# 196 "Block.m"
-return(self->nVars==2)?(id)self:(objcT20=(id)self,(*_imp(objcT20,selTransTbl[13]))(objcT20,selTransTbl[13]));
+# 242 "Block.m"
+return(self->nVars==2)?(id)self:(objcT29=(id)self,(*_imp(objcT29,selTransTbl[16]))(objcT29,selTransTbl[16]));
 }
 
 static id i_Block_value(struct Block_PRIVATE *self,SEL _cmd)
 {
-id objcT21;
+id objcT30;
 
-# 201 "Block.m"
-return(self->nVars==0)?(id)( *self->fn)((id)self,self->data):(objcT21=(id)self,(*_imp(objcT21,selTransTbl[13]))(objcT21,selTransTbl[13]));
+# 247 "Block.m"
+return(self->nVars==0)?(id)( *self->fn)((id)self,self->data):(objcT30=(id)self,(*_imp(objcT30,selTransTbl[16]))(objcT30,selTransTbl[16]));
 }
 
 static int i_Block_intvalue(struct Block_PRIVATE *self,SEL _cmd)
 {
-id objcT22;
+id objcT31;
 
-# 206 "Block.m"
+# 252 "Block.m"
 if(self->nVars!=0)
-(objcT22=(id)self,(*_imp(objcT22,selTransTbl[13]))(objcT22,selTransTbl[13]));
+(objcT31=(id)self,(*_imp(objcT31,selTransTbl[16]))(objcT31,selTransTbl[16]));
 return( *((int(*)(id,void*))self->fn))((id)self,self->data);
 }
 
-# 223 "Block.m"
+# 269 "Block.m"
 static id i_Block_atExit(struct Block_PRIVATE *self,SEL _cmd)
 {
-id objcT23;
+id objcT32;
 
-return(objcT23=(id)self,(*_imp(objcT23,selTransTbl[14]))(objcT23,selTransTbl[14]));
-# 240 "Block.m"
+return(objcT32=(id)self,(*_imp(objcT32,selTransTbl[17]))(objcT32,selTransTbl[17]));
+# 286 "Block.m"
 }
 
 static id i_Block_value_(struct Block_PRIVATE *self,SEL _cmd,id anObject)
 {
-id objcT24;
+id objcT33;
 
-# 244 "Block.m"
-return(self->nVars==1)?(id)( *self->fn)((id)self,self->data,anObject):(objcT24=(id)self,(*_imp(objcT24,selTransTbl[13]))(objcT24,selTransTbl[13]));
+# 290 "Block.m"
+return(self->nVars==1)?(id)( *self->fn)((id)self,self->data,anObject):(objcT33=(id)self,(*_imp(objcT33,selTransTbl[16]))(objcT33,selTransTbl[16]));
 }
 
 static int i_Block_intvalue_(struct Block_PRIVATE *self,SEL _cmd,id anObject)
 {
-id objcT25;
+id objcT34;
 
-# 249 "Block.m"
+# 295 "Block.m"
 if(self->nVars!=1)
-(objcT25=(id)self,(*_imp(objcT25,selTransTbl[13]))(objcT25,selTransTbl[13]));
+(objcT34=(id)self,(*_imp(objcT34,selTransTbl[16]))(objcT34,selTransTbl[16]));
 return( *((int(*)(id,void*,id))self->fn))((id)self,self->data,anObject);
 }
 
@@ -461,49 +532,49 @@ return(id)( *self->fn)((id)self,self->data,firstObject,secondObject);
 }
 else
 {
-id objcT26;
+id objcT35;
 
-# 262 "Block.m"
-return(objcT26=(id)self,(*_imp(objcT26,selTransTbl[13]))(objcT26,selTransTbl[13]));
+# 308 "Block.m"
+return(objcT35=(id)self,(*_imp(objcT35,selTransTbl[16]))(objcT35,selTransTbl[16]));
 }
 return(id)0;
 }
 
 static int i_Block_intvalue_value_(struct Block_PRIVATE *self,SEL _cmd,id firstObject,id secondObject)
 {
-id objcT27;
+id objcT36;
 
-# 269 "Block.m"
+# 315 "Block.m"
 if(self->nVars!=2)
-(objcT27=(id)self,(*_imp(objcT27,selTransTbl[13]))(objcT27,selTransTbl[13]));
+(objcT36=(id)self,(*_imp(objcT36,selTransTbl[16]))(objcT36,selTransTbl[16]));
 return( *((int(*)(id,void*,id,id))self->fn))((id)self,self->data,firstObject,secondObject);
 }
 
-# 281 "Block.m"
+# 327 "Block.m"
 static id i_Block_repeatTimes_(struct Block_PRIVATE *self,SEL _cmd,int n)
 {
-id objcT28;
+id objcT37;
 
-# 283 "Block.m"
+# 329 "Block.m"
 int i;
 for(i=0;i<n;i++)
-(objcT28=(id)self,(*_imp(objcT28,selTransTbl[10]))(objcT28,selTransTbl[10]));
+(objcT37=(id)self,(*_imp(objcT37,selTransTbl[12]))(objcT37,selTransTbl[12]));
 return(id)self;
 }
 
 static id i_Block_shouldNotImplement(struct Block_PRIVATE *self,SEL _cmd)
 {
-id objcT29;
+id objcT38;
 
-(objcT29=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT29,selTransTbl[8]))(objcT29,selTransTbl[8],"Message is not approriate for this class."));
+(objcT38=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT38,selTransTbl[15]))(objcT38,selTransTbl[15],"Message is not approriate for this class."));
 return(id)self;
 }
 
 static id i_Block_printOn_(struct Block_PRIVATE *self,SEL _cmd,IOD anIod)
 {
-id objcT30;
+id objcT39;
 
-return(objcT30=(id)self,(*_imp(objcT30,selTransTbl[3]))(objcT30,selTransTbl[3]));
+return(objcT39=(id)self,(*_imp(objcT39,selTransTbl[3]))(objcT39,selTransTbl[3]));
 }
 extern id  Object;
 extern struct _SHARED _Object;
@@ -511,10 +582,9 @@ extern struct _SHARED __Object;
 static struct _SLT _Block_clsDispatchTbl[] ={
 {"new",(id (*)())c_Block_new},
 {"blkc:blkfn:blkv:blkdtor:",(id (*)())c_Block_blkc_blkfn_blkv_blkdtor_},
-{"pop",(id (*)())c_Block_pop},
-{"push:",(id (*)())c_Block_push_},
 {"errorHandler",(id (*)())c_Block_errorHandler},
 {"errorHandler:",(id (*)())c_Block_errorHandler_},
+{"halt:value:",(id (*)())c_Block_halt_value_},
 {(char*)0,(id (*)())0}
 };
 static struct _SLT _Block_nstDispatchTbl[] ={
@@ -525,6 +595,10 @@ static struct _SLT _Block_nstDispatchTbl[] ={
 {"release",(id (*)())i_Block_release},
 {"ifError:",(id (*)())i_Block_ifError_},
 {"value:ifError:",(id (*)())i_Block_value_ifError_},
+{"push:",(id (*)())i_Block_push_},
+{"pop",(id (*)())i_Block_pop},
+{"on:do:",(id (*)())i_Block_on_do_},
+{"value:on:do:",(id (*)())i_Block_value_on_do_},
 {"errorNumArgs",(id (*)())i_Block_errorNumArgs},
 {"errorGoodHandler",(id (*)())i_Block_errorGoodHandler},
 {"value",(id (*)())i_Block_value},
@@ -547,7 +621,7 @@ struct _SHARED  _Block = {
   "Block",
   0,
   sizeof(struct Block_PRIVATE),
-  19,
+  23,
   _Block_nstDispatchTbl,
   41,
   &Block_modDesc,
@@ -563,7 +637,7 @@ struct _SHARED __Block = {
   "Block",
   0,
   sizeof(struct _SHARED),
-  6,
+  5,
   _Block_clsDispatchTbl,
   34,
   &Block_modDesc,
@@ -582,23 +656,26 @@ static char *_selTransTbl[] ={
 "free",
 "release",
 "errorGoodHandler",
-"error:",
+"errorHandler",
+"pop",
+"value:value:",
 "push:",
 "value",
-"pop",
 "value:",
+"install:",
+"error:",
 "errorNumArgs",
 "notImplemented",
 0
 };
 struct modDescriptor Block_modDesc = {
   "Block",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
   &Block,
-  15,
+  18,
   _selTransTbl,
   0
 };
