@@ -763,45 +763,27 @@ static id i_Object_halt_(struct Object_PRIVATE *self,SEL _cmd,id message)
 id objcT40;
 
 # 528 "Object.m"
-id handler=(objcT40=Block,(*_imp(objcT40,selTransTbl[20]))(objcT40,selTransTbl[20]));
-
-if(handler)
-{
-id objcT41,objcT42;
-
-# 532 "Object.m"
-(objcT41=handler,(*_imp(objcT41,selTransTbl[21]))(objcT41,selTransTbl[21],message,(id)self));
-(objcT42=Block,(*_imp(objcT42,selTransTbl[22]))(objcT42,selTransTbl[22],handler));
-}
-else
-{
-id objcT43,objcT44;
-
-# 537 "Object.m"
-handler=(objcT43=Block,(*_imp(objcT43,selTransTbl[23]))(objcT43,selTransTbl[23]));
-(objcT44=handler,(*_imp(objcT44,selTransTbl[21]))(objcT44,selTransTbl[21],message,(id)self));
-}
-
+(objcT40=Block,(*_imp(objcT40,selTransTbl[20]))(objcT40,selTransTbl[20],message,(id)self));
 return(id)self;
 }
 
-# 552 "Object.m"
+# 540 "Object.m"
 static id i_Object_doesNotRecognize_(struct Object_PRIVATE *self,SEL _cmd,SEL aSelector)
 {
-id objcT45;
+id objcT41;
 
-# 554 "Object.m"
-return(objcT45=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT45,selTransTbl[7]))(objcT45,selTransTbl[7],"Message not recognized by this class."));
+# 542 "Object.m"
+return(objcT41=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT41,selTransTbl[7]))(objcT41,selTransTbl[7],"Message not recognized by this class."));
 }
 static id i_Object_doesNotUnderstand_(struct Object_PRIVATE *self,SEL _cmd,id aMessage)
 {
-id objcT46,objcT47;
+id objcT42,objcT43;
 
-# 558 "Object.m"
-return(objcT46=(id)self,(*(id(*)(id,SEL,SEL))_imp(objcT46,selTransTbl[24]))(objcT46,selTransTbl[24],(objcT47=aMessage,(*(SEL(*)(id,SEL))_imp(objcT47,selTransTbl[25]))(objcT47,selTransTbl[25]))));
+# 546 "Object.m"
+return(objcT42=(id)self,(*(id(*)(id,SEL,SEL))_imp(objcT42,selTransTbl[21]))(objcT42,selTransTbl[21],(objcT43=aMessage,(*(SEL(*)(id,SEL))_imp(objcT43,selTransTbl[22]))(objcT43,selTransTbl[22]))));
 }
 
-# 568 "Object.m"
+# 556 "Object.m"
 static IMP i_Object_methodFor_(struct Object_PRIVATE *self,SEL _cmd,SEL aSelector)
 {
 return _imp((id)self,aSelector);
@@ -812,7 +794,7 @@ static IMP c_Object_instanceMethodFor_(struct Object_PRIVATE *self,SEL _cmd,SEL
 return _impSuper((id)self,aSelector);
 }
 
-# 585 "Object.m"
+# 573 "Object.m"
 static id i_Object_perform_(struct Object_PRIVATE *self,SEL _cmd,SEL aSelector)
 {
 return( *fwdimp((id)self,aSelector,selptrfwd))((id)self,aSelector);
@@ -836,46 +818,47 @@ static id i_Object_perform_with_with_with_(struct Object_PRIVATE *self,SEL _cmd,
 return( *fwdimp((id)self,aSelector,selptrfwd))((id)self,aSelector,anObject,otherObject,thirdObj);
 }
 
-# 613 "Object.m"
+# 601 "Object.m"
 static id i_Object_print(struct Object_PRIVATE *self,SEL _cmd)
 {
-id objcT48;
+id objcT44;
 
-# 615 "Object.m"
-return(objcT48=(id)self,(*(id(*)(id,SEL,IOD))_imp(objcT48,selTransTbl[26]))(objcT48,selTransTbl[26],stdout));
+# 603 "Object.m"
+return(objcT44=(id)self,(*(id(*)(id,SEL,IOD))_imp(objcT44,selTransTbl[23]))(objcT44,selTransTbl[23],stdout));
 }
 
 static id c_Object_print(struct Object_PRIVATE *self,SEL _cmd)
 {
-id objcT49;
+id objcT45;
 
-# 620 "Object.m"
-printf((objcT49=(id)self,(*(STR(*)(id,SEL))_imp(objcT49,selTransTbl[5]))(objcT49,selTransTbl[5])));
+# 608 "Object.m"
+printf((objcT45=(id)self,(*(STR(*)(id,SEL))_imp(objcT45,selTransTbl[5]))(objcT45,selTransTbl[5])));
 return(id)self;
 }
 
 
 static id i_Object_printLine(struct Object_PRIVATE *self,SEL _cmd)
 {
-id objcT50;
+id objcT46;
 
-# 627 "Object.m"
-(objcT50=(id)self,(*_imp(objcT50,selTransTbl[27]))(objcT50,selTransTbl[27]));
+# 615 "Object.m"
+(objcT46=(id)self,(*_imp(objcT46,selTransTbl[24]))(objcT46,selTransTbl[24]));
 printf("\n");
 return(id)self;
 }
 
 static id i_Object_show(struct Object_PRIVATE *self,SEL _cmd)
 {
-return( *_showOn)((id)self,0);
+( *_showOn)((id)self,0);
+return(id)self;
 }
 
 static id i_Object_printToFile_(struct Object_PRIVATE *self,SEL _cmd,FILE*aFile)
 {
-id objcT51;
+id objcT47;
 
-# 648 "Object.m"
-return(objcT51=(id)self,(*(id(*)(id,SEL,IOD))_imp(objcT51,selTransTbl[26]))(objcT51,selTransTbl[26],aFile));
+# 637 "Object.m"
+return(objcT47=(id)self,(*(id(*)(id,SEL,IOD))_imp(objcT47,selTransTbl[23]))(objcT47,selTransTbl[23],aFile));
 }
 
 static id i_Object_printOn_(struct Object_PRIVATE *self,SEL _cmd,IOD anIOD)
@@ -883,13 +866,13 @@ static id i_Object_printOn_(struct Object_PRIVATE *self,SEL _cmd,IOD anIOD)
 return(id)self;
 }
 
-# 662 "Object.m"
+# 651 "Object.m"
 static STR c_Object_objcrtRevision(struct Object_PRIVATE *self,SEL _cmd)
 {
-return"3.1.6";
+return"3.2.1";
 }
 
-# 673 "Object.m"
+# 662 "Object.m"
 static id c_Object_readFrom_(struct Object_PRIVATE *self,SEL _cmd,STR aFileName)
 {
 return( *_readFrom)(aFileName);
@@ -899,7 +882,7 @@ static BOOL i_Object_storeOn_(struct Object_PRIVATE *self,SEL _cmd,STR aFileName
 return( *_storeOn)(aFileName,(id)self);
 }
 
-# 687 "Object.m"
+# 676 "Object.m"
 static id i_Object_fileOutIdsFor_(struct Object_PRIVATE *self,SEL _cmd,id aFiler)
 {
 return(id)self;
@@ -922,42 +905,42 @@ return(id)self;
 
 static id i_Object_fileOutOn_(struct Object_PRIVATE *self,SEL _cmd,id aFiler)
 {
-id objcT52,objcT53;
+id objcT48,objcT49;
 
-# 709 "Object.m"
-(objcT52=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT52,selTransTbl[28]))(objcT52,selTransTbl[28], &self->isa,'#'));
-return(objcT53=(id)self,(*_imp(objcT53,selTransTbl[29]))(objcT53,selTransTbl[29],aFiler));
+# 698 "Object.m"
+(objcT48=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT48,selTransTbl[25]))(objcT48,selTransTbl[25], &self->isa,'#'));
+return(objcT49=(id)self,(*_imp(objcT49,selTransTbl[26]))(objcT49,selTransTbl[26],aFiler));
 }
 static id c_Object_fileInFrom_(struct Object_PRIVATE *self,SEL _cmd,id aFiler)
 {
-id objcT54;
+id objcT50;
 
-# 714 "Object.m"
+# 703 "Object.m"
 id newObject=( *oc_alloc)((id)self,0);
-return(objcT54=newObject,(*_imp(objcT54,selTransTbl[30]))(objcT54,selTransTbl[30],aFiler));
+return(objcT50=newObject,(*_imp(objcT50,selTransTbl[27]))(objcT50,selTransTbl[27],aFiler));
 }
 
 static id i_Object_fileInFrom_(struct Object_PRIVATE *self,SEL _cmd,id aFiler)
 {
-id objcT55;
+id objcT51;
 
-# 720 "Object.m"
-return(objcT55=(id)self,(*_imp(objcT55,selTransTbl[31]))(objcT55,selTransTbl[31],aFiler));
+# 709 "Object.m"
+return(objcT51=(id)self,(*_imp(objcT51,selTransTbl[28]))(objcT51,selTransTbl[28],aFiler));
 }
 static id i_Object_fileOut_type_(struct Object_PRIVATE *self,SEL _cmd,void*value,char typeDesc)
 {
-id objcT56;
+id objcT52;
 
-# 724 "Object.m"
-return(objcT56=(id)self,(*_imp(objcT56,selTransTbl[17]))(objcT56,selTransTbl[17]));
+# 713 "Object.m"
+return(objcT52=(id)self,(*_imp(objcT52,selTransTbl[17]))(objcT52,selTransTbl[17]));
 }
 
 static id i_Object_fileIn_type_(struct Object_PRIVATE *self,SEL _cmd,void*value,char typeDesc)
 {
-id objcT57;
+id objcT53;
 
-# 729 "Object.m"
-return(objcT57=(id)self,(*_imp(objcT57,selTransTbl[17]))(objcT57,selTransTbl[17]));
+# 718 "Object.m"
+return(objcT53=(id)self,(*_imp(objcT53,selTransTbl[17]))(objcT53,selTransTbl[17]));
 }
 
 static id i_Object_awake(struct Object_PRIVATE *self,SEL _cmd)
@@ -967,10 +950,10 @@ return(id)self;
 
 static id i_Object_awakeFrom_(struct Object_PRIVATE *self,SEL _cmd,id aFiler)
 {
-id objcT58;
+id objcT54;
 
-# 739 "Object.m"
-return(objcT58=(id)self,(*_imp(objcT58,selTransTbl[32]))(objcT58,selTransTbl[32]));
+# 728 "Object.m"
+return(objcT54=(id)self,(*_imp(objcT54,selTransTbl[29]))(objcT54,selTransTbl[29]));
 }
 static struct _SLT _Object_clsDispatchTbl[] ={
 {"initialize",(id (*)())c_Object_initialize},
@@ -1125,10 +1108,7 @@ static char *_selTransTbl[] ={
 "subclassResponsibility",
 "halt:",
 "vsprintf::",
-"pop",
-"value:value:",
-"push:",
-"errorHandler",
+"halt:value:",
 "doesNotRecognize:",
 "selector",
 "printOn:",
@@ -1142,12 +1122,12 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor Object_modDesc = {
   "Object",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
   &Object,
-  33,
+  30,
   _selTransTbl,
   0
 };
