@@ -141,13 +141,13 @@ extern struct _SHARED _AsciiFiler;
 extern struct _SHARED __AsciiFiler;
 
 
-# 39 "ascfiler.m"
+# 43 "ascfiler.m"
 static BOOL
 asciiFileOut(FILE*f,id anObject)
 {
 id objcT0,objcT1,objcT2;
 
-# 42 "ascfiler.m"
+# 46 "ascfiler.m"
 BOOL r;
 id aFiler=(objcT0=AsciiFiler,(*_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0]));
 r=(objcT1=aFiler,(*(BOOL(*)(id,SEL,id,FILE*))_imp(objcT1,selTransTbl[1]))(objcT1,selTransTbl[1],anObject,f));
@@ -162,7 +162,7 @@ asciiFileIn(FILE*f)
 {
 id objcT3,objcT4,objcT5;
 
-# 54 "ascfiler.m"
+# 58 "ascfiler.m"
 id r;
 id aFiler=(objcT3=AsciiFiler,(*_imp(objcT3,selTransTbl[0]))(objcT3,selTransTbl[0]));
 r=(objcT4=aFiler,(*(id(*)(id,SEL,FILE*))_imp(objcT4,selTransTbl[3]))(objcT4,selTransTbl[3],f));
@@ -179,12 +179,12 @@ setfileout(asciiFileOut);
 return(id)self;
 }
 
-# 77 "ascfiler.m"
+# 81 "ascfiler.m"
 static id c_AsciiFiler_new(struct AsciiFiler_PRIVATE *self,SEL _cmd)
 {
 id objcT6;
 
-# 79 "ascfiler.m"
+# 83 "ascfiler.m"
 return(objcT6=__AsciiFiler.clsSuper,(*_impSuper(objcT6,selTransTbl[0]))((id)self,selTransTbl[0]));
 }
 
@@ -192,7 +192,7 @@ static id i_AsciiFiler_free(struct AsciiFiler_PRIVATE *self,SEL _cmd)
 {
 id objcT7;
 
-# 84 "ascfiler.m"
+# 88 "ascfiler.m"
 if(self->ownFile)
 {
 fclose(self->file);
@@ -200,7 +200,7 @@ fclose(self->file);
 return(objcT7=_AsciiFiler.clsSuper,(*_impSuper(objcT7,selTransTbl[2]))((id)self,selTransTbl[2]));
 }
 
-# 98 "ascfiler.m"
+# 102 "ascfiler.m"
 static BOOL i_AsciiFiler_store_on_(struct AsciiFiler_PRIVATE *self,SEL _cmd,id anObject,STR aFileName)
 {
 BOOL r;
@@ -209,7 +209,7 @@ if((self->file=fopen(aFileName,"w")))
 {
 id objcT8;
 self->
-# 104 "ascfiler.m"
+# 108 "ascfiler.m"
 ownFile=(BOOL)1;
 r=(objcT8=(id)self,(*(BOOL(*)(id,SEL,id,FILE*))_imp(objcT8,selTransTbl[1]))(objcT8,selTransTbl[1],anObject,self->file));
 if(self->ownFile)
@@ -234,7 +234,7 @@ if((self->file=fopen(aFileName,"r")))
 {
 id objcT9;
 self->
-# 126 "ascfiler.m"
+# 130 "ascfiler.m"
 ownFile=(BOOL)1;
 r=(objcT9=(id)self,(*(id(*)(id,SEL,FILE*))_imp(objcT9,selTransTbl[3]))(objcT9,selTransTbl[3],self->file));
 if(self->ownFile)
@@ -251,37 +251,37 @@ r=(id)0;
 return r;
 }
 
-# 160 "ascfiler.m"
+# 165 "ascfiler.m"
 static BOOL
 isClass(id anObject)
 {
 id objcT10;
 
-# 163 "ascfiler.m"
+# 168 "ascfiler.m"
 return anObject!=(id)0&&(objcT10=anObject,(*_imp(objcT10,selTransTbl[4]))(objcT10,selTransTbl[4]))==anObject;
 }
 
 # 39 "ordcltn.h"
 extern id  OrdCltn;
 
-# 166 "ascfiler.m"
+# 171 "ascfiler.m"
 static BOOL i_AsciiFiler_store_onFile_(struct AsciiFiler_PRIVATE *self,SEL _cmd,id anObject,FILE*aFile)
 {
 id objcT11,objcT12,objcT13,objcT14,objcT17;
 
-# 168 "ascfiler.m"
+# 173 "ascfiler.m"
 int i,n;self->
 
 file=aFile;
 
 
-fprintf(self->file,"#%s i%d \n",(objcT11=(id)self,(*(STR(*)(id,SEL))_imp(objcT11,selTransTbl[5]))(objcT11,selTransTbl[5])),317);self->
+fprintf(self->file,"#%s i%d \n",(objcT11=(id)self,(*(STR(*)(id,SEL))_imp(objcT11,selTransTbl[5]))(objcT11,selTransTbl[5])),325);self->
 
 
 inSecondPass=(BOOL)0;self->
 toc=(objcT12=OrdCltn,(*_imp(objcT12,selTransTbl[0]))(objcT12,selTransTbl[0]));
 (objcT13=(id)self,(*_imp(objcT13,selTransTbl[6]))(objcT13,selTransTbl[6],anObject));self->
-# 182 "ascfiler.m"
+# 187 "ascfiler.m"
 inSecondPass=(BOOL)1;
 for(i=0,n=(objcT14=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT14,selTransTbl[7]))(objcT14,selTransTbl[7]));i<n;i++)
 {
@@ -298,7 +298,7 @@ fprintf(self->file,"\n");
 inSecondPass=(BOOL)0;self->
 
 toc=(objcT17=self->toc,(*_imp(objcT17,selTransTbl[2]))(objcT17,selTransTbl[2]));
-# 202 "ascfiler.m"
+# 207 "ascfiler.m"
 return(BOOL)1;
 }
 
@@ -307,11 +307,15 @@ outClass(FILE*file,void*value)
 {
 id objcT18;
 
-# 208 "ascfiler.m"
+# 213 "ascfiler.m"
 id aClass= *((id*)value);
 fprintf(file,"#%s ",(objcT18=aClass,(*(STR(*)(id,SEL))_imp(objcT18,selTransTbl[5]))(objcT18,selTransTbl[5])));
 }
 
+# 28 "outofbnd.h"
+extern id  OutOfBounds;
+
+# 217 "ascfiler.m"
 static void
 outObject(id self,FILE*file,id toc,void*value)
 {
@@ -322,21 +326,29 @@ if(isClass(anObject))
 {
 id objcT19;
 
-# 220 "ascfiler.m"
+# 225 "ascfiler.m"
 (objcT19=self,(*(id(*)(id,SEL,void*,char))_imp(objcT19,selTransTbl[10]))(objcT19,selTransTbl[10],value,'#'));
 return;
 }
 
 if(anObject)
 {
-id objcT20,objcT21;
+id objcT20;
 
-# 226 "ascfiler.m"
+# 231 "ascfiler.m"
 int offset=(objcT20=toc,(*(unsigned(*)(id,SEL,id))_imp(objcT20,selTransTbl[11]))(objcT20,selTransTbl[11],anObject));
 if(offset== -1)
-(objcT21=self,(*(id(*)(id,SEL,STR,...))_imp(objcT21,selTransTbl[12]))(objcT21,selTransTbl[12],"AsciiFiler : offset error"));
+{
+id objcT21,objcT22,objcT23,objcT24;
+
+# 234 "ascfiler.m"
+(objcT21=(objcT22=(objcT23=OutOfBounds,(*(id(*)(id,SEL,unsigned))_imp(objcT23,selTransTbl[12]))(objcT23,selTransTbl[12],(objcT24=toc,(*(unsigned(*)(id,SEL))_imp(objcT24,selTransTbl[7]))(objcT24,selTransTbl[7])))),(*(id(*)(id,SEL,unsigned))_imp(objcT22,selTransTbl[8]))(objcT22,selTransTbl[8], -1)),(*_imp(objcT21,selTransTbl[13]))(objcT21,selTransTbl[13]));
+}
+else
+{
 fprintf(file,"@%i ",offset+1);
 }
+}
 else
 {
 fprintf(file,"@0 ");
@@ -385,7 +397,7 @@ double d= *((double*)value);
 fprintf(file,"d%f ",d);
 }
 
-# 283 "ascfiler.m"
+# 293 "ascfiler.m"
 static void
 outSTR(FILE*file,void*value)
 {
@@ -405,6 +417,10 @@ fprintf(file,"%c0 ",044);
 }
 }
 
+# 28 "unknownt.h"
+extern id  UnknownType;
+
+# 312 "ascfiler.m"
 static id i_AsciiFiler_fileOut2_type_(struct AsciiFiler_PRIVATE *self,SEL _cmd,void*value,char typeDesc)
 {
 switch(typeDesc)
@@ -440,10 +456,10 @@ fprintf(self->file,"%c0 ",044);
 break;
 default:
 {
-id objcT22;
+id objcT25,objcT26,objcT27;
 
-# 337 "ascfiler.m"
-(objcT22=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT22,selTransTbl[12]))(objcT22,selTransTbl[12],"Asciifiler: unknown type descriptor '%c'",typeDesc));
+# 347 "ascfiler.m"
+(objcT25=(objcT26=(objcT27=UnknownType,(*_imp(objcT27,selTransTbl[0]))(objcT27,selTransTbl[0])),(*(id(*)(id,SEL,char))_imp(objcT26,selTransTbl[14]))(objcT26,selTransTbl[14],typeDesc)),(*_imp(objcT25,selTransTbl[13]))(objcT25,selTransTbl[13]));
 break;
 }
 }
@@ -453,16 +469,16 @@ return(id)self;
 
 static id i_AsciiFiler_fileOutObject_(struct AsciiFiler_PRIVATE *self,SEL _cmd,id anObject)
 {
-id objcT23;
+id objcT28;
 
-# 347 "ascfiler.m"
-if(anObject!=(id)0&& !isClass(anObject)&&(objcT23=self->toc,(*_imp(objcT23,selTransTbl[13]))(objcT23,selTransTbl[13],anObject))==(id)0)
+# 357 "ascfiler.m"
+if(anObject!=(id)0&& !isClass(anObject)&&(objcT28=self->toc,(*_imp(objcT28,selTransTbl[15]))(objcT28,selTransTbl[15],anObject))==(id)0)
 {
-id objcT24,objcT25;
+id objcT29,objcT30;
 
-# 349 "ascfiler.m"
-(objcT24=self->toc,(*_imp(objcT24,selTransTbl[14]))(objcT24,selTransTbl[14],anObject));
-(objcT25=anObject,(*_imp(objcT25,selTransTbl[9]))(objcT25,selTransTbl[9],(id)self));
+# 359 "ascfiler.m"
+(objcT29=self->toc,(*_imp(objcT29,selTransTbl[16]))(objcT29,selTransTbl[16],anObject));
+(objcT30=anObject,(*_imp(objcT30,selTransTbl[9]))(objcT30,selTransTbl[9],(id)self));
 }
 
 return(id)self;
@@ -470,26 +486,25 @@ return(id)self;
 
 static id i_AsciiFiler_fileOut_type_(struct AsciiFiler_PRIVATE *self,SEL _cmd,void*value,char typeDesc)
 {
-id objcT26;
+id objcT31;
 
-# 358 "ascfiler.m"
+# 368 "ascfiler.m"
 if(self->inSecondPass)
-return(objcT26=(id)self,(*(id(*)(id,SEL,void*,char))_imp(objcT26,selTransTbl[10]))(objcT26,selTransTbl[10],value,typeDesc));
+return(objcT31=(id)self,(*(id(*)(id,SEL,void*,char))_imp(objcT31,selTransTbl[10]))(objcT31,selTransTbl[10],value,typeDesc));
 
 if(typeDesc=='@')
 {
-id objcT27;
+id objcT32;
 
-# 363 "ascfiler.m"
+# 373 "ascfiler.m"
 id anObject= *((id*)value);
-return(objcT27=(id)self,(*_imp(objcT27,selTransTbl[6]))(objcT27,selTransTbl[6],anObject));
+return(objcT32=(id)self,(*_imp(objcT32,selTransTbl[6]))(objcT32,selTransTbl[6],anObject));
 }
 
 return(id)self;
 }
-# 377 "ascfiler.m"
-static char changeErr[]="Asciifiler: type inconsistency :want '%c' got '%c'";
 
+# 387 "ascfiler.m"
 static int
 nextCode(FILE*file)
 {
@@ -502,8 +517,10 @@ while(code==' '||code=='\t');
 return code;
 }
 
+# 28 "typeinc.h"
+extern id  TypeInconsistency;
 
-
+# 401 "ascfiler.m"
 static int
 lex(id self,FILE*file,int expected,char*buffer)
 {
@@ -536,15 +553,15 @@ return code;
 
 if(code==expected)
 {
-# 439 "ascfiler.m"
+# 447 "ascfiler.m"
 return code;
 }
 else
 {
-id objcT28;
+id objcT33,objcT34,objcT35;
 
-# 443 "ascfiler.m"
-(objcT28=self,(*(id(*)(id,SEL,STR,...))_imp(objcT28,selTransTbl[12]))(objcT28,selTransTbl[12],changeErr,expected,code));
+# 451 "ascfiler.m"
+(objcT33=(objcT34=(objcT35=TypeInconsistency,(*_imp(objcT35,selTransTbl[0]))(objcT35,selTransTbl[0])),(*(id(*)(id,SEL,char,char))_imp(objcT34,selTransTbl[17]))(objcT34,selTransTbl[17],code,expected)),(*_imp(objcT33,selTransTbl[13]))(objcT33,selTransTbl[13]));
 return 0;
 }
 }
@@ -567,7 +584,7 @@ skipIX(FILE*file)
 int c;
 while(feof(file)==0&&(c=getc(file))!=' ')
 {
-# 469 "ascfiler.m"
+# 477 "ascfiler.m"
 }
 return 0==feof(file);
 }
@@ -586,10 +603,10 @@ return NULL;
 
 if(code!=expected)
 {
-id objcT29;
+id objcT36,objcT37,objcT38;
 
-# 487 "ascfiler.m"
-(objcT29=self,(*(id(*)(id,SEL,STR,...))_imp(objcT29,selTransTbl[12]))(objcT29,selTransTbl[12],changeErr,expected,code));
+# 495 "ascfiler.m"
+(objcT36=(objcT37=(objcT38=TypeInconsistency,(*_imp(objcT38,selTransTbl[0]))(objcT38,selTransTbl[0])),(*(id(*)(id,SEL,char,char))_imp(objcT37,selTransTbl[17]))(objcT37,selTransTbl[17],code,expected)),(*_imp(objcT36,selTransTbl[13]))(objcT36,selTransTbl[13]));
 return NULL;
 }
 else
@@ -609,7 +626,7 @@ q=s;
 while(len--) *
 q++=getc(file); *
 q++=0;
-# 511 "ascfiler.m"
+# 519 "ascfiler.m"
 return s;
 }
 }
@@ -617,12 +634,12 @@ return s;
 static id
 lexClass(id self,FILE*file)
 {
-id objcT30;
+id objcT39;
 
-# 518 "ascfiler.m"
+# 526 "ascfiler.m"
 char buffer[1024];
 lex(self,file,'#',buffer);
-return(objcT30=self,(*(id(*)(id,SEL,STR))_imp(objcT30,selTransTbl[15]))(objcT30,selTransTbl[15],buffer));
+return(objcT39=self,(*(id(*)(id,SEL,STR))_imp(objcT39,selTransTbl[18]))(objcT39,selTransTbl[18],buffer));
 }
 
 static int
@@ -688,12 +705,16 @@ skipNL(id self,FILE*file)
 lex(self,file,'\n',NULL);
 }
 
+# 28 "badvers.h"
+extern id  BadVersion;
+
+# 594 "ascfiler.m"
 static id i_AsciiFiler_readFromFile_(struct AsciiFiler_PRIVATE *self,SEL _cmd,FILE*aFile)
 {
-id objcT31,objcT33,objcT39,objcT40,objcT41;
-id objcT42,objcT43;
+id objcT44,objcT53,objcT54,objcT55,objcT56;
+id objcT57;
 
-# 588 "ascfiler.m"
+# 596 "ascfiler.m"
 id anObject;
 int i,n,version;self->
 
@@ -701,63 +722,79 @@ file=aFile;
 
 
 if(self->isa!=lexClass((id)self,self->file))
-(objcT31=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT31,selTransTbl[12]))(objcT31,selTransTbl[12],"Asciifiler: wrong filer"));
-version=lexInt((id)self,self->file);
-if(version!=317)
 {
-id objcT32;
+id objcT40;
 
-# 599 "ascfiler.m"
-STR msg="AsciiFiler '%d': input is in '%d' format";
-return(objcT32=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT32,selTransTbl[12]))(objcT32,selTransTbl[12],msg,317,version));
+# 604 "ascfiler.m"
+(objcT40=BadVersion,(*_imp(objcT40,selTransTbl[13]))(objcT40,selTransTbl[13]));
+return(id)0;
+}
+version=lexInt((id)self,self->file);
+if(version!=325)
+{
+id objcT41,objcT42,objcT43;
+
+# 610 "ascfiler.m"
+id e=(objcT41=BadVersion,(*_imp(objcT41,selTransTbl[0]))(objcT41,selTransTbl[0]));
+(objcT42=(objcT43=e,(*(id(*)(id,SEL,int,int))_imp(objcT43,selTransTbl[19]))(objcT43,selTransTbl[19],325,version)),(*_imp(objcT42,selTransTbl[13]))(objcT42,selTransTbl[13]));
+return(id)0;
 }
 
 skipNL((id)self,self->file);self->
 
-toc=(objcT33=OrdCltn,(*_imp(objcT33,selTransTbl[0]))(objcT33,selTransTbl[0]));self->
+toc=(objcT44=OrdCltn,(*_imp(objcT44,selTransTbl[0]))(objcT44,selTransTbl[0]));self->
 patchSize=0;self->
-patchCapacity=16;self->
+patchCapacity=64;self->
 patchPointers=(void**)OC_Malloc(sizeof(void*)*self->patchCapacity);
-# 616 "ascfiler.m"
+# 628 "ascfiler.m"
 while(feof(self->file)==0&&skipIX(self->file))
 {
-id objcT34,objcT35;
+id objcT45,objcT46;
 
-# 618 "ascfiler.m"
+# 630 "ascfiler.m"
+id tmpObject;
 id aClass=lexClass((id)self,self->file);
-anObject=(objcT34=aClass,(*_imp(objcT34,selTransTbl[16]))(objcT34,selTransTbl[16],(id)self));
-(objcT35=self->toc,(*_imp(objcT35,selTransTbl[14]))(objcT35,selTransTbl[14],anObject));
+tmpObject=(objcT45=aClass,(*_imp(objcT45,selTransTbl[20]))(objcT45,selTransTbl[20],(id)self));
+(objcT46=self->toc,(*_imp(objcT46,selTransTbl[16]))(objcT46,selTransTbl[16],tmpObject));
 skipNL((id)self,self->file);
 }
-# 626 "ascfiler.m"
+# 639 "ascfiler.m"
 for(i=0;i<self->patchSize;i++)
 {
-id objcT36,objcT38;
+id objcT47;
 
-# 628 "ascfiler.m"
+# 641 "ascfiler.m"
 int offset;
 void*value=self->patchPointers[i];
 offset= *((int*)value);
-if(offset>(objcT36=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT36,selTransTbl[7]))(objcT36,selTransTbl[7])))
+if(offset>(objcT47=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT47,selTransTbl[7]))(objcT47,selTransTbl[7])))
 {
-id objcT37;
+id objcT48,objcT49,objcT50,objcT51;
 
-# 633 "ascfiler.m"
-(objcT37=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT37,selTransTbl[12]))(objcT37,selTransTbl[12],"AsciiFiler : offset error"));
-} *
-((id*)value)=(offset)?(objcT38=self->toc,(*(id(*)(id,SEL,unsigned))_imp(objcT38,selTransTbl[8]))(objcT38,selTransTbl[8],offset-1)):(id)0;
+# 646 "ascfiler.m"
+(objcT48=(objcT49=(objcT50=OutOfBounds,(*(id(*)(id,SEL,unsigned))_imp(objcT50,selTransTbl[12]))(objcT50,selTransTbl[12],(objcT51=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT51,selTransTbl[7]))(objcT51,selTransTbl[7])))),(*(id(*)(id,SEL,unsigned))_imp(objcT49,selTransTbl[8]))(objcT49,selTransTbl[8],offset)),(*_imp(objcT48,selTransTbl[13]))(objcT48,selTransTbl[13]));
 }
-# 640 "ascfiler.m"
-for(i=0,n=(objcT39=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT39,selTransTbl[7]))(objcT39,selTransTbl[7]));i<n;i++)
-(objcT40=(objcT41=self->toc,(*(id(*)(id,SEL,unsigned))_imp(objcT41,selTransTbl[8]))(objcT41,selTransTbl[8],i)),(*_imp(objcT40,selTransTbl[17]))(objcT40,selTransTbl[17],(id)self));
-# 645 "ascfiler.m"
-anObject=(objcT42=self->toc,(*_imp(objcT42,selTransTbl[18]))(objcT42,selTransTbl[18]));
+else
+{
+id objcT52;
+
+# 650 "ascfiler.m"
+id realObject=(offset)?(objcT52=self->toc,(*(id(*)(id,SEL,unsigned))_imp(objcT52,selTransTbl[8]))(objcT52,selTransTbl[8],offset-1)):(id)0; *
+# 654 "ascfiler.m"
+(void**)value=NULL; *
+((id*)value)=realObject;
+}
+}
+# 661 "ascfiler.m"
+for(i=0,n=(objcT53=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT53,selTransTbl[7]))(objcT53,selTransTbl[7]));i<n;i++)
+(objcT54=(objcT55=self->toc,(*(id(*)(id,SEL,unsigned))_imp(objcT55,selTransTbl[8]))(objcT55,selTransTbl[8],i)),(*_imp(objcT54,selTransTbl[21]))(objcT54,selTransTbl[21],(id)self));
+# 666 "ascfiler.m"
+anObject=(objcT56=self->toc,(*_imp(objcT56,selTransTbl[22]))(objcT56,selTransTbl[22]));
 OC_Free(self->patchPointers);self->
 patchPointers=NULL;self->
 
-toc=(objcT43=self->toc,(*_imp(objcT43,selTransTbl[2]))(objcT43,selTransTbl[2]));
-
-
+toc=(objcT57=self->toc,(*_imp(objcT57,selTransTbl[2]))(objcT57,selTransTbl[2]));
+# 675 "ascfiler.m"
 return anObject;
 }
 
@@ -772,23 +809,23 @@ break;
 }
 case'@':
 {
-id objcT44;
+id objcT58;
 
-# 666 "ascfiler.m"
+# 689 "ascfiler.m"
 int offset;
 offset=lexObjectOffset((id)self,self->file);
-if(offset<=(objcT44=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT44,selTransTbl[7]))(objcT44,selTransTbl[7])))
+if(offset<=(objcT58=self->toc,(*(unsigned(*)(id,SEL))_imp(objcT58,selTransTbl[7]))(objcT58,selTransTbl[7])))
 {
-id objcT45;
+id objcT59;
  *
-# 670 "ascfiler.m"
-((id*)value)=(offset)?(objcT45=self->toc,(*(id(*)(id,SEL,unsigned))_imp(objcT45,selTransTbl[8]))(objcT45,selTransTbl[8],offset-1)):(id)0;
+# 693 "ascfiler.m"
+((id*)value)=(offset)?(objcT59=self->toc,(*(id(*)(id,SEL,unsigned))_imp(objcT59,selTransTbl[8]))(objcT59,selTransTbl[8],offset-1)):(id)0;
 }
 else
 { *
 
 ((int*)value)=offset;
-if(self->patchSize==self->patchCapacity)
+if(self->patchSize+1==self->patchCapacity)
 {self->
 patchCapacity=self->patchCapacity*2+1;self->
 patchPointers=(void**)OC_Realloc(self->patchPointers,self->patchCapacity);
@@ -842,10 +879,10 @@ break;
 }
 default:
 {
-id objcT46;
+id objcT60,objcT61,objcT62;
 
-# 730 "ascfiler.m"
-(objcT46=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT46,selTransTbl[12]))(objcT46,selTransTbl[12],"Asciifiler: unknown type descriptor '%c'",typeDesc));
+# 753 "ascfiler.m"
+(objcT60=(objcT61=(objcT62=UnknownType,(*_imp(objcT62,selTransTbl[0]))(objcT62,selTransTbl[0])),(*(id(*)(id,SEL,char))_imp(objcT61,selTransTbl[14]))(objcT61,selTransTbl[14],typeDesc)),(*_imp(objcT60,selTransTbl[13]))(objcT60,selTransTbl[13]));
 break;
 }
 }
@@ -919,10 +956,14 @@ static char *_selTransTbl[] ={
 "fileOutOn:",
 "fileOut2:type:",
 "offsetOf:",
-"error:",
+"new:",
+"signal",
+"typeDesc:",
 "find:",
 "add:",
+"got:wanted:",
 "idOfSTR:",
+"goodVersion:badVersion:",
 "fileInFrom:",
 "awakeFrom:",
 "firstElement",
@@ -930,12 +971,12 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor ascfiler_modDesc = {
   "ascfiler",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
   &AsciiFiler,
-  19,
+  23,
   _selTransTbl,
   0
 };
