@@ -278,7 +278,7 @@ id mkbitfielddecl(id decl,id expr);
 id mkstardecl(id pointer,id decl);
 id mkasmop(id string,id expr);
 id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
-id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
+id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
 id mklist(id c,id s);
 id mklist2(id c,id s,id t);
 id atdefsaddall(id c,id n);
@@ -324,6 +324,7 @@ void defoptions(void);
 
 extern int o_warnings;
 extern int o_gnu;
+extern int o_hpux;
 extern int o_vms;
 extern int o_refcnt;
 extern int o_ppi;
@@ -402,6 +403,7 @@ id lbrace;
 id datadefs;
 id initializers;
 id stmts;
+id subblock;
 id rbrace;
 id enclosing;
 id returnlabel;
@@ -522,6 +524,12 @@ stmts=stmtlist;
 return(id)self;
 }
 
+static id i_CompoundStmt_subblock_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id sub)
+{self->
+subblock=sub;
+return(id)self;
+}
+
 static id i_CompoundStmt_nextreturnlabel(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
 if(self->returnlabel){
@@ -531,12 +539,12 @@ if(self->enclosing){
 if(self->decrefs||self->heapvars){
 id objcT4;
 
-# 142 "compstmt.m"
+# 148 "compstmt.m"
 return(objcT4=(id)self,(*_imp(objcT4,selTransTbl[3]))(objcT4,selTransTbl[3]));
 }else{
 id objcT5;
 
-# 144 "compstmt.m"
+# 150 "compstmt.m"
 return(objcT5=self->enclosing,(*_imp(objcT5,selTransTbl[4]))(objcT5,selTransTbl[4]));
 }
 }else{
@@ -556,7 +564,7 @@ fatal("-refcnt doesn't work inside GNU ({...}) braced groups");
 }else{
 id objcT7;
 self->
-# 161 "compstmt.m"
+# 167 "compstmt.m"
 returnlabel=(objcT7=trlunit,(*_imp(objcT7,selTransTbl[3]))(objcT7,selTransTbl[3]));
 }
 }
@@ -573,7 +581,7 @@ static id i_CompoundStmt_synth(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
 id objcT16,objcT17,objcT18,objcT19;
 
-# 175 "compstmt.m"
+# 181 "compstmt.m"
 int i,n;self->
 
 enclosing=curcompound;
@@ -581,23 +589,23 @@ curcompound=(id)self;
 if( !self->enclosing){
 id objcT8,objcT9;
 self->
-# 180 "compstmt.m"
+# 186 "compstmt.m"
 restype=(objcT8=curdef,(*_imp(objcT8,selTransTbl[5]))(objcT8,selTransTbl[5]));self->
 parmnames=(objcT9=curdef,(*_imp(objcT9,selTransTbl[6]))(objcT9,selTransTbl[6]));
 if(o_refcnt){
 id objcT10;
 
-# 183 "compstmt.m"
+# 189 "compstmt.m"
 for(i=0,n=(objcT10=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT10,selTransTbl[7]))(objcT10,selTransTbl[7]));i<n;i++){
 id objcT11,objcT12,objcT13;
 
-# 184 "compstmt.m"
+# 190 "compstmt.m"
 id x=(objcT11=self->parmnames,(*(id(*)(id,SEL,unsigned))_imp(objcT11,selTransTbl[8]))(objcT11,selTransTbl[8],i));
 
 if((objcT12=(objcT13=curdef,(*_imp(objcT13,selTransTbl[9]))(objcT13,selTransTbl[9],x)),(*(BOOL(*)(id,SEL))_imp(objcT12,selTransTbl[10]))(objcT12,selTransTbl[10]))){
 id objcT14,objcT15;
 
-# 187 "compstmt.m"
+# 193 "compstmt.m"
 (objcT14=(id)self,(*_imp(objcT14,selTransTbl[11]))(objcT14,selTransTbl[11],x));
 (objcT15=(id)self,(*_imp(objcT15,selTransTbl[12]))(objcT15,selTransTbl[12],x));
 }
@@ -614,13 +622,13 @@ if(o_refcnt)
 for(i=0,n=(objcT19=self->locals,(*(unsigned(*)(id,SEL))_imp(objcT19,selTransTbl[7]))(objcT19,selTransTbl[7]));i<n;i++){
 id objcT20,objcT21,objcT22,objcT23;
 
-# 201 "compstmt.m"
+# 207 "compstmt.m"
 id x=(objcT20=self->locals,(*(id(*)(id,SEL,unsigned))_imp(objcT20,selTransTbl[8]))(objcT20,selTransTbl[8],i));
 
 if((objcT21=(objcT22=(id)self,(*_imp(objcT22,selTransTbl[15]))(objcT22,selTransTbl[15],x)),(*(BOOL(*)(id,SEL))_imp(objcT21,selTransTbl[10]))(objcT21,selTransTbl[10]))&& !(objcT23=(id)self,(*(BOOL(*)(id,SEL,id))_imp(objcT23,selTransTbl[16]))(objcT23,selTransTbl[16],x))){
 id objcT24;
 
-# 204 "compstmt.m"
+# 210 "compstmt.m"
 (objcT24=(id)self,(*_imp(objcT24,selTransTbl[12]))(objcT24,selTransTbl[12],x));
 }
 }
@@ -631,9 +639,9 @@ return(id)self;
 static id i_CompoundStmt_gen(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
 id objcT25,objcT26,objcT30,objcT31,objcT32;
-id objcT33,objcT34,objcT41;
+id objcT33,objcT34,objcT35,objcT42;
 
-# 213 "compstmt.m"
+# 219 "compstmt.m"
 if(self->lbrace)
 (objcT25=self->lbrace,(*_imp(objcT25,selTransTbl[17]))(objcT25,selTransTbl[17]));
 else
@@ -644,7 +652,7 @@ if(self->needreturnflag)gs("int _returnflag = 0;\n");
 if(o_refcnt&&self->enclosing==(id)0&& !(objcT26=self->restype,(*(BOOL(*)(id,SEL))_imp(objcT26,selTransTbl[18]))(objcT26,selTransTbl[18]))){
 id objcT27,objcT28;
 
-# 221 "compstmt.m"
+# 227 "compstmt.m"
 (objcT27=self->restype,(*_imp(objcT27,selTransTbl[19]))(objcT27,selTransTbl[19],s_returnval));
 if((objcT28=self->restype,(*(BOOL(*)(id,SEL))_imp(objcT28,selTransTbl[20]))(objcT28,selTransTbl[20]))){
 id objcT29;
@@ -668,37 +676,39 @@ if(self->initializers)
 (objcT33=self->initializers,(*(id(*)(id,SEL,SEL))_imp(objcT33,selTransTbl[13]))(objcT33,selTransTbl[13],_cmd));
 if(self->stmts)
 (objcT34=self->stmts,(*(id(*)(id,SEL,SEL))_imp(objcT34,selTransTbl[13]))(objcT34,selTransTbl[13],_cmd));
+if(self->subblock)
+(objcT35=self->subblock,(*_imp(objcT35,selTransTbl[17]))(objcT35,selTransTbl[17]));
 if(self->returnlabel){
-id objcT35;
+id objcT36;
 
-# 245 "compstmt.m"
+# 253 "compstmt.m"
 gc('\n');
-gs((objcT35=self->returnlabel,(*(STR(*)(id,SEL))_imp(objcT35,selTransTbl[24]))(objcT35,selTransTbl[24])));
+gs((objcT36=self->returnlabel,(*(STR(*)(id,SEL))_imp(objcT36,selTransTbl[24]))(objcT36,selTransTbl[24])));
 gs(":\n");
 }
 if(self->heapvars){
-id objcT36;
-
-# 250 "compstmt.m"
-(objcT36=(id)self,(*_imp(objcT36,selTransTbl[25]))(objcT36,selTransTbl[25]));
-}
-if(o_refcnt){
 id objcT37;
 
-# 253 "compstmt.m"
-if(self->decrefs)
-(objcT37=(id)self,(*_imp(objcT37,selTransTbl[26]))(objcT37,selTransTbl[26]));
-if(self->checkreturnflag){
-id objcT38,objcT39;
+# 258 "compstmt.m"
+(objcT37=(id)self,(*_imp(objcT37,selTransTbl[25]))(objcT37,selTransTbl[25]));
+}
+if(o_refcnt){
+id objcT38;
 
-# 256 "compstmt.m"
-gf("if (_returnflag) goto %s;\n",(objcT38=(objcT39=self->enclosing,(*_imp(objcT39,selTransTbl[4]))(objcT39,selTransTbl[4])),(*(STR(*)(id,SEL))_imp(objcT38,selTransTbl[24]))(objcT38,selTransTbl[24])));
+# 261 "compstmt.m"
+if(self->decrefs)
+(objcT38=(id)self,(*_imp(objcT38,selTransTbl[26]))(objcT38,selTransTbl[26]));
+if(self->checkreturnflag){
+id objcT39,objcT40;
+
+# 264 "compstmt.m"
+gf("if (_returnflag) goto %s;\n",(objcT39=(objcT40=self->enclosing,(*_imp(objcT40,selTransTbl[4]))(objcT40,selTransTbl[4])),(*(STR(*)(id,SEL))_imp(objcT39,selTransTbl[24]))(objcT39,selTransTbl[24])));
 }
 if(self->enclosing==(id)0){
-id objcT40;
+id objcT41;
 
-# 259 "compstmt.m"
-if((objcT40=self->restype,(*(BOOL(*)(id,SEL))_imp(objcT40,selTransTbl[18]))(objcT40,selTransTbl[18]))){
+# 267 "compstmt.m"
+if((objcT41=self->restype,(*(BOOL(*)(id,SEL))_imp(objcT41,selTransTbl[18]))(objcT41,selTransTbl[18]))){
 gs("return;\n");
 }else{
 gs("return _returnval;");
@@ -706,7 +716,7 @@ gs("return _returnval;");
 }
 }
 if(self->rbrace)
-(objcT41=self->rbrace,(*_imp(objcT41,selTransTbl[17]))(objcT41,selTransTbl[17]));
+(objcT42=self->rbrace,(*_imp(objcT42,selTransTbl[17]))(objcT42,selTransTbl[17]));
 else
 gc('}');
 return(id)self;
@@ -724,50 +734,50 @@ extern id  OrdCltn;
 # 29 "shared.m"
 static id i_CompoundStmt_addtmpvar_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id tvar)
 {
-id objcT42,objcT43;
+id objcT43,objcT44;
 
 # 31 "shared.m"
 if( !self->tmpvars)self->
-tmpvars=(objcT42=OrdCltn,(*_imp(objcT42,selTransTbl[27]))(objcT42,selTransTbl[27]));
-(objcT43=self->tmpvars,(*_imp(objcT43,selTransTbl[28]))(objcT43,selTransTbl[28],tvar));
+tmpvars=(objcT43=OrdCltn,(*_imp(objcT43,selTransTbl[27]))(objcT43,selTransTbl[27]));
+(objcT44=self->tmpvars,(*_imp(objcT44,selTransTbl[28]))(objcT44,selTransTbl[28],tvar));
 return(id)self;
 }
 
 static id i_CompoundStmt_addicache_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id tvar)
 {
-id objcT44,objcT45;
+id objcT45,objcT46;
 
 # 39 "shared.m"
 if( !self->icaches)self->
-icaches=(objcT44=OrdCltn,(*_imp(objcT44,selTransTbl[27]))(objcT44,selTransTbl[27]));
-(objcT45=self->icaches,(*_imp(objcT45,selTransTbl[28]))(objcT45,selTransTbl[28],tvar));
+icaches=(objcT45=OrdCltn,(*_imp(objcT45,selTransTbl[27]))(objcT45,selTransTbl[27]));
+(objcT46=self->icaches,(*_imp(objcT46,selTransTbl[28]))(objcT46,selTransTbl[28],tvar));
 return(id)self;
 }
 
 static id i_CompoundStmt_addincref_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id v)
 {
-id objcT46,objcT47;
+id objcT47,objcT48;
 
 # 47 "shared.m"
 if( !self->increfs)self->
-increfs=(objcT46=OrdCltn,(*_imp(objcT46,selTransTbl[27]))(objcT46,selTransTbl[27]));
-(objcT47=self->increfs,(*_imp(objcT47,selTransTbl[28]))(objcT47,selTransTbl[28],v));
+increfs=(objcT47=OrdCltn,(*_imp(objcT47,selTransTbl[27]))(objcT47,selTransTbl[27]));
+(objcT48=self->increfs,(*_imp(objcT48,selTransTbl[28]))(objcT48,selTransTbl[28],v));
 return(id)self;
 }
 
 static id i_CompoundStmt_genincrefs(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT48;
+id objcT49;
 
 # 55 "shared.m"
-int i,n=(objcT48=self->increfs,(*(unsigned(*)(id,SEL))_imp(objcT48,selTransTbl[7]))(objcT48,selTransTbl[7]));
+int i,n=(objcT49=self->increfs,(*(unsigned(*)(id,SEL))_imp(objcT49,selTransTbl[7]))(objcT49,selTransTbl[7]));
 
 for(i=0;i<n;i++){
-id objcT49,objcT50,objcT51,objcT52,objcT53;
+id objcT50,objcT51,objcT52,objcT53,objcT54;
 
 # 58 "shared.m"
-if(self->lbrace)gl((objcT49=self->lbrace,(*(int(*)(id,SEL))_imp(objcT49,selTransTbl[1]))(objcT49,selTransTbl[1])),(objcT50=(objcT51=self->lbrace,(*_imp(objcT51,selTransTbl[2]))(objcT51,selTransTbl[2])),(*(STR(*)(id,SEL))_imp(objcT50,selTransTbl[24]))(objcT50,selTransTbl[24])));
-gf("idincref(%s);\n",(objcT52=(objcT53=self->increfs,(*(id(*)(id,SEL,unsigned))_imp(objcT53,selTransTbl[8]))(objcT53,selTransTbl[8],i)),(*(STR(*)(id,SEL))_imp(objcT52,selTransTbl[24]))(objcT52,selTransTbl[24])));
+if(self->lbrace)gl((objcT50=self->lbrace,(*(int(*)(id,SEL))_imp(objcT50,selTransTbl[1]))(objcT50,selTransTbl[1])),(objcT51=(objcT52=self->lbrace,(*_imp(objcT52,selTransTbl[2]))(objcT52,selTransTbl[2])),(*(STR(*)(id,SEL))_imp(objcT51,selTransTbl[24]))(objcT51,selTransTbl[24])));
+gf("idincref(%s);\n",(objcT53=(objcT54=self->increfs,(*(id(*)(id,SEL,unsigned))_imp(objcT54,selTransTbl[8]))(objcT54,selTransTbl[8],i)),(*(STR(*)(id,SEL))_imp(objcT53,selTransTbl[24]))(objcT53,selTransTbl[24])));
 }
 gc('\n');
 return(id)self;
@@ -775,32 +785,32 @@ return(id)self;
 
 static id i_CompoundStmt_adddecref_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id v)
 {
-id objcT54,objcT55,objcT56;
+id objcT55,objcT56,objcT57;
 
 # 67 "shared.m"
 if( !self->decrefs)self->
-decrefs=(objcT54=OrdCltn,(*_imp(objcT54,selTransTbl[27]))(objcT54,selTransTbl[27]));
-(objcT55=self->decrefs,(*_imp(objcT55,selTransTbl[28]))(objcT55,selTransTbl[28],v));
+decrefs=(objcT55=OrdCltn,(*_imp(objcT55,selTransTbl[27]))(objcT55,selTransTbl[27]));
+(objcT56=self->decrefs,(*_imp(objcT56,selTransTbl[28]))(objcT56,selTransTbl[28],v));
 
 if(curloopcompound&&(id)self!=curloopcompound)
-(objcT56=curloopcompound,(*_imp(objcT56,selTransTbl[12]))(objcT56,selTransTbl[12],v));
+(objcT57=curloopcompound,(*_imp(objcT57,selTransTbl[12]))(objcT57,selTransTbl[12],v));
 return(id)self;
 }
 
 static id i_CompoundStmt_gendecrefs(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT57;
+id objcT58;
 
 # 78 "shared.m"
-int i,n=(objcT57=self->decrefs,(*(unsigned(*)(id,SEL))_imp(objcT57,selTransTbl[7]))(objcT57,selTransTbl[7]));
+int i,n=(objcT58=self->decrefs,(*(unsigned(*)(id,SEL))_imp(objcT58,selTransTbl[7]))(objcT58,selTransTbl[7]));
 
 for(i=0;i<n;i++){
-id objcT58,objcT59,objcT60,objcT61,objcT62;
+id objcT59,objcT60,objcT61,objcT62,objcT63;
 
 # 81 "shared.m"
-char*s=(objcT58=(objcT59=self->decrefs,(*(id(*)(id,SEL,unsigned))_imp(objcT59,selTransTbl[8]))(objcT59,selTransTbl[8],i)),(*(STR(*)(id,SEL))_imp(objcT58,selTransTbl[24]))(objcT58,selTransTbl[24]));
+char*s=(objcT59=(objcT60=self->decrefs,(*(id(*)(id,SEL,unsigned))_imp(objcT60,selTransTbl[8]))(objcT60,selTransTbl[8],i)),(*(STR(*)(id,SEL))_imp(objcT59,selTransTbl[24]))(objcT59,selTransTbl[24]));
 
-if(self->rbrace)gl((objcT60=self->rbrace,(*(int(*)(id,SEL))_imp(objcT60,selTransTbl[1]))(objcT60,selTransTbl[1])),(objcT61=(objcT62=self->rbrace,(*_imp(objcT62,selTransTbl[2]))(objcT62,selTransTbl[2])),(*(STR(*)(id,SEL))_imp(objcT61,selTransTbl[24]))(objcT61,selTransTbl[24])));
+if(self->rbrace)gl((objcT61=self->rbrace,(*(int(*)(id,SEL))_imp(objcT61,selTransTbl[1]))(objcT61,selTransTbl[1])),(objcT62=(objcT63=self->rbrace,(*_imp(objcT63,selTransTbl[2]))(objcT63,selTransTbl[2])),(*(STR(*)(id,SEL))_imp(objcT62,selTransTbl[24]))(objcT62,selTransTbl[24])));
 gf("%s=iddecref(%s);\n",s,s);
 }
 gc('\n');
@@ -809,10 +819,10 @@ return(id)self;
 
 static id i_CompoundStmt_lookuplocal_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id sym)
 {
-id objcT63;
+id objcT64;
 
 # 92 "shared.m"
-return(self->localdic)?(objcT63=self->localdic,(*_imp(objcT63,selTransTbl[29]))(objcT63,selTransTbl[29],sym)):(id)0;
+return(self->localdic)?(objcT64=self->localdic,(*_imp(objcT64,selTransTbl[29]))(objcT64,selTransTbl[29],sym)):(id)0;
 }
 
 # 32 "../../include/objpak/dictnary.h"
@@ -821,34 +831,34 @@ extern id  Dictionary;
 # 95 "shared.m"
 static id i_CompoundStmt_deflocal_astype_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id sym,id t)
 {
-id objcT66,objcT67,objcT68;
+id objcT67,objcT68,objcT69;
 
 # 97 "shared.m"
 if( !self->localdic){
-id objcT64,objcT65;
+id objcT65,objcT66;
 self->
 # 98 "shared.m"
-localdic=(objcT64=Dictionary,(*_imp(objcT64,selTransTbl[27]))(objcT64,selTransTbl[27]));self->
-locals=(objcT65=OrdCltn,(*_imp(objcT65,selTransTbl[27]))(objcT65,selTransTbl[27]));
+localdic=(objcT65=Dictionary,(*_imp(objcT65,selTransTbl[27]))(objcT65,selTransTbl[27]));self->
+locals=(objcT66=OrdCltn,(*_imp(objcT66,selTransTbl[27]))(objcT66,selTransTbl[27]));
 }
-(objcT66=self->localdic,(*_imp(objcT66,selTransTbl[30]))(objcT66,selTransTbl[30],sym,t));
-(objcT67=self->locals,(*_imp(objcT67,selTransTbl[28]))(objcT67,selTransTbl[28],sym));
-if(curdef&&((objcT68=curdef,(*(BOOL(*)(id,SEL))_imp(objcT68,selTransTbl[31]))(objcT68,selTransTbl[31])))){
-id objcT69,objcT71;
+(objcT67=self->localdic,(*_imp(objcT67,selTransTbl[30]))(objcT67,selTransTbl[30],sym,t));
+(objcT68=self->locals,(*_imp(objcT68,selTransTbl[28]))(objcT68,selTransTbl[28],sym));
+if(curdef&&((objcT69=curdef,(*(BOOL(*)(id,SEL))_imp(objcT69,selTransTbl[31]))(objcT69,selTransTbl[31])))){
+id objcT70,objcT72;
 
 # 104 "shared.m"
 (void)0;
-if((objcT69=curclassdef,(*(BOOL(*)(id,SEL,id))_imp(objcT69,selTransTbl[32]))(objcT69,selTransTbl[32],sym))){
-id objcT70;
+if((objcT70=curclassdef,(*(BOOL(*)(id,SEL,id))_imp(objcT70,selTransTbl[32]))(objcT70,selTransTbl[32],sym))){
+id objcT71;
 
 # 106 "shared.m"
-warnat(sym,"definition of local '%s' hides instance variable",(objcT70=sym,(*(STR(*)(id,SEL))_imp(objcT70,selTransTbl[24]))(objcT70,selTransTbl[24])));
+warnat(sym,"definition of local '%s' hides instance variable",(objcT71=sym,(*(STR(*)(id,SEL))_imp(objcT71,selTransTbl[24]))(objcT71,selTransTbl[24])));
 }
-if((objcT71=curclassdef,(*(BOOL(*)(id,SEL,id))_imp(objcT71,selTransTbl[33]))(objcT71,selTransTbl[33],sym))){
-id objcT72;
+if((objcT72=curclassdef,(*(BOOL(*)(id,SEL,id))_imp(objcT72,selTransTbl[33]))(objcT72,selTransTbl[33],sym))){
+id objcT73;
 
 # 109 "shared.m"
-warnat(sym,"definition of local '%s' hides class variable",(objcT72=sym,(*(STR(*)(id,SEL))_imp(objcT72,selTransTbl[24]))(objcT72,selTransTbl[24])));
+warnat(sym,"definition of local '%s' hides class variable",(objcT73=sym,(*(STR(*)(id,SEL))_imp(objcT73,selTransTbl[24]))(objcT73,selTransTbl[24])));
 }
 }
 return(id)self;
@@ -867,13 +877,13 @@ return(id)self;
 
 static id i_CompoundStmt_freeheapvarptr(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT73;
+id objcT74;
 
 # 128 "shared.m"
 char*p=self->heapvarptrname;
 
 gf("if (%s->heaprefcnt-- == 0) {\n",p);
-if(o_refcnt)(objcT73=(id)self,(*_imp(objcT73,selTransTbl[34]))(objcT73,selTransTbl[34]));
+if(o_refcnt)(objcT74=(id)self,(*_imp(objcT74,selTransTbl[34]))(objcT74,selTransTbl[34]));
 gf("OC_Free(%s);\n",p);
 gs("}\n");
 
@@ -882,25 +892,25 @@ return(id)self;
 
 static id i_CompoundStmt_gendecrefsheapvars(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT74;
+id objcT75;
 
 # 140 "shared.m"
-int i,n=(objcT74=self->heapnames,(*(unsigned(*)(id,SEL))_imp(objcT74,selTransTbl[7]))(objcT74,selTransTbl[7]));
+int i,n=(objcT75=self->heapnames,(*(unsigned(*)(id,SEL))_imp(objcT75,selTransTbl[7]))(objcT75,selTransTbl[7]));
 char*hvp=self->heapvarptrname;
 
 for(i=0;i<n;i++){
-id objcT75,objcT76,objcT77;
+id objcT76,objcT77,objcT78;
 
 # 144 "shared.m"
-id x=(objcT75=self->heapnames,(*(id(*)(id,SEL,unsigned))_imp(objcT75,selTransTbl[8]))(objcT75,selTransTbl[8],i));
-id t=(objcT76=self->heaptypes,(*(id(*)(id,SEL,unsigned))_imp(objcT76,selTransTbl[8]))(objcT76,selTransTbl[8],i));
+id x=(objcT76=self->heapnames,(*(id(*)(id,SEL,unsigned))_imp(objcT76,selTransTbl[8]))(objcT76,selTransTbl[8],i));
+id t=(objcT77=self->heaptypes,(*(id(*)(id,SEL,unsigned))_imp(objcT77,selTransTbl[8]))(objcT77,selTransTbl[8],i));
 
 (void)0;
-if((objcT77=t,(*(BOOL(*)(id,SEL))_imp(objcT77,selTransTbl[10]))(objcT77,selTransTbl[10]))){
-id objcT78;
+if((objcT78=t,(*(BOOL(*)(id,SEL))_imp(objcT78,selTransTbl[10]))(objcT78,selTransTbl[10]))){
+id objcT79;
 
 # 149 "shared.m"
-char*s=(objcT78=x,(*(STR(*)(id,SEL))_imp(objcT78,selTransTbl[24]))(objcT78,selTransTbl[24]));
+char*s=(objcT79=x,(*(STR(*)(id,SEL))_imp(objcT79,selTransTbl[24]))(objcT79,selTransTbl[24]));
 gf("%s->%s=iddecref(%s->%s);\n",hvp,s,hvp,s);
 }
 }
@@ -909,24 +919,24 @@ return(id)self;
 
 static id i_CompoundStmt_genheapvartype(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT79;
+id objcT80;
 
 # 158 "shared.m"
-int i,n=(objcT79=self->heapnames,(*(unsigned(*)(id,SEL))_imp(objcT79,selTransTbl[7]))(objcT79,selTransTbl[7]));
+int i,n=(objcT80=self->heapnames,(*(unsigned(*)(id,SEL))_imp(objcT80,selTransTbl[7]))(objcT80,selTransTbl[7]));
 
 if( !n)
 return(id)self;
 gf("%s {\n",self->heapvartypename);
 gs("int heaprefcnt;\n");
 for(i=0;i<n;i++){
-id objcT80,objcT81,objcT82;
+id objcT81,objcT82,objcT83;
 
 # 165 "shared.m"
-id x=(objcT80=self->heapnames,(*(id(*)(id,SEL,unsigned))_imp(objcT80,selTransTbl[8]))(objcT80,selTransTbl[8],i));
-id t=(objcT81=self->heaptypes,(*(id(*)(id,SEL,unsigned))_imp(objcT81,selTransTbl[8]))(objcT81,selTransTbl[8],i));
+id x=(objcT81=self->heapnames,(*(id(*)(id,SEL,unsigned))_imp(objcT81,selTransTbl[8]))(objcT81,selTransTbl[8],i));
+id t=(objcT82=self->heaptypes,(*(id(*)(id,SEL,unsigned))_imp(objcT82,selTransTbl[8]))(objcT82,selTransTbl[8],i));
 
 (void)0;
-(objcT82=t,(*_imp(objcT82,selTransTbl[19]))(objcT82,selTransTbl[19],x));
+(objcT83=t,(*_imp(objcT83,selTransTbl[19]))(objcT83,selTransTbl[19],x));
 gs(";\n");
 }
 gs("};\n");
@@ -940,10 +950,10 @@ return(id)0;
 
 static BOOL i_CompoundStmt_isheapvar_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id x)
 {
-id objcT83;
+id objcT84;
 
 # 183 "shared.m"
-return(self->heapvars)?(objcT83=self->heapvars,(*(BOOL(*)(id,SEL,id))_imp(objcT83,selTransTbl[35]))(objcT83,selTransTbl[35],x)):(BOOL)0;
+return(self->heapvars)?(objcT84=self->heapvars,(*(BOOL(*)(id,SEL,id))_imp(objcT84,selTransTbl[35]))(objcT84,selTransTbl[35],x)):(BOOL)0;
 }
 
 # 36 "../../include/objpak/set.h"
@@ -955,40 +965,40 @@ extern id  String;
 # 186 "shared.m"
 static id i_CompoundStmt_defheapvar_type_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id x,id t)
 {
-id objcT92;
+id objcT93;
 
 # 188 "shared.m"
 int i;
 
 if( !self->heapvars){
-id objcT84,objcT85,objcT86,objcT87,objcT88;
-id objcT89,objcT90,objcT91;
+id objcT85,objcT86,objcT87,objcT88,objcT89;
+id objcT90,objcT91,objcT92;
 self->
 # 191 "shared.m"
-heapvars=(objcT84=Set,(*_imp(objcT84,selTransTbl[27]))(objcT84,selTransTbl[27]));self->
-heapnames=(objcT85=OrdCltn,(*_imp(objcT85,selTransTbl[27]))(objcT85,selTransTbl[27]));self->
-heaptypes=(objcT86=OrdCltn,(*_imp(objcT86,selTransTbl[27]))(objcT86,selTransTbl[27]));
-i=(objcT87=trlunit,(*(int(*)(id,SEL))_imp(objcT87,selTransTbl[36]))(objcT87,selTransTbl[36]));self->
-heapvarptrname=(objcT88=(objcT89=String,(*(id(*)(id,SEL,STR,...))_imp(objcT89,selTransTbl[37]))(objcT89,selTransTbl[37],"heapvars%i",i)),(*(STR(*)(id,SEL))_imp(objcT88,selTransTbl[38]))(objcT88,selTransTbl[38]));self->
-heapvartypename=(objcT90=(objcT91=String,(*(id(*)(id,SEL,STR,...))_imp(objcT91,selTransTbl[37]))(objcT91,selTransTbl[37],"struct heaptype%i",i)),(*(STR(*)(id,SEL))_imp(objcT90,selTransTbl[38]))(objcT90,selTransTbl[38]));
+heapvars=(objcT85=Set,(*_imp(objcT85,selTransTbl[27]))(objcT85,selTransTbl[27]));self->
+heapnames=(objcT86=OrdCltn,(*_imp(objcT86,selTransTbl[27]))(objcT86,selTransTbl[27]));self->
+heaptypes=(objcT87=OrdCltn,(*_imp(objcT87,selTransTbl[27]))(objcT87,selTransTbl[27]));
+i=(objcT88=trlunit,(*(int(*)(id,SEL))_imp(objcT88,selTransTbl[36]))(objcT88,selTransTbl[36]));self->
+heapvarptrname=(objcT89=(objcT90=String,(*(id(*)(id,SEL,STR,...))_imp(objcT90,selTransTbl[37]))(objcT90,selTransTbl[37],"heapvars%i",i)),(*(STR(*)(id,SEL))_imp(objcT89,selTransTbl[38]))(objcT89,selTransTbl[38]));self->
+heapvartypename=(objcT91=(objcT92=String,(*(id(*)(id,SEL,STR,...))_imp(objcT92,selTransTbl[37]))(objcT92,selTransTbl[37],"struct heaptype%i",i)),(*(STR(*)(id,SEL))_imp(objcT91,selTransTbl[38]))(objcT91,selTransTbl[38]));
 }
-if((objcT92=t,(*(BOOL(*)(id,SEL))_imp(objcT92,selTransTbl[39]))(objcT92,selTransTbl[39]))){
-id objcT93;
+if((objcT93=t,(*(BOOL(*)(id,SEL))_imp(objcT93,selTransTbl[39]))(objcT93,selTransTbl[39]))){
+id objcT94;
 
 # 199 "shared.m"
 char*msg="can't use static local variables (%s) from within block";
 
-fatalat(x,msg,(objcT93=x,(*(STR(*)(id,SEL))_imp(objcT93,selTransTbl[24]))(objcT93,selTransTbl[24])));
+fatalat(x,msg,(objcT94=x,(*(STR(*)(id,SEL))_imp(objcT94,selTransTbl[24]))(objcT94,selTransTbl[24])));
 }else{
-id objcT94;
+id objcT95;
 
 # 203 "shared.m"
-if((objcT94=self->heapvars,(*_imp(objcT94,selTransTbl[40]))(objcT94,selTransTbl[40],x))!=(id)0){
-id objcT95,objcT96;
+if((objcT95=self->heapvars,(*_imp(objcT95,selTransTbl[40]))(objcT95,selTransTbl[40],x))!=(id)0){
+id objcT96,objcT97;
 
 # 204 "shared.m"
-(objcT95=self->heapnames,(*_imp(objcT95,selTransTbl[28]))(objcT95,selTransTbl[28],x));
-(objcT96=self->heaptypes,(*_imp(objcT96,selTransTbl[28]))(objcT96,selTransTbl[28],t));
+(objcT96=self->heapnames,(*_imp(objcT96,selTransTbl[28]))(objcT96,selTransTbl[28],x));
+(objcT97=self->heaptypes,(*_imp(objcT97,selTransTbl[28]))(objcT97,selTransTbl[28],t));
 }
 }
 return(id)self;
@@ -1008,85 +1018,85 @@ return self->heapvartypename;
 
 static id i_CompoundStmt_removeheapvarsfromdatadefs(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT97,objcT109;
+id objcT98,objcT110;
 
 # 225 "shared.m"
 int n;
 
 (void)0;self->
-initializers=(objcT97=OrdCltn,(*_imp(objcT97,selTransTbl[27]))(objcT97,selTransTbl[27]));
+initializers=(objcT98=OrdCltn,(*_imp(objcT98,selTransTbl[27]))(objcT98,selTransTbl[27]));
 
 if(self->parmnames){
-id objcT98;
+id objcT99;
 
 # 231 "shared.m"
-n=(objcT98=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT98,selTransTbl[7]))(objcT98,selTransTbl[7]));
+n=(objcT99=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT99,selTransTbl[7]))(objcT99,selTransTbl[7]));
 while(n--){
-id objcT99,objcT100;
+id objcT100,objcT101;
 
 # 233 "shared.m"
-id p=(objcT99=self->parmnames,(*(id(*)(id,SEL,unsigned))_imp(objcT99,selTransTbl[8]))(objcT99,selTransTbl[8],n));
+id p=(objcT100=self->parmnames,(*(id(*)(id,SEL,unsigned))_imp(objcT100,selTransTbl[8]))(objcT100,selTransTbl[8],n));
 
-if((objcT100=self->heapvars,(*(BOOL(*)(id,SEL,id))_imp(objcT100,selTransTbl[35]))(objcT100,selTransTbl[35],p))){
-id objcT101,objcT102,objcT103;
+if((objcT101=self->heapvars,(*(BOOL(*)(id,SEL,id))_imp(objcT101,selTransTbl[35]))(objcT101,selTransTbl[35],p))){
+id objcT102,objcT103,objcT104;
 
 # 236 "shared.m"
-id x=(objcT101=(objcT102=mkidentexpr(p),(*(id(*)(id,SEL,BOOL))_imp(objcT102,selTransTbl[41]))(objcT102,selTransTbl[41],(BOOL)1)),(*_imp(objcT101,selTransTbl[42]))(objcT101,selTransTbl[42]));
+id x=(objcT102=(objcT103=mkidentexpr(p),(*(id(*)(id,SEL,BOOL))_imp(objcT103,selTransTbl[41]))(objcT103,selTransTbl[41],(BOOL)1)),(*_imp(objcT102,selTransTbl[42]))(objcT102,selTransTbl[42]));
 id y=mkidentexpr(p);
 
-(objcT103=self->initializers,(*_imp(objcT103,selTransTbl[28]))(objcT103,selTransTbl[28],mkexprstmt(mkassignexpr(x,"=",y))));
+(objcT104=self->initializers,(*_imp(objcT104,selTransTbl[28]))(objcT104,selTransTbl[28],mkexprstmt(mkassignexpr(x,"=",y))));
 }
 }
 }
 if(self->datadefs){
-id objcT104;
+id objcT105;
 
 # 244 "shared.m"
-n=(objcT104=self->datadefs,(*(unsigned(*)(id,SEL))_imp(objcT104,selTransTbl[7]))(objcT104,selTransTbl[7]));
+n=(objcT105=self->datadefs,(*(unsigned(*)(id,SEL))_imp(objcT105,selTransTbl[7]))(objcT105,selTransTbl[7]));
 while(n--){
-id objcT105,objcT106,objcT107,objcT108;
+id objcT106,objcT107,objcT108,objcT109;
 
 # 246 "shared.m"
-id def=(objcT105=self->datadefs,(*(id(*)(id,SEL,unsigned))_imp(objcT105,selTransTbl[8]))(objcT105,selTransTbl[8],n));
+id def=(objcT106=self->datadefs,(*(id(*)(id,SEL,unsigned))_imp(objcT106,selTransTbl[8]))(objcT106,selTransTbl[8],n));
 
-(objcT106=def,(*_imp(objcT106,selTransTbl[43]))(objcT106,selTransTbl[43],self->heapvars,self->initializers));
-if((objcT107=def,(*_imp(objcT107,selTransTbl[44]))(objcT107,selTransTbl[44]))==(id)0)
-(objcT108=self->datadefs,(*(id(*)(id,SEL,unsigned))_imp(objcT108,selTransTbl[45]))(objcT108,selTransTbl[45],n));
+(objcT107=def,(*_imp(objcT107,selTransTbl[43]))(objcT107,selTransTbl[43],self->heapvars,self->initializers));
+if((objcT108=def,(*_imp(objcT108,selTransTbl[44]))(objcT108,selTransTbl[44]))==(id)0)
+(objcT109=self->datadefs,(*(id(*)(id,SEL,unsigned))_imp(objcT109,selTransTbl[45]))(objcT109,selTransTbl[45],n));
 }
 }
-if((objcT109=self->datadefs,(*(unsigned(*)(id,SEL))_imp(objcT109,selTransTbl[7]))(objcT109,selTransTbl[7]))==0)self->
+if((objcT110=self->datadefs,(*(unsigned(*)(id,SEL))_imp(objcT110,selTransTbl[7]))(objcT110,selTransTbl[7]))==0)self->
 datadefs=(id)0;
 return(id)self;
 }
 
 static id i_CompoundStmt_fcall_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id x)
 {
-id objcT110,objcT111;
+id objcT111,objcT112;
 
 # 260 "shared.m"
-if((objcT110=x,(*(unsigned(*)(id,SEL))_imp(objcT110,selTransTbl[7]))(objcT110,selTransTbl[7]))<(objcT111=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT111,selTransTbl[7]))(objcT111,selTransTbl[7]))){
-id objcT112;
+if((objcT111=x,(*(unsigned(*)(id,SEL))_imp(objcT111,selTransTbl[7]))(objcT111,selTransTbl[7]))<(objcT112=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT112,selTransTbl[7]))(objcT112,selTransTbl[7]))){
+id objcT113;
 
 # 261 "shared.m"
-return(objcT112=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT112,selTransTbl[46]))(objcT112,selTransTbl[46],"Arguments expected"));
+return(objcT113=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT113,selTransTbl[46]))(objcT113,selTransTbl[46],"Arguments expected"));
 }else{
-id objcT113,objcT117,objcT118;
+id objcT114,objcT118,objcT119;
 
 # 263 "shared.m"
 int i,n;
 (void)0;
-for(i=0,n=(objcT113=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT113,selTransTbl[7]))(objcT113,selTransTbl[7]));i<n;i++){
-id objcT114,objcT115,objcT116;
+for(i=0,n=(objcT114=self->parmnames,(*(unsigned(*)(id,SEL))_imp(objcT114,selTransTbl[7]))(objcT114,selTransTbl[7]));i<n;i++){
+id objcT115,objcT116,objcT117;
 
 # 266 "shared.m"
-(objcT114=topframe,(*_imp(objcT114,selTransTbl[47]))(objcT114,selTransTbl[47],(objcT115=self->parmnames,(*(id(*)(id,SEL,unsigned))_imp(objcT115,selTransTbl[8]))(objcT115,selTransTbl[8],i)),(objcT116=x,(*(id(*)(id,SEL,unsigned))_imp(objcT116,selTransTbl[8]))(objcT116,selTransTbl[8],i))));
+(objcT115=topframe,(*_imp(objcT115,selTransTbl[47]))(objcT115,selTransTbl[47],(objcT116=self->parmnames,(*(id(*)(id,SEL,unsigned))_imp(objcT116,selTransTbl[8]))(objcT116,selTransTbl[8],i)),(objcT117=x,(*(id(*)(id,SEL,unsigned))_imp(objcT117,selTransTbl[8]))(objcT117,selTransTbl[8],i))));
 }
-(objcT117=(id)self,(*_imp(objcT117,selTransTbl[48]))(objcT117,selTransTbl[48]));
-if((objcT118=topframe,(*(BOOL(*)(id,SEL))_imp(objcT118,selTransTbl[49]))(objcT118,selTransTbl[49]))){
-id objcT119;
+(objcT118=(id)self,(*_imp(objcT118,selTransTbl[48]))(objcT118,selTransTbl[48]));
+if((objcT119=topframe,(*(BOOL(*)(id,SEL))_imp(objcT119,selTransTbl[49]))(objcT119,selTransTbl[49]))){
+id objcT120;
 
 # 270 "shared.m"
-return(objcT119=topframe,(*_imp(objcT119,selTransTbl[50]))(objcT119,selTransTbl[50]));
+return(objcT120=topframe,(*_imp(objcT120,selTransTbl[50]))(objcT120,selTransTbl[50]));
 }else{
 return(id)0;
 }
@@ -1099,90 +1109,90 @@ extern id  Stackframe;
 # 277 "shared.m"
 static id i_CompoundStmt_switchOn__(struct CompoundStmt_PRIVATE *self,SEL _cmd,BOOL dosw,id e)
 {
-id objcT120,objcT121,objcT122,objcT123,objcT131;
-id objcT135,objcT136;
+id objcT121,objcT122,objcT123,objcT124,objcT132;
+id objcT136,objcT137;
 
 # 279 "shared.m"
 int i,n;
 BOOL quit=(BOOL)0;
 BOOL dobrk=(BOOL)0;
 BOOL docont=(BOOL)0;
-id frame=(objcT120=(objcT121=Stackframe,(*_imp(objcT121,selTransTbl[51]))(objcT121,selTransTbl[51])),(*_imp(objcT120,selTransTbl[52]))(objcT120,selTransTbl[52],(id)self));
-if(self->datadefs)(objcT122=self->datadefs,(*(id(*)(id,SEL,SEL))_imp(objcT122,selTransTbl[13]))(objcT122,selTransTbl[13],selTransTbl[48]));
+id frame=(objcT121=(objcT122=Stackframe,(*_imp(objcT122,selTransTbl[51]))(objcT122,selTransTbl[51])),(*_imp(objcT121,selTransTbl[52]))(objcT121,selTransTbl[52],(id)self));
+if(self->datadefs)(objcT123=self->datadefs,(*(id(*)(id,SEL,SEL))_imp(objcT123,selTransTbl[13]))(objcT123,selTransTbl[13],selTransTbl[48]));
 i=0;
-n=(objcT123=self->stmts,(*(unsigned(*)(id,SEL))_imp(objcT123,selTransTbl[7]))(objcT123,selTransTbl[7]));
+n=(objcT124=self->stmts,(*(unsigned(*)(id,SEL))_imp(objcT124,selTransTbl[7]))(objcT124,selTransTbl[7]));
 if(dosw)for(;i<n;i++){
-id objcT124,objcT125;
+id objcT125,objcT126;
 
 # 288 "shared.m"
-if((objcT124=(objcT125=self->stmts,(*(id(*)(id,SEL,unsigned))_imp(objcT125,selTransTbl[8]))(objcT125,selTransTbl[8],i)),(*(BOOL(*)(id,SEL,id))_imp(objcT124,selTransTbl[53]))(objcT124,selTransTbl[53],e)))break;
+if((objcT125=(objcT126=self->stmts,(*(id(*)(id,SEL,unsigned))_imp(objcT126,selTransTbl[8]))(objcT126,selTransTbl[8],i)),(*(BOOL(*)(id,SEL,id))_imp(objcT125,selTransTbl[53]))(objcT125,selTransTbl[53],e)))break;
 }
 for(;i<n;i++){
-id objcT126,objcT127,objcT128,objcT129,objcT130;
+id objcT127,objcT128,objcT129,objcT130,objcT131;
 
 # 291 "shared.m"
-(objcT126=(objcT127=self->stmts,(*(id(*)(id,SEL,unsigned))_imp(objcT127,selTransTbl[8]))(objcT127,selTransTbl[8],i)),(*_imp(objcT126,selTransTbl[48]))(objcT126,selTransTbl[48]));
-if((quit=(objcT128=frame,(*(BOOL(*)(id,SEL))_imp(objcT128,selTransTbl[49]))(objcT128,selTransTbl[49]))))break;
-if((docont=(objcT129=frame,(*(BOOL(*)(id,SEL))_imp(objcT129,selTransTbl[54]))(objcT129,selTransTbl[54]))))break;
-if((dobrk=(objcT130=frame,(*(BOOL(*)(id,SEL))_imp(objcT130,selTransTbl[55]))(objcT130,selTransTbl[55]))))break;
+(objcT127=(objcT128=self->stmts,(*(id(*)(id,SEL,unsigned))_imp(objcT128,selTransTbl[8]))(objcT128,selTransTbl[8],i)),(*_imp(objcT127,selTransTbl[48]))(objcT127,selTransTbl[48]));
+if((quit=(objcT129=frame,(*(BOOL(*)(id,SEL))_imp(objcT129,selTransTbl[49]))(objcT129,selTransTbl[49]))))break;
+if((docont=(objcT130=frame,(*(BOOL(*)(id,SEL))_imp(objcT130,selTransTbl[54]))(objcT130,selTransTbl[54]))))break;
+if((dobrk=(objcT131=frame,(*(BOOL(*)(id,SEL))_imp(objcT131,selTransTbl[55]))(objcT131,selTransTbl[55]))))break;
 }
-(objcT131=Stackframe,(*_imp(objcT131,selTransTbl[56]))(objcT131,selTransTbl[56]));
+(objcT132=Stackframe,(*_imp(objcT132,selTransTbl[56]))(objcT132,selTransTbl[56]));
 if(quit){
-id objcT132,objcT133,objcT134;
+id objcT133,objcT134,objcT135;
 
 # 298 "shared.m"
-(objcT132=topframe,(*(id(*)(id,SEL,BOOL))_imp(objcT132,selTransTbl[57]))(objcT132,selTransTbl[57],(BOOL)1));
-(objcT133=topframe,(*_imp(objcT133,selTransTbl[58]))(objcT133,selTransTbl[58],(objcT134=frame,(*_imp(objcT134,selTransTbl[50]))(objcT134,selTransTbl[50]))));
+(objcT133=topframe,(*(id(*)(id,SEL,BOOL))_imp(objcT133,selTransTbl[57]))(objcT133,selTransTbl[57],(BOOL)1));
+(objcT134=topframe,(*_imp(objcT134,selTransTbl[58]))(objcT134,selTransTbl[58],(objcT135=frame,(*_imp(objcT135,selTransTbl[50]))(objcT135,selTransTbl[50]))));
 }
-if(docont)(objcT135=topframe,(*(id(*)(id,SEL,BOOL))_imp(objcT135,selTransTbl[59]))(objcT135,selTransTbl[59],(BOOL)1));
-if(dobrk)(objcT136=topframe,(*(id(*)(id,SEL,BOOL))_imp(objcT136,selTransTbl[60]))(objcT136,selTransTbl[60],(BOOL)1));
+if(docont)(objcT136=topframe,(*(id(*)(id,SEL,BOOL))_imp(objcT136,selTransTbl[59]))(objcT136,selTransTbl[59],(BOOL)1));
+if(dobrk)(objcT137=topframe,(*(id(*)(id,SEL,BOOL))_imp(objcT137,selTransTbl[60]))(objcT137,selTransTbl[60],(BOOL)1));
 return(id)self;
 }
 
 static id i_CompoundStmt_switchOn_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id e)
 {
-id objcT137;
+id objcT138;
 
 # 308 "shared.m"
-return(objcT137=(id)self,(*(id(*)(id,SEL,BOOL,id))_imp(objcT137,selTransTbl[61]))(objcT137,selTransTbl[61],(BOOL)1,e));
+return(objcT138=(id)self,(*(id(*)(id,SEL,BOOL,id))_imp(objcT138,selTransTbl[61]))(objcT138,selTransTbl[61],(BOOL)1,e));
 }
 
 static id i_CompoundStmt_go(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT138;
+id objcT139;
 
 # 313 "shared.m"
-return(objcT138=(id)self,(*(id(*)(id,SEL,BOOL,id))_imp(objcT138,selTransTbl[61]))(objcT138,selTransTbl[61],(BOOL)0,(id)0));
+return(objcT139=(id)self,(*(id(*)(id,SEL,BOOL,id))_imp(objcT139,selTransTbl[61]))(objcT139,selTransTbl[61],(BOOL)0,(id)0));
 }
 
-# 275 "compstmt.m"
+# 283 "compstmt.m"
 static id i_CompoundStmt_addheapvarblock_(struct CompoundStmt_PRIVATE *self,SEL _cmd,id c)
 {
 if(c==(id)self){
 return(id)self;
 }else{
-id objcT139;
+id objcT140;
 
-# 280 "compstmt.m"
+# 288 "compstmt.m"
 if(self->enclosing)
-(objcT139=self->enclosing,(*_imp(objcT139,selTransTbl[62]))(objcT139,selTransTbl[62],c));
+(objcT140=self->enclosing,(*_imp(objcT140,selTransTbl[62]))(objcT140,selTransTbl[62],c));
 return(id)self;
 }
 }
 
 static id i_CompoundStmt_st80(struct CompoundStmt_PRIVATE *self,SEL _cmd)
 {
-id objcT140,objcT141,objcT142;
+id objcT141,objcT142,objcT143;
 
-# 288 "compstmt.m"
+# 296 "compstmt.m"
 gc('|');
 if(self->datadefs)
-(objcT140=self->datadefs,(*(id(*)(id,SEL,SEL))_imp(objcT140,selTransTbl[13]))(objcT140,selTransTbl[13],_cmd));
+(objcT141=self->datadefs,(*(id(*)(id,SEL,SEL))_imp(objcT141,selTransTbl[13]))(objcT141,selTransTbl[13],_cmd));
 gc('|');
 gc('\n');
 if(self->datadefs)
-(objcT141=self->datadefs,(*(id(*)(id,SEL,SEL))_imp(objcT141,selTransTbl[13]))(objcT141,selTransTbl[13],selTransTbl[63]));
-(objcT142=self->stmts,(*(id(*)(id,SEL,SEL))_imp(objcT142,selTransTbl[13]))(objcT142,selTransTbl[13],_cmd));
+(objcT142=self->datadefs,(*(id(*)(id,SEL,SEL))_imp(objcT142,selTransTbl[13]))(objcT142,selTransTbl[13],selTransTbl[63]));
+(objcT143=self->stmts,(*(id(*)(id,SEL,SEL))_imp(objcT143,selTransTbl[13]))(objcT143,selTransTbl[13],_cmd));
 return(id)self;
 }
 extern id  Object;
@@ -1206,6 +1216,7 @@ static struct _SLT _CompoundStmt_nstDispatchTbl[] ={
 {"rbrace:",(id (*)())i_CompoundStmt_rbrace_},
 {"datadefs:",(id (*)())i_CompoundStmt_datadefs_},
 {"stmts:",(id (*)())i_CompoundStmt_stmts_},
+{"subblock:",(id (*)())i_CompoundStmt_subblock_},
 {"nextreturnlabel",(id (*)())i_CompoundStmt_nextreturnlabel},
 {"returnlabel",(id (*)())i_CompoundStmt_returnlabel},
 {"lookupparm:",(id (*)())i_CompoundStmt_lookupparm_},
@@ -1246,7 +1257,7 @@ struct _SHARED  _CompoundStmt = {
   "CompoundStmt",
   0,
   sizeof(struct CompoundStmt_PRIVATE),
-  41,
+  42,
   _CompoundStmt_nstDispatchTbl,
   41,
   &compstmt_modDesc,
@@ -1341,7 +1352,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor compstmt_modDesc = {
   "compstmt",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
