@@ -185,7 +185,7 @@ id mkbitfielddecl(id decl,id expr);
 id mkstardecl(id pointer,id decl);
 id mkasmop(id string,id expr);
 id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
-id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
+id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
 id mklist(id c,id s);
 id mklist2(id c,id s,id t);
 id atdefsaddall(id c,id n);
@@ -231,6 +231,7 @@ void defoptions(void);
 
 extern int o_warnings;
 extern int o_gnu;
+extern int o_hpux;
 extern int o_vms;
 extern int o_refcnt;
 extern int o_ppi;
@@ -318,7 +319,7 @@ self->
 # 40 "dfltstmt.m"
 stmt=aStmt;
 if(o_refcnt&& !(objcT0=self->stmt,(*(BOOL(*)(id,SEL))_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0]))){self->
-stmt=mkcompstmt((id)0,(id)0,mklist((id)0,self->stmt),(id)0);
+stmt=mkcompstmt((id)0,(id)0,mklist((id)0,self->stmt),(id)0,(id)0);
 }
 return(id)self;
 }
@@ -422,7 +423,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor dfltstmt_modDesc = {
   "dfltstmt",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
