@@ -137,13 +137,13 @@ extern struct _SHARED __Dictionary;
 # 36 "set.h"
 extern id  Set;
 
-# 41 "dictnary.m"
+# 42 "dictnary.m"
 static void
 setUp(id*associations)
 {
 id objcT0;
  *
-# 44 "dictnary.m"
+# 45 "dictnary.m"
 associations=(objcT0=Set,(*_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0]));
 }
 
@@ -151,7 +151,7 @@ static id c_Dictionary_new(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT1,objcT2;
 
-# 49 "dictnary.m"
+# 50 "dictnary.m"
 id newObject=(objcT1=__Dictionary.clsSuper,(*_impSuper(objcT1,selTransTbl[0]))((id)self,selTransTbl[0]));
 setUp((objcT2=newObject,(*(id*(*)(id,SEL))_imp(objcT2,selTransTbl[1]))(objcT2,selTransTbl[1])));
 return newObject;
@@ -161,7 +161,7 @@ static id i_Dictionary_copyAssociations(struct Dictionary_PRIVATE *self,SEL _cmd
 {
 id objcT3;
 self->
-# 56 "dictnary.m"
+# 57 "dictnary.m"
 associations=(objcT3=self->associations,(*_imp(objcT3,selTransTbl[2]))(objcT3,selTransTbl[2]));
 return(id)self;
 }
@@ -170,7 +170,7 @@ static id i_Dictionary_copy(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT4,objcT5;
 
-# 62 "dictnary.m"
+# 63 "dictnary.m"
 return(objcT4=(objcT5=_Dictionary.clsSuper,(*_impSuper(objcT5,selTransTbl[2]))((id)self,selTransTbl[2])),(*_imp(objcT4,selTransTbl[3]))(objcT4,selTransTbl[3]));
 }
 
@@ -178,7 +178,7 @@ static id i_Dictionary_deepCopyAssociations(struct Dictionary_PRIVATE *self,SEL
 {
 id objcT6;
 self->
-# 67 "dictnary.m"
+# 68 "dictnary.m"
 associations=(objcT6=self->associations,(*_imp(objcT6,selTransTbl[4]))(objcT6,selTransTbl[4]));
 return(id)self;
 }
@@ -195,7 +195,7 @@ static id i_Dictionary_emptyYourself(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT9;
 
-# 81 "dictnary.m"
+# 82 "dictnary.m"
 (objcT9=self->associations,(*_imp(objcT9,selTransTbl[6]))(objcT9,selTransTbl[6]));
 return(id)self;
 }
@@ -204,7 +204,7 @@ static id i_Dictionary_freeContents(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT10;
 
-# 87 "dictnary.m"
+# 88 "dictnary.m"
 (objcT10=self->associations,(*_imp(objcT10,selTransTbl[6]))(objcT10,selTransTbl[6]));
 return(id)self;
 }
@@ -213,7 +213,7 @@ static id i_Dictionary_freeAll(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT11;
 
-# 93 "dictnary.m"
+# 94 "dictnary.m"
 (objcT11=self->associations,(*_imp(objcT11,selTransTbl[7]))(objcT11,selTransTbl[7]));
 return(id)self;
 }
@@ -222,7 +222,7 @@ static id i_Dictionary_free(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT12,objcT13;
 self->
-# 99 "dictnary.m"
+# 100 "dictnary.m"
 associations=(objcT12=self->associations,(*_imp(objcT12,selTransTbl[8]))(objcT12,selTransTbl[8]));
 return(objcT13=_Dictionary.clsSuper,(*_impSuper(objcT13,selTransTbl[8]))((id)self,selTransTbl[8]));
 }
@@ -237,7 +237,7 @@ return(objcT14=(id)self,(*(id(*)(id,SEL,SEL))_imp(objcT14,selTransTbl[9]))(objcT
 
 }
 
-# 120 "dictnary.m"
+# 121 "dictnary.m"
 static id i_Dictionary_associations(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 return self->associations;
@@ -252,7 +252,7 @@ static unsigned i_Dictionary_size(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT15;
 
-# 132 "dictnary.m"
+# 133 "dictnary.m"
 return(objcT15=self->associations,(*(unsigned(*)(id,SEL))_imp(objcT15,selTransTbl[10]))(objcT15,selTransTbl[10]));
 }
 
@@ -260,7 +260,7 @@ static BOOL i_Dictionary_isEmpty(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT16;
 
-# 137 "dictnary.m"
+# 138 "dictnary.m"
 return(objcT16=self->associations,(*(BOOL(*)(id,SEL))_imp(objcT16,selTransTbl[11]))(objcT16,selTransTbl[11]));
 }
 
@@ -268,16 +268,16 @@ static BOOL i_Dictionary_includesKey_(struct Dictionary_PRIVATE *self,SEL _cmd,i
 {
 id objcT17;
 
-# 142 "dictnary.m"
+# 143 "dictnary.m"
 return(BOOL)((objcT17=(id)self,(*_imp(objcT17,selTransTbl[12]))(objcT17,selTransTbl[12],aKey))!=(id)0);
 }
 
-# 152 "dictnary.m"
+# 153 "dictnary.m"
 static unsigned i_Dictionary_hash(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
 id objcT18;
 
-# 154 "dictnary.m"
+# 155 "dictnary.m"
 return(objcT18=self->associations,(*(unsigned(*)(id,SEL))_imp(objcT18,selTransTbl[13]))(objcT18,selTransTbl[13]));
 }
 
@@ -285,75 +285,67 @@ static BOOL i_Dictionary_isEqual_(struct Dictionary_PRIVATE *self,SEL _cmd,id aD
 {
 id objcT19,objcT20;
 
-# 159 "dictnary.m"
+# 160 "dictnary.m"
 if((id)self==aDic)
 return(BOOL)1;
 return(objcT19=self->associations,(*(BOOL(*)(id,SEL,id))_imp(objcT19,selTransTbl[14]))(objcT19,selTransTbl[14],(objcT20=aDic,(*_imp(objcT20,selTransTbl[15]))(objcT20,selTransTbl[15]))));
 }
 
-# 171 "dictnary.m"
-static id i_Dictionary_errorKeyNotFound(struct Dictionary_PRIVATE *self,SEL _cmd)
-{
-id objcT21;
-
-# 173 "dictnary.m"
-return(objcT21=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT21,selTransTbl[16]))(objcT21,selTransTbl[16],"key not found"));
-}
-
+# 172 "dictnary.m"
 static id i_Dictionary_associationAt_(struct Dictionary_PRIVATE *self,SEL _cmd,id aKey)
 {
-id objcT22;
-return(objcT22=self->associations,(*_imp(objcT22,selTransTbl[17]))(objcT22,selTransTbl[17],aKey));
+id objcT21;
+return(objcT21=self->associations,(*_imp(objcT21,selTransTbl[16]))(objcT21,selTransTbl[16],aKey));
 }
 
 static id i_Dictionary_atKey_(struct Dictionary_PRIVATE *self,SEL _cmd,id aKey)
 {
-id objcT23,objcT24;
+id objcT22,objcT23;
 
-# 184 "dictnary.m"
-id association=(objcT23=(id)self,(*_imp(objcT23,selTransTbl[12]))(objcT23,selTransTbl[12],aKey));
-return(association)?(objcT24=association,(*_imp(objcT24,selTransTbl[18]))(objcT24,selTransTbl[18])):(id)0;
+# 180 "dictnary.m"
+id association=(objcT22=(id)self,(*_imp(objcT22,selTransTbl[12]))(objcT22,selTransTbl[12],aKey));
+return(association)?(objcT23=association,(*_imp(objcT23,selTransTbl[17]))(objcT23,selTransTbl[17])):(id)0;
 }
 
 static id i_Dictionary_atKey_ifAbsent_(struct Dictionary_PRIVATE *self,SEL _cmd,id aKey,id exceptionBlock)
 {
-id objcT25,objcT26,objcT27;
+id objcT24,objcT25,objcT26;
 
-# 190 "dictnary.m"
-id association=(objcT25=(id)self,(*_imp(objcT25,selTransTbl[12]))(objcT25,selTransTbl[12],aKey));
-return(association)?(objcT26=association,(*_imp(objcT26,selTransTbl[18]))(objcT26,selTransTbl[18])):(objcT27=exceptionBlock,(*_imp(objcT27,selTransTbl[18]))(objcT27,selTransTbl[18]));
+# 186 "dictnary.m"
+id association=(objcT24=(id)self,(*_imp(objcT24,selTransTbl[12]))(objcT24,selTransTbl[12],aKey));
+return(association)?(objcT25=association,(*_imp(objcT25,selTransTbl[17]))(objcT25,selTransTbl[17])):(objcT26=exceptionBlock,(*_imp(objcT26,selTransTbl[17]))(objcT26,selTransTbl[17]));
 }
 
 # 40 "ocstring.h"
 extern id  String;
 
-# 194 "dictnary.m"
+# 190 "dictnary.m"
 static id i_Dictionary_atKeySTR_(struct Dictionary_PRIVATE *self,SEL _cmd,STR strKey)
 {
-id objcT28,objcT29;
+id objcT27,objcT28;
 
-# 196 "dictnary.m"
-return(objcT28=(id)self,(*_imp(objcT28,selTransTbl[19]))(objcT28,selTransTbl[19],(objcT29=String,(*(id(*)(id,SEL,STR))_imp(objcT29,selTransTbl[20]))(objcT29,selTransTbl[20],strKey))));
+# 192 "dictnary.m"
+return(objcT27=(id)self,(*_imp(objcT27,selTransTbl[18]))(objcT27,selTransTbl[18],(objcT28=String,(*(id(*)(id,SEL,STR))_imp(objcT28,selTransTbl[19]))(objcT28,selTransTbl[19],strKey))));
 }
 
 # 35 "assoc.h"
 extern id  Assoc;
 
-# 199 "dictnary.m"
+# 195 "dictnary.m"
 static id i_Dictionary_atKey_put_(struct Dictionary_PRIVATE *self,SEL _cmd,id aKey,id anObject)
 {
-id objcT30,objcT31,objcT32;
+id objcT29,objcT30,objcT31;
 
-# 201 "dictnary.m"
-return(objcT30=(objcT31=self->associations,(*_imp(objcT31,selTransTbl[21]))(objcT31,selTransTbl[21],(objcT32=Assoc,(*_imp(objcT32,selTransTbl[22]))(objcT32,selTransTbl[22],aKey)))),(*_imp(objcT30,selTransTbl[23]))(objcT30,selTransTbl[23],anObject));
+# 197 "dictnary.m"
+return(objcT29=(objcT30=self->associations,(*_imp(objcT30,selTransTbl[20]))(objcT30,selTransTbl[20],(objcT31=Assoc,(*_imp(objcT31,selTransTbl[21]))(objcT31,selTransTbl[21],aKey)))),(*_imp(objcT29,selTransTbl[22]))(objcT29,selTransTbl[22],anObject));
 }
 
 static id i_Dictionary_atKeySTR_put_(struct Dictionary_PRIVATE *self,SEL _cmd,STR strKey,id anObject)
 {
-id objcT33,objcT34;
+id objcT32,objcT33;
 
-# 206 "dictnary.m"
-return(objcT33=(id)self,(*_imp(objcT33,selTransTbl[24]))(objcT33,selTransTbl[24],(objcT34=String,(*(id(*)(id,SEL,STR))_imp(objcT34,selTransTbl[20]))(objcT34,selTransTbl[20],strKey)),anObject));
+# 202 "dictnary.m"
+return(objcT32=(id)self,(*_imp(objcT32,selTransTbl[23]))(objcT32,selTransTbl[23],(objcT33=String,(*(id(*)(id,SEL,STR))_imp(objcT33,selTransTbl[19]))(objcT33,selTransTbl[19],strKey)),anObject));
 }
 
 # 32 "keyseq.h"
@@ -362,108 +354,111 @@ extern id  KeySequence;
 # 35 "sequence.h"
 extern id  Sequence;
 
-# 209 "dictnary.m"
+# 205 "dictnary.m"
 static id i_Dictionary_eachKey(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
-id objcT35,objcT36,objcT37;
+id objcT34,objcT35,objcT36;
 
-# 211 "dictnary.m"
-id aCarrier=(objcT35=KeySequence,(*_imp(objcT35,selTransTbl[25]))(objcT35,selTransTbl[25],(objcT36=self->associations,(*_imp(objcT36,selTransTbl[26]))(objcT36,selTransTbl[26]))));
-return(objcT37=Sequence,(*_imp(objcT37,selTransTbl[25]))(objcT37,selTransTbl[25],aCarrier));
+# 207 "dictnary.m"
+id aCarrier=(objcT34=KeySequence,(*_imp(objcT34,selTransTbl[24]))(objcT34,selTransTbl[24],(objcT35=self->associations,(*_imp(objcT35,selTransTbl[25]))(objcT35,selTransTbl[25]))));
+return(objcT36=Sequence,(*_imp(objcT36,selTransTbl[24]))(objcT36,selTransTbl[24],aCarrier));
 }
 
 # 32 "valueseq.h"
 extern id  ValueSequence;
 
-# 214 "dictnary.m"
+# 210 "dictnary.m"
 static id i_Dictionary_eachValue(struct Dictionary_PRIVATE *self,SEL _cmd)
 {
-id objcT38,objcT39,objcT40;
+id objcT37,objcT38,objcT39;
 
-# 216 "dictnary.m"
-id aCarrier=(objcT38=ValueSequence,(*_imp(objcT38,selTransTbl[25]))(objcT38,selTransTbl[25],(objcT39=self->associations,(*_imp(objcT39,selTransTbl[26]))(objcT39,selTransTbl[26]))));
-return(objcT40=Sequence,(*_imp(objcT40,selTransTbl[25]))(objcT40,selTransTbl[25],aCarrier));
+# 212 "dictnary.m"
+id aCarrier=(objcT37=ValueSequence,(*_imp(objcT37,selTransTbl[24]))(objcT37,selTransTbl[24],(objcT38=self->associations,(*_imp(objcT38,selTransTbl[25]))(objcT38,selTransTbl[25]))));
+return(objcT39=Sequence,(*_imp(objcT39,selTransTbl[24]))(objcT39,selTransTbl[24],aCarrier));
 }
 
-# 226 "dictnary.m"
+# 28 "notfound.h"
+extern id  NotFound;
+
+# 222 "dictnary.m"
 static id i_Dictionary_removeKey_(struct Dictionary_PRIVATE *self,SEL _cmd,id key)
 {
-id objcT41,objcT42;
+id objcT40,objcT41;
 
-# 228 "dictnary.m"
+# 224 "dictnary.m"
 id assoc,v;
-if((assoc=(objcT41=(objcT42=(id)self,(*_imp(objcT42,selTransTbl[15]))(objcT42,selTransTbl[15])),(*_imp(objcT41,selTransTbl[27]))(objcT41,selTransTbl[27],key))))
+if((assoc=(objcT40=(objcT41=(id)self,(*_imp(objcT41,selTransTbl[15]))(objcT41,selTransTbl[15])),(*_imp(objcT40,selTransTbl[26]))(objcT40,selTransTbl[26],key))))
 {
-id objcT43,objcT44;
+id objcT42,objcT43;
 
-# 231 "dictnary.m"
-v=(objcT43=assoc,(*_imp(objcT43,selTransTbl[18]))(objcT43,selTransTbl[18]));
+# 227 "dictnary.m"
+v=(objcT42=assoc,(*_imp(objcT42,selTransTbl[17]))(objcT42,selTransTbl[17]));
 
-assoc=(objcT44=assoc,(*_imp(objcT44,selTransTbl[8]))(objcT44,selTransTbl[8]));
+assoc=(objcT43=assoc,(*_imp(objcT43,selTransTbl[8]))(objcT43,selTransTbl[8]));
 
 return v;
 }
 else
 {
-id objcT45;
+id objcT44;
 
-# 239 "dictnary.m"
-(objcT45=(id)self,(*_imp(objcT45,selTransTbl[28]))(objcT45,selTransTbl[28]));
+# 235 "dictnary.m"
+(objcT44=NotFound,(*_imp(objcT44,selTransTbl[27]))(objcT44,selTransTbl[27]));
 return(id)0;
 }
 }
 
 static id i_Dictionary_removeKey_ifAbsent_(struct Dictionary_PRIVATE *self,SEL _cmd,id key,id aBlock)
 {
-id objcT46,objcT47;
+id objcT45,objcT46;
 
-# 246 "dictnary.m"
+# 242 "dictnary.m"
 id assoc,v;
-if((assoc=(objcT46=(objcT47=(id)self,(*_imp(objcT47,selTransTbl[15]))(objcT47,selTransTbl[15])),(*_imp(objcT46,selTransTbl[27]))(objcT46,selTransTbl[27],key))))
+if((assoc=(objcT45=(objcT46=(id)self,(*_imp(objcT46,selTransTbl[15]))(objcT46,selTransTbl[15])),(*_imp(objcT45,selTransTbl[26]))(objcT45,selTransTbl[26],key))))
 {
-id objcT48,objcT49;
+id objcT47,objcT48;
 
-# 249 "dictnary.m"
-v=(objcT48=assoc,(*_imp(objcT48,selTransTbl[18]))(objcT48,selTransTbl[18]));
+# 245 "dictnary.m"
+v=(objcT47=assoc,(*_imp(objcT47,selTransTbl[17]))(objcT47,selTransTbl[17]));
 
-assoc=(objcT49=assoc,(*_imp(objcT49,selTransTbl[8]))(objcT49,selTransTbl[8]));
+assoc=(objcT48=assoc,(*_imp(objcT48,selTransTbl[8]))(objcT48,selTransTbl[8]));
 
 return v;
 }
 else
 {
-id objcT50;
+id objcT49;
 
-# 257 "dictnary.m"
-return(objcT50=aBlock,(*_imp(objcT50,selTransTbl[18]))(objcT50,selTransTbl[18]));
+# 253 "dictnary.m"
+return(objcT49=aBlock,(*_imp(objcT49,selTransTbl[17]))(objcT49,selTransTbl[17]));
 }
 }
 
-# 269 "dictnary.m"
+# 265 "dictnary.m"
 static id i_Dictionary_keysDo_(struct Dictionary_PRIVATE *self,SEL _cmd,id aBlock)
 {
-id objcT51,objcT52,objcT53,objcT54;
+id objcT50,objcT51,objcT52,objcT53;
 
-# 271 "dictnary.m"
+# 267 "dictnary.m"
 id aKey;
-id keys=(objcT51=(id)self,(*_imp(objcT51,selTransTbl[29]))(objcT51,selTransTbl[29]));
+id keys=(objcT50=(id)self,(*_imp(objcT50,selTransTbl[28]))(objcT50,selTransTbl[28]));
 
-while((aKey=(objcT52=keys,(*_imp(objcT52,selTransTbl[30]))(objcT52,selTransTbl[30]))))
-(objcT53=aBlock,(*_imp(objcT53,selTransTbl[23]))(objcT53,selTransTbl[23],aKey));
+while((aKey=(objcT51=keys,(*_imp(objcT51,selTransTbl[29]))(objcT51,selTransTbl[29]))))
+(objcT52=aBlock,(*_imp(objcT52,selTransTbl[22]))(objcT52,selTransTbl[22],aKey));
 
-keys=(objcT54=keys,(*_imp(objcT54,selTransTbl[8]))(objcT54,selTransTbl[8]));
+keys=(objcT53=keys,(*_imp(objcT53,selTransTbl[8]))(objcT53,selTransTbl[8]));
 
 
 return(id)self;
 }
 
-# 290 "dictnary.m"
+# 286 "dictnary.m"
 static id i_Dictionary_printOn_(struct Dictionary_PRIVATE *self,SEL _cmd,IOD aFile)
 {
-id objcT55;
+id objcT54;
 
-# 292 "dictnary.m"
-(objcT55=self->associations,(*(id(*)(id,SEL,IOD))_imp(objcT55,selTransTbl[31]))(objcT55,selTransTbl[31],aFile));
+# 288 "dictnary.m"
+(objcT54=self->associations,(*(id(*)(id,SEL,IOD))_imp(objcT54,selTransTbl[30]))(objcT54,selTransTbl[30],aFile));
 return(id)self;
 }
 extern id  Object;
@@ -490,7 +485,6 @@ static struct _SLT _Dictionary_nstDispatchTbl[] ={
 {"includesKey:",(id (*)())i_Dictionary_includesKey_},
 {"hash",(id (*)())i_Dictionary_hash},
 {"isEqual:",(id (*)())i_Dictionary_isEqual_},
-{"errorKeyNotFound",(id (*)())i_Dictionary_errorKeyNotFound},
 {"associationAt:",(id (*)())i_Dictionary_associationAt_},
 {"atKey:",(id (*)())i_Dictionary_atKey_},
 {"atKey:ifAbsent:",(id (*)())i_Dictionary_atKey_ifAbsent_},
@@ -513,7 +507,7 @@ struct _SHARED  _Dictionary = {
   "Dictionary",
   0,
   sizeof(struct Dictionary_PRIVATE),
-  29,
+  28,
   _Dictionary_nstDispatchTbl,
   41,
   &dictnary_modDesc,
@@ -556,7 +550,6 @@ static char *_selTransTbl[] ={
 "hash",
 "isEqual:",
 "associations",
-"error:",
 "find:",
 "value",
 "atKey:",
@@ -568,7 +561,7 @@ static char *_selTransTbl[] ={
 "over:",
 "eachElement",
 "remove:",
-"errorKeyNotFound",
+"signal",
 "eachKey",
 "next",
 "printOn:",
@@ -576,12 +569,12 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor dictnary_modDesc = {
   "dictnary",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
   &Dictionary,
-  32,
+  31,
   _selTransTbl,
   0
 };
