@@ -139,6 +139,7 @@ void defoptions(void);
 
 extern int o_warnings;
 extern int o_gnu;
+extern int o_hpux;
 extern int o_vms;
 extern int o_refcnt;
 extern int o_ppi;
@@ -253,7 +254,7 @@ id mkbitfielddecl(id decl,id expr);
 id mkstardecl(id pointer,id decl);
 id mkasmop(id string,id expr);
 id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
-id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
+id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
 id mklist(id c,id s);
 id mklist2(id c,id s,id t);
 id atdefsaddall(id c,id n);
@@ -329,7 +330,7 @@ self->
 # 50 "dostmt.m"
 stmt=aStmt;
 if(o_refcnt&& !(objcT0=self->stmt,(*(BOOL(*)(id,SEL))_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0]))){self->
-stmt=mkcompstmt((id)0,(id)0,mklist((id)0,self->stmt),(id)0);
+stmt=mkcompstmt((id)0,(id)0,mklist((id)0,self->stmt),(id)0,(id)0);
 }
 return(id)self;
 }
@@ -479,7 +480,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor dostmt_modDesc = {
   "dostmt",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
