@@ -144,7 +144,7 @@ extern struct _SHARED _IdArray;
 extern struct _SHARED __IdArray;
 
 
-# 53 "idarray.m"
+# 54 "idarray.m"
 static void
 init(idary_t self,id v,int c)
 {
@@ -157,7 +157,7 @@ static id c_IdArray_new(struct IdArray_PRIVATE *self,SEL _cmd)
 {
 id objcT0,objcT1;
 
-# 63 "idarray.m"
+# 64 "idarray.m"
 id newObj=(objcT0=__IdArray.clsSuper,(*_impSuper(objcT0,selTransTbl[0]))((id)self,selTransTbl[0]));
 init((objcT1=newObj,(*(idary_t(*)(id,SEL))_imp(objcT1,selTransTbl[1]))(objcT1,selTransTbl[1])),(id)0,(16));
 return newObj;
@@ -167,7 +167,7 @@ static id c_IdArray_new_(struct IdArray_PRIVATE *self,SEL _cmd,unsigned n)
 {
 id objcT2,objcT3;
 
-# 70 "idarray.m"
+# 71 "idarray.m"
 id newObj=(objcT2=__IdArray.clsSuper,(*_impSuper(objcT2,selTransTbl[0]))((id)self,selTransTbl[0]));
 init((objcT3=newObj,(*(idary_t(*)(id,SEL))_imp(objcT3,selTransTbl[1]))(objcT3,selTransTbl[1])),(id)0,n);
 return newObj;
@@ -179,13 +179,13 @@ id objcT4;
 unsigned i;
 va_list vp;
 id newObject=(objcT4=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT4,selTransTbl[2]))(objcT4,selTransTbl[2],nArgs));
-# 95 "idarray.m"
+# 96 "idarray.m"
 va_start(vp,nArgs);
 for(i=0;i<nArgs;i++)
 {
 id objcT5;
 
-# 98 "idarray.m"
+# 99 "idarray.m"
 id anObject=va_arg(vp,id);
 (objcT5=newObject,(*(id(*)(id,SEL,unsigned,id))_imp(objcT5,selTransTbl[3]))(objcT5,selTransTbl[3],i,anObject));
 }
@@ -217,7 +217,7 @@ static id i_IdArray_copy(struct IdArray_PRIVATE *self,SEL _cmd)
 {
 id objcT6,objcT7;
 
-# 127 "idarray.m"
+# 128 "idarray.m"
 id aCopy=(objcT6=_IdArray.clsSuper,(*_impSuper(objcT6,selTransTbl[4]))((id)self,selTransTbl[4]));
 copy((objcT7=aCopy,(*(idary_t(*)(id,SEL))_imp(objcT7,selTransTbl[1]))(objcT7,selTransTbl[1])),( &self->value));
 return aCopy;
@@ -230,7 +230,7 @@ while(n--)
 {
 id objcT8;
  *
-# 137 "idarray.m"
+# 138 "idarray.m"
 p++=(objcT8= *q++,(*_imp(objcT8,selTransTbl[5]))(objcT8,selTransTbl[5]));
 }
 }
@@ -248,7 +248,7 @@ static id i_IdArray_deepCopy(struct IdArray_PRIVATE *self,SEL _cmd)
 {
 id objcT9,objcT10;
 
-# 152 "idarray.m"
+# 153 "idarray.m"
 id aCopy=(objcT9=_IdArray.clsSuper,(*_impSuper(objcT9,selTransTbl[4]))((id)self,selTransTbl[4]));
 deepcopy((objcT10=aCopy,(*(idary_t(*)(id,SEL))_imp(objcT10,selTransTbl[1]))(objcT10,selTransTbl[1])),( &self->value));
 return aCopy;
@@ -265,12 +265,12 @@ static id i_IdArray_free(struct IdArray_PRIVATE *self,SEL _cmd)
 {
 id objcT11;
 
-# 166 "idarray.m"
+# 167 "idarray.m"
 clear(( &self->value));
 return(objcT11=_IdArray.clsSuper,(*_impSuper(objcT11,selTransTbl[6]))((id)self,selTransTbl[6]));
 }
 
-# 176 "idarray.m"
+# 177 "idarray.m"
 static idary_t i_IdArray_idaryvalue(struct IdArray_PRIVATE *self,SEL _cmd)
 {
 return( &self->value);
@@ -292,6 +292,10 @@ static unsigned i_IdArray_size(struct IdArray_PRIVATE *self,SEL _cmd)
 return getsize(( &self->value));
 }
 
+# 28 "outofbnd.h"
+extern id  OutOfBounds;
+
+# 198 "idarray.m"
 static id
 at(idary_t self,int i)
 {
@@ -303,8 +307,8 @@ else
 {
 id objcT12;
 
-# 206 "idarray.m"
-(objcT12=IdArray,(*(id(*)(id,SEL,STR,...))_imp(objcT12,selTransTbl[7]))(objcT12,selTransTbl[7],"Index out of bounds"));
+# 207 "idarray.m"
+(objcT12=OutOfBounds,(*_imp(objcT12,selTransTbl[7]))(objcT12,selTransTbl[7]));
 return(id)0;
 }
 }
@@ -333,8 +337,8 @@ else
 {
 id objcT13;
 
-# 233 "idarray.m"
-(objcT13=IdArray,(*(id(*)(id,SEL,STR,...))_imp(objcT13,selTransTbl[7]))(objcT13,selTransTbl[7],"Index out of bounds"));
+# 234 "idarray.m"
+(objcT13=OutOfBounds,(*_imp(objcT13,selTransTbl[7]))(objcT13,selTransTbl[7]));
 return(id)0;
 }
 }
@@ -344,7 +348,7 @@ static id i_IdArray_at_put_(struct IdArray_PRIVATE *self,SEL _cmd,unsigned anOff
 return putat(( &self->value),anOffset,anObject);
 }
 
-# 249 "idarray.m"
+# 250 "idarray.m"
 static unsigned i_IdArray_capacity(struct IdArray_PRIVATE *self,SEL _cmd)
 {
 return(( &self->value)->capacity);
@@ -400,19 +404,19 @@ packcontents(( &self->value));
 return(id)self;
 }
 
-# 310 "idarray.m"
+# 311 "idarray.m"
 static id i_IdArray_printOn_(struct IdArray_PRIVATE *self,SEL _cmd,IOD aFile)
 {
 id objcT14;
 
-# 312 "idarray.m"
+# 313 "idarray.m"
 unsigned i,n=(objcT14=(id)self,(*(unsigned(*)(id,SEL))_imp(objcT14,selTransTbl[8]))(objcT14,selTransTbl[8]));
 
 if(n)
 {
 id objcT15,objcT16;
 
-# 316 "idarray.m"
+# 317 "idarray.m"
 id o=(objcT15=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT15,selTransTbl[9]))(objcT15,selTransTbl[9],0));
 if(o)
 (objcT16=o,(*(id(*)(id,SEL,IOD))_imp(objcT16,selTransTbl[10]))(objcT16,selTransTbl[10],aFile));
@@ -424,7 +428,7 @@ for(i=0;i<n;i++)
 {
 id objcT17,objcT18;
 
-# 325 "idarray.m"
+# 326 "idarray.m"
 id o=(objcT17=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT17,selTransTbl[9]))(objcT17,selTransTbl[9],i));
 fprintf(aFile,",");
 if(o)
@@ -436,7 +440,7 @@ fprintf(aFile,"nil");
 return(id)self;
 }
 
-# 343 "idarray.m"
+# 344 "idarray.m"
 static void
 idfileout(id aFiler,id*p,int n)
 {
@@ -444,7 +448,7 @@ while(n--)
 {
 id objcT19;
 
-# 348 "idarray.m"
+# 349 "idarray.m"
 (objcT19=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT19,selTransTbl[11]))(objcT19,selTransTbl[11],p++,'@'));
 }
 }
@@ -456,7 +460,7 @@ while(n--)
 {
 id objcT20;
 
-# 357 "idarray.m"
+# 358 "idarray.m"
 (objcT20=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT20,selTransTbl[12]))(objcT20,selTransTbl[12],p++,'@'));
 }
 }
@@ -466,7 +470,7 @@ fileout(id aFiler,idary_t self)
 {
 id objcT21;
 
-# 364 "idarray.m"
+# 365 "idarray.m"
 (objcT21=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT21,selTransTbl[11]))(objcT21,selTransTbl[11], &self->capacity,'i'));
 idfileout(aFiler,self->ptr,self->capacity);
 }
@@ -476,7 +480,7 @@ filein(id aFiler,idary_t self)
 {
 id objcT22;
 
-# 371 "idarray.m"
+# 372 "idarray.m"
 (objcT22=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT22,selTransTbl[12]))(objcT22,selTransTbl[12], &self->capacity,'i'));
 self->ptr=(id*)OC_Malloc(self->capacity*sizeof(id));
 idfilein(aFiler,self->ptr,self->capacity);
@@ -486,7 +490,7 @@ static id i_IdArray_fileOutOn_(struct IdArray_PRIVATE *self,SEL _cmd,id aFiler)
 {
 id objcT23;
 
-# 378 "idarray.m"
+# 379 "idarray.m"
 (objcT23=_IdArray.clsSuper,(*_impSuper(objcT23,selTransTbl[13]))((id)self,selTransTbl[13],aFiler));
 fileout(aFiler,( &self->value));
 return(id)self;
@@ -496,7 +500,7 @@ static id i_IdArray_fileInFrom_(struct IdArray_PRIVATE *self,SEL _cmd,id aFiler)
 {
 id objcT24;
 
-# 385 "idarray.m"
+# 386 "idarray.m"
 (objcT24=_IdArray.clsSuper,(*_impSuper(objcT24,selTransTbl[14]))((id)self,selTransTbl[14],aFiler));
 filein(aFiler,( &self->value));
 return(id)self;
@@ -571,7 +575,7 @@ static char *_selTransTbl[] ={
 "copy",
 "deepCopy",
 "free",
-"error:",
+"signal",
 "size",
 "at:",
 "printOn:",
@@ -583,7 +587,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor idarray_modDesc = {
   "idarray",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
