@@ -141,7 +141,7 @@ extern struct _SHARED _IntArray;
 extern struct _SHARED __IntArray;
 
 
-# 41 "intarray.m"
+# 42 "intarray.m"
 static void
 fill(int*p,int v,int n)
 {
@@ -164,7 +164,7 @@ static id c_IntArray_new(struct IntArray_PRIVATE *self,SEL _cmd)
 {
 id objcT0,objcT1;
 
-# 61 "intarray.m"
+# 62 "intarray.m"
 id newObj=(objcT0=__IntArray.clsSuper,(*_impSuper(objcT0,selTransTbl[0]))((id)self,selTransTbl[0]));
 init((objcT1=newObj,(*(intary_t(*)(id,SEL))_imp(objcT1,selTransTbl[1]))(objcT1,selTransTbl[1])),0,(16));
 return newObj;
@@ -174,7 +174,7 @@ static id c_IntArray_new_(struct IntArray_PRIVATE *self,SEL _cmd,unsigned n)
 {
 id objcT2,objcT3;
 
-# 68 "intarray.m"
+# 69 "intarray.m"
 id newObj=(objcT2=__IntArray.clsSuper,(*_impSuper(objcT2,selTransTbl[0]))((id)self,selTransTbl[0]));
 init((objcT3=newObj,(*(intary_t(*)(id,SEL))_imp(objcT3,selTransTbl[1]))(objcT3,selTransTbl[1])),0,n);
 return newObj;
@@ -186,13 +186,13 @@ id objcT4;
 unsigned i;
 va_list vp;
 id newObject=(objcT4=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT4,selTransTbl[2]))(objcT4,selTransTbl[2],nArgs));
-# 93 "intarray.m"
+# 94 "intarray.m"
 va_start(vp,nArgs);
 for(i=0;i<nArgs;i++)
 {
 id objcT5;
 
-# 96 "intarray.m"
+# 97 "intarray.m"
 int anObject=va_arg(vp,int);
 (objcT5=newObject,(*(int(*)(id,SEL,unsigned,int))_imp(objcT5,selTransTbl[3]))(objcT5,selTransTbl[3],i,anObject));
 }
@@ -226,7 +226,7 @@ static id i_IntArray_copy(struct IntArray_PRIVATE *self,SEL _cmd)
 {
 id objcT6,objcT7;
 
-# 127 "intarray.m"
+# 128 "intarray.m"
 id aCopy=(objcT6=_IntArray.clsSuper,(*_impSuper(objcT6,selTransTbl[4]))((id)self,selTransTbl[4]));
 copy((objcT7=aCopy,(*(intary_t(*)(id,SEL))_imp(objcT7,selTransTbl[1]))(objcT7,selTransTbl[1])),( &self->value));
 return aCopy;
@@ -236,7 +236,7 @@ static id i_IntArray_deepCopy(struct IntArray_PRIVATE *self,SEL _cmd)
 {
 id objcT8;
 
-# 134 "intarray.m"
+# 135 "intarray.m"
 return(objcT8=(id)self,(*_imp(objcT8,selTransTbl[4]))(objcT8,selTransTbl[4]));
 }
 
@@ -251,12 +251,12 @@ static id i_IntArray_free(struct IntArray_PRIVATE *self,SEL _cmd)
 {
 id objcT9;
 
-# 146 "intarray.m"
+# 147 "intarray.m"
 clear(( &self->value));
 return(objcT9=_IntArray.clsSuper,(*_impSuper(objcT9,selTransTbl[5]))((id)self,selTransTbl[5]));
 }
 
-# 156 "intarray.m"
+# 157 "intarray.m"
 static intary_t i_IntArray_intaryvalue(struct IntArray_PRIVATE *self,SEL _cmd)
 {
 return( &self->value);
@@ -267,6 +267,10 @@ static unsigned i_IntArray_size(struct IntArray_PRIVATE *self,SEL _cmd)
 return( &self->value)->capacity;
 }
 
+# 28 "outofbnd.h"
+extern id  OutOfBounds;
+
+# 167 "intarray.m"
 static int
 intat(intary_t self,int i)
 {
@@ -278,8 +282,8 @@ else
 {
 id objcT10;
 
-# 175 "intarray.m"
-(objcT10=IntArray,(*(id(*)(id,SEL,STR,...))_imp(objcT10,selTransTbl[6]))(objcT10,selTransTbl[6],"index out of bounds"));
+# 176 "intarray.m"
+(objcT10=OutOfBounds,(*_imp(objcT10,selTransTbl[6]))(objcT10,selTransTbl[6]));
 return 0;
 }
 }
@@ -308,8 +312,8 @@ else
 {
 id objcT11;
 
-# 202 "intarray.m"
-(objcT11=IntArray,(*(id(*)(id,SEL,STR,...))_imp(objcT11,selTransTbl[6]))(objcT11,selTransTbl[6],"index out of bounds"));
+# 203 "intarray.m"
+(objcT11=OutOfBounds,(*_imp(objcT11,selTransTbl[6]))(objcT11,selTransTbl[6]));
 return 0;
 }
 }
@@ -319,7 +323,7 @@ static int i_IntArray_intAt_put_(struct IntArray_PRIVATE *self,SEL _cmd,unsigned
 return putintat(( &self->value),anOffset,anInt);
 }
 
-# 218 "intarray.m"
+# 219 "intarray.m"
 static void
 resize(intary_t self,unsigned c)
 {
@@ -375,12 +379,12 @@ packcontents(( &self->value));
 return(id)self;
 }
 
-# 279 "intarray.m"
+# 280 "intarray.m"
 static id i_IntArray_printOn_(struct IntArray_PRIVATE *self,SEL _cmd,IOD aFile)
 {
 id objcT12,objcT13,objcT14;
 
-# 281 "intarray.m"
+# 282 "intarray.m"
 unsigned i,n=(objcT12=(id)self,(*(unsigned(*)(id,SEL))_imp(objcT12,selTransTbl[7]))(objcT12,selTransTbl[7]));
 if(n)
 fprintf(aFile,"%i",(objcT13=(id)self,(*(int(*)(id,SEL,unsigned))_imp(objcT13,selTransTbl[8]))(objcT13,selTransTbl[8],0)));
@@ -389,7 +393,7 @@ fprintf(aFile,",%i",(objcT14=(id)self,(*(int(*)(id,SEL,unsigned))_imp(objcT14,se
 return(id)self;
 }
 
-# 296 "intarray.m"
+# 297 "intarray.m"
 static void
 intfileout(id aFiler,int*p,int n)
 {
@@ -397,7 +401,7 @@ while(n--)
 {
 id objcT15;
 
-# 301 "intarray.m"
+# 302 "intarray.m"
 (objcT15=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT15,selTransTbl[9]))(objcT15,selTransTbl[9],p++,'i'));
 }
 }
@@ -409,7 +413,7 @@ while(n--)
 {
 id objcT16;
 
-# 310 "intarray.m"
+# 311 "intarray.m"
 (objcT16=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT16,selTransTbl[10]))(objcT16,selTransTbl[10],p++,'i'));
 }
 }
@@ -419,7 +423,7 @@ fileout(id aFiler,intary_t self)
 {
 id objcT17;
 
-# 317 "intarray.m"
+# 318 "intarray.m"
 (objcT17=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT17,selTransTbl[9]))(objcT17,selTransTbl[9], &self->capacity,'i'));
 intfileout(aFiler,self->ptr,self->capacity);
 }
@@ -429,7 +433,7 @@ filein(id aFiler,intary_t self)
 {
 id objcT18;
 
-# 324 "intarray.m"
+# 325 "intarray.m"
 (objcT18=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT18,selTransTbl[10]))(objcT18,selTransTbl[10], &self->capacity,'i'));
 self->ptr=(int*)OC_MallocAtomic(self->capacity*sizeof(int));
 intfilein(aFiler,self->ptr,self->capacity);
@@ -439,7 +443,7 @@ static id i_IntArray_fileOutOn_(struct IntArray_PRIVATE *self,SEL _cmd,id aFiler
 {
 id objcT19;
 
-# 331 "intarray.m"
+# 332 "intarray.m"
 (objcT19=_IntArray.clsSuper,(*_impSuper(objcT19,selTransTbl[11]))((id)self,selTransTbl[11],aFiler));
 fileout(aFiler, &self->value);
 return(id)self;
@@ -449,7 +453,7 @@ static id i_IntArray_fileInFrom_(struct IntArray_PRIVATE *self,SEL _cmd,id aFile
 {
 id objcT20;
 
-# 338 "intarray.m"
+# 339 "intarray.m"
 (objcT20=_IntArray.clsSuper,(*_impSuper(objcT20,selTransTbl[12]))((id)self,selTransTbl[12],aFiler));
 filein(aFiler, &self->value);
 return(id)self;
@@ -523,7 +527,7 @@ static char *_selTransTbl[] ={
 "intAt:put:",
 "copy",
 "free",
-"error:",
+"signal",
 "size",
 "intAt:",
 "fileOut:type:",
@@ -534,7 +538,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor intarray_modDesc = {
   "intarray",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
