@@ -158,7 +158,7 @@ id mkbitfielddecl(id decl,id expr);
 id mkstardecl(id pointer,id decl);
 id mkasmop(id string,id expr);
 id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
-id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
+id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
 id mklist(id c,id s);
 id mklist2(id c,id s,id t);
 id atdefsaddall(id c,id n);
@@ -204,6 +204,7 @@ void defoptions(void);
 
 extern int o_warnings;
 extern int o_gnu;
+extern int o_hpux;
 extern int o_vms;
 extern int o_refcnt;
 extern int o_ppi;
@@ -456,7 +457,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor lexfiltr_modDesc = {
   "lexfiltr",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
