@@ -154,6 +154,7 @@ void defoptions(void);
 
 extern int o_warnings;
 extern int o_gnu;
+extern int o_hpux;
 extern int o_vms;
 extern int o_refcnt;
 extern int o_ppi;
@@ -268,7 +269,7 @@ id mkbitfielddecl(id decl,id expr);
 id mkstardecl(id pointer,id decl);
 id mkasmop(id string,id expr);
 id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
-id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
+id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
 id mklist(id c,id s);
 id mklist2(id c,id s,id t);
 id atdefsaddall(id c,id n);
@@ -350,13 +351,13 @@ void definebuiltinvar(char*s);
 # 40 "objc1.m"
 void printversion(void)
 {
-printf("%s\n","3.1.32");
+printf("%s\n","3.2.8");
 exit(0);
 }
 
 void printcopyright(void)
 {
-printf("Portable Object Compiler %s (c) 1997, 98, 99, 2000, 01, 02.\n","3.1.32");
+printf("Portable Object Compiler %s (c) 1997, 98, 99, 2000, 01, 02, 03, 04.\n","3.2.8");
 printf("Distributed under the terms of the GNU LGPL.\n");
 }
 
@@ -614,6 +615,8 @@ o_shareddata=0;
 o_gnu++;
 }else if( !strcmp(t,"-vms")){
 o_vms++;
+}else if( !strcmp(t,"-hpux")){
+o_hpux++;
 }else if( !strcmp(t,"-refcnt")){
 o_refcnt++;
 o_selfassign=0;
@@ -622,7 +625,7 @@ o_enableasm=0;
 }else if( !strcmp(t,"-nolonglong")){
 o_llkeyw=0;
 }else if( !strcmp(t,"-msdos")){
-o_duptypedefs++;
+# 280 "objc1.m"
 o_msdos++;
 }else if( !strcmp(t,"-watcom")){
 o_watcom++;
@@ -736,7 +739,7 @@ unknownoption(t);
 }
 }
 
-# 392 "objc1.m"
+# 398 "objc1.m"
 void openinfile(void)
 {
 if(o_infile){
@@ -754,18 +757,18 @@ inlineno=1;
 if(o_srcfilename){
 id objcT37;
 
-# 407 "objc1.m"
+# 413 "objc1.m"
 infilename=(objcT37=String,(*(id(*)(id,SEL,STR))_imp(objcT37,selTransTbl[1]))(objcT37,selTransTbl[1],o_srcfilename));
 }else{
 if(o_infile){
 id objcT38;
 
-# 410 "objc1.m"
+# 416 "objc1.m"
 infilename=(objcT38=String,(*(id(*)(id,SEL,STR))_imp(objcT38,selTransTbl[1]))(objcT38,selTransTbl[1],o_infile));
 }else{
 id objcT39;
 
-# 412 "objc1.m"
+# 418 "objc1.m"
 infilename=(objcT39=String,(*(id(*)(id,SEL,STR))_imp(objcT39,selTransTbl[1]))(objcT39,selTransTbl[1],"-=stdin=-"));
 }
 }
@@ -773,12 +776,12 @@ infilename=(objcT39=String,(*(id(*)(id,SEL,STR))_imp(objcT39,selTransTbl[1]))(ob
 if( !o_nolinetags){
 id objcT40;
 
-# 417 "objc1.m"
+# 423 "objc1.m"
 gl(inlineno,(objcT40=infilename,(*(STR(*)(id,SEL))_imp(objcT40,selTransTbl[0]))(objcT40,selTransTbl[0])));
 }
 
 (void)0;
-(objcT41=trlunit,(*(id(*)(id,SEL,char*))_imp(objcT41,selTransTbl[7]))(objcT41,selTransTbl[7],"objc3.1.32"));
+(objcT41=trlunit,(*(id(*)(id,SEL,char*))_imp(objcT41,selTransTbl[7]))(objcT41,selTransTbl[7],"objc3.2.8"));
 (objcT42=trlunit,(*(id(*)(id,SEL,char*))_imp(objcT42,selTransTbl[8]))(objcT42,selTransTbl[8],(objcT43=infilename,(*(STR(*)(id,SEL))_imp(objcT43,selTransTbl[0]))(objcT43,selTransTbl[0]))));
 
 if(o_vms){
@@ -787,6 +790,14 @@ definebuiltinfun("__IS_X_FLOAT_BUILTIN");
 definebuiltintype("__int64");
 }
 
+if(o_hpux){
+definebuiltinfun("__va_start__");
+definebuiltinfun("__va_arg__");
+definebuiltintype("__va_list__");
+definebuiltintype("__fpreg");
+definebuiltintype("__float80");
+}
+
 if(o_gnu){
 definebuiltinfun("__builtin_saveregs");
 definebuiltinfun("__builtin_classify_type");
@@ -809,6 +820,11 @@ definebuiltintype("__builtin_va_list");
 definebuiltinfun("__builtin_stdarg_start");
 definebuiltinfun("__builtin_va_end");
 definebuiltinfun("__builtin_va_arg");
+definebuiltinfun("__builtin_va_start");
+definebuiltinfun("__builtin_expect");
+definebuiltinfun("__builtin_strchr");
+definebuiltinfun("__builtin_strcmp");
+definebuiltinfun("__builtin_strncmp");
 
 
 definebuiltinfun("__builtin_va_alist");
@@ -845,12 +861,12 @@ if(o_outfile)fclose(gfile);
 # 24 "../oclib/trlunit.h"
 extern id  TranslationUnit;
 
-# 485 "objc1.m"
+# 504 "objc1.m"
 int objcmain(int argc,char*argv[])
 {
 id objcT44,objcT45,objcT46,objcT47;
+trlunit=(objcT44=TranslationUnit,(*_imp(objcT44,selTransTbl[3]))(objcT44,selTransTbl[3]));
 
-# 487 "objc1.m"
 defoptions();
 setoptions(cmdlineopts(argc,argv));
 
@@ -859,7 +875,6 @@ if( !o_quiet)printcopyright();
 
 openinfile();
 openoutfile();
-trlunit=(objcT44=TranslationUnit,(*_imp(objcT44,selTransTbl[3]))(objcT44,selTransTbl[3]));
 
 setfirstlinetag();
 
@@ -877,7 +892,7 @@ return 0;
 }
 extern int oc_objcInit(int debug,int traceInit);
 
-# 485 "objc1.m"
+# 504 "objc1.m"
 int main(int argc,char*argv[]){
 oc_objcInit(0,0);
 return objcmain(argc,argv);
@@ -900,7 +915,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor objc1_modDesc = {
   "objc1",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
