@@ -209,6 +209,9 @@ extern id newBlock(int n,IMP fn,void*data,IMP dtor);
 # 1 "../../util/stdio.h"
 #include <stdio.h>
 
+# 1 "../../util/stdio.h"
+#include <stdio.h>
+
 # 1 "../../util/assert.h"
 #include <assert.h>
 
@@ -219,7 +222,7 @@ extern id newBlock(int n,IMP fn,void*data,IMP dtor);
 #include <string.h>
 
 
-# 59 "objcrt.m"
+# 61 "objcrt.m"
 static BOOL
 isfactory(Cls_t cls)
 {
@@ -273,7 +276,7 @@ getisa(id anObject)
 {
 
 return anObject->isa;
-# 115 "objcrt.m"
+# 117 "objcrt.m"
 }
 
 static void
@@ -281,7 +284,7 @@ setisa(id anObject,id aClass)
 {
 
 anObject->isa=aClass;
-# 125 "objcrt.m"
+# 127 "objcrt.m"
 }
 
 static short
@@ -289,11 +292,11 @@ nstsize(id aClass)
 {
 return((Cls_t)(aClass))->clsSizInstance;
 }
-# 136 "objcrt.m"
+# 138 "objcrt.m"
 static PHASH*hashList;
 static int nHashLists;
 
-# 147 "objcrt.m"
+# 149 "objcrt.m"
 static void
 markmodmapped(struct objcrt_modDescriptor*aMod)
 {
@@ -313,9 +316,9 @@ isminmaxsel(SEL s)
 {
 return(minsel<=s)&&(s<=maxsel);
 }
-# 183 "objcrt.m"
+# 185 "objcrt.m"
 extern Mentry_t _objcModules;
-# 193 "objcrt.m"
+# 195 "objcrt.m"
 typedef struct modnode
 {
 Mentry_t objcmodules;
@@ -341,16 +344,15 @@ freemodnode(modnode_t*n,modnode_t m)
 n=m->next;
 OC_Free(m);
 }
-# 225 "objcrt.m"
-id OC_Malloc_msg;
-
-# 40 "Object.h"
-extern id  Object;
-
 # 227 "objcrt.m"
+static id outOfMem;
+
 void*
 OC_Malloc(size_t nBytes)
 {
+id objcT0;
+
+# 232 "objcrt.m"
 void*data;
 
 
@@ -358,48 +360,31 @@ if( !nBytes)
 nBytes=sizeof(void*);
 if(nBytes>32*1024)
 dbg("OC_Malloc call for %i bytes\n",nBytes);
-
-while(1)
-{
-id objcT0;
-
-
-
+# 243 "objcrt.m"
 data=malloc(nBytes);
-# 248 "objcrt.m"
+# 247 "objcrt.m"
 if( !data)
-(objcT0=Object,(*_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0],OC_Malloc_msg));
-else
-break;
-}
-
+(objcT0=outOfMem,(*_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0]));
 return data;
 }
 
 void*
 OC_MallocAtomic(size_t nBytes)
 {
+id objcT1;
+
+# 255 "objcrt.m"
 void*data;
 
 if( !nBytes)
 nBytes=sizeof(void*);
 if(nBytes>32*1024)
 dbg("OC_MallocAtomic call for %i bytes\n",nBytes);
-
-while(1)
-{
-id objcT1;
-
-
-
+# 265 "objcrt.m"
 data=malloc(nBytes);
-# 277 "objcrt.m"
+# 269 "objcrt.m"
 if( !data)
-(objcT1=Object,(*_imp(objcT1,selTransTbl[0]))(objcT1,selTransTbl[0],OC_Malloc_msg));
-else
-break;
-}
-
+(objcT1=outOfMem,(*_imp(objcT1,selTransTbl[0]))(objcT1,selTransTbl[0]));
 return data;
 }
 
@@ -423,72 +408,63 @@ if( !nBytes)
 nBytes=sizeof(void*);
 if(nBytes>32*1024)
 dbg("OC_Realloc call for %i bytes\n",nBytes);
-
-if( !data)
-(objcT2=Object,(*_imp(objcT2,selTransTbl[0]))(objcT2,selTransTbl[0],OC_Malloc_msg));
-
-while(1)
-{
-id objcT3;
-
-
-
+# 298 "objcrt.m"
 data=realloc(data,nBytes);
-# 320 "objcrt.m"
+# 302 "objcrt.m"
 if( !data)
-(objcT3=Object,(*_imp(objcT3,selTransTbl[0]))(objcT3,selTransTbl[0],OC_Malloc_msg));
-else
-break;
-}
-
+(objcT2=outOfMem,(*_imp(objcT2,selTransTbl[0]))(objcT2,selTransTbl[0]));
 return data;
 }
 
 void*
 OC_Free(void*data)
 {
-# 335 "objcrt.m"
+# 313 "objcrt.m"
 free(data);
 
 return NULL;
 }
 
-# 377 "objcrt.m"
+# 355 "objcrt.m"
 id
 idassign(id*lhs,id rhs)
 {
-# 398 "objcrt.m"
+# 376 "objcrt.m"
 return( *lhs=rhs);
 }
 
 id
 idincref(id rhs)
 {
-# 414 "objcrt.m"
+# 392 "objcrt.m"
 return rhs;
 }
 
 id
 iddecref(id e)
 {
-# 433 "objcrt.m"
+# 411 "objcrt.m"
 return(id)0;
 }
 
+# 40 "Object.h"
+extern id  Object;
+
+# 414 "objcrt.m"
 static id
 nstalloc(id aClass,unsigned int nBytes)
 {
-id objcT4;
+id objcT3;
 
-# 439 "objcrt.m"
+# 417 "objcrt.m"
 id anObject;
 unsigned aSize;
 if( !aClass)
-(objcT4=Object,(*(id(*)(id,SEL,STR,...))_imp(objcT4,selTransTbl[1]))(objcT4,selTransTbl[1],"alloc: nil class"));
+(objcT3=Object,(*(id(*)(id,SEL,STR,...))_imp(objcT3,selTransTbl[1]))(objcT3,selTransTbl[1],"alloc: nil class"));
 aSize=nstsize(aClass)+nBytes;
 
 anObject=(id)OC_Calloc(aSize);
-# 451 "objcrt.m"
+# 429 "objcrt.m"
 setisa(anObject,aClass);
 return anObject;
 }
@@ -507,9 +483,9 @@ aSize=nstsize(aClass)+nBytes;
 newObject=(id)OC_Malloc(aSize);
 p=(char*)newObject;
 q=(char*)anObject;
-# 477 "objcrt.m"
+# 455 "objcrt.m"
 memcpy(p,q,aSize);
-# 482 "objcrt.m"
+# 460 "objcrt.m"
 (void)0;
 return newObject;
 }
@@ -521,15 +497,15 @@ setisa(anObject,(id)0);
 
 
 OC_Free(anObject);
-# 499 "objcrt.m"
+# 477 "objcrt.m"
 return(id)0;
 }
 
 id(*oc_alloc)(id,unsigned int)=nstalloc;
 id(*oc_copy)(id,unsigned int)=nstcopy;
-# 507 "objcrt.m"
+# 485 "objcrt.m"
 id(*oc_dealloc)(id)=nstdealloc;
-# 530 "objcrt.m"
+# 508 "objcrt.m"
 typedef struct _msgframe
 {
 struct _msgframe*prev;
@@ -544,11 +520,11 @@ argfrm;
 }*
 msgframe;
 
-# 590 "objcrt.m"
+# 568 "objcrt.m"
 void
 prnstack(FILE*firstArg)
 {
-# 597 "objcrt.m"
+# 575 "objcrt.m"
 FILE*stream=firstArg;
 msgframe pf,f=((msgframe)((unsigned) &firstArg-((unsigned) &(((msgframe)0)->argfrm.receiver))));
 int nsels=0;
@@ -568,7 +544,7 @@ fprintf(stream," %.80s\n",sels[nsels]);
 
 }
 
-# 625 "objcrt.m"
+# 603 "objcrt.m"
 static id
 reportv(id self,STR fmt,va_list ap)
 {
@@ -594,14 +570,14 @@ return self;
 
 id(*oc_error)(id self,STR fmt,va_list ap)=reportv;
 
-# 658 "objcrt.m"
+# 636 "objcrt.m"
 static void
 nofiler(void)
 {
-id objcT5;
+id objcT4;
 
-# 661 "objcrt.m"
-(objcT5=Object,(*(id(*)(id,SEL,STR,...))_imp(objcT5,selTransTbl[1]))(objcT5,selTransTbl[1],"No filer class linked into application."));
+# 639 "objcrt.m"
+(objcT4=Object,(*(id(*)(id,SEL,STR,...))_imp(objcT4,selTransTbl[1]))(objcT4,selTransTbl[1],"No filer class linked into application."));
 }
 
 static id
@@ -661,17 +637,17 @@ setfileout(BOOL(*f)(FILE*,id))
 _fileOut=f;
 }
 
-# 725 "objcrt.m"
+# 703 "objcrt.m"
 id
 __showOn(id self,unsigned level)
 {
 ( *_fileOut)(stderr,self);
-return self;
+return(id)0;
 }
 
 id(*_showOn)(id,unsigned)=__showOn;
 
-# 742 "objcrt.m"
+# 720 "objcrt.m"
 static int
 strCmp(char*s1,char*s2)
 {
@@ -737,25 +713,13 @@ static PHASH
 hashNew(STR key,PHASH link)
 {
 int n;
-PHASH obj=(PHASH)OC_Malloc(sizeof(HASH));
+PHASH obj;
 (void)0;
+obj=(PHASH)OC_Malloc(sizeof(HASH));
 obj->next=link;
 n=strlen(key);
 obj->key=(STR)OC_Malloc(n+1);
 strcpy(obj->key,key);
-key=obj->key;
-if(minsel)
-{
-if(key<minsel)
-minsel=key;
-if(key>maxsel)
-maxsel=key;
-}
-else
-{
-minsel=key;
-maxsel=key;
-}
 return obj;
 }
 
@@ -781,6 +745,18 @@ static PHASH
 hashEnter(STR key,int slot)
 {
 (void)0;
+if(minsel)
+{
+if(key<minsel)
+minsel=key;
+if(key>maxsel)
+maxsel=key;
+}
+else
+{
+minsel=key;
+maxsel=key;
+}
 if(slot<0)
 slot=strHash(key)%nHashLists;
 hashList[slot]=hashNew(key,hashList[slot]);
@@ -794,7 +770,7 @@ PHASH prev;
 return search(key,slot, &prev);
 }
 
-# 915 "objcrt.m"
+# 893 "objcrt.m"
 static void
 mapsels(PMOD info,SEL*sel)
 {
@@ -859,16 +835,16 @@ if( !ismapped(cls))
 mapcls(cls);
 }
 }
-# 986 "objcrt.m"
+# 964 "objcrt.m"
 static BOOL objcinitflag;
-# 995 "objcrt.m"
+# 973 "objcrt.m"
 static struct objcrt_useDescriptor*modlist=0;
 static int bindcnt=0;
 
 
 extern struct objcrt_useDescriptor*OCU_main;
 
-# 1006 "objcrt.m"
+# 984 "objcrt.m"
 static void
 traverse(struct objcrt_useDescriptor*desc)
 {
@@ -883,7 +859,7 @@ for(nxt=desc->uses; *nxt;nxt++)
 if( * *nxt&& !(( * *nxt)->processed))
 traverse( * *nxt);
 }
-# 1027 "objcrt.m"
+# 1005 "objcrt.m"
 if(desc->bind)
 {
 desc->next=modlist;
@@ -905,7 +881,7 @@ traverse(desc);
 
 aSize=(bindcnt+1)*sizeof(struct objcrt_modEntry);
 theModules=(Mentry_t)OC_Malloc(aSize);
-# 1053 "objcrt.m"
+# 1031 "objcrt.m"
 for(md=modlist,tmp=theModules;md;md=md->next,tmp++)
 {
 tmp->modLink=md->bind;
@@ -923,7 +899,7 @@ static void
 initsels(Mentry_t modPtr)
 {
 static int needHashInit=1;
-# 1075 "objcrt.m"
+# 1053 "objcrt.m"
 if(needHashInit)
 {
 hashInit();
@@ -960,26 +936,26 @@ mapclass(((Cls_t)( *cls)));
 static void
 initcls(id cls)
 {
-id objcT6;
+id objcT5;
 
-# 1111 "objcrt.m"
+# 1089 "objcrt.m"
 Cls_t aCls=((Cls_t)(cls));
 
 if(initlzd(aCls))
 return;
-# 1128 "objcrt.m"
+# 1106 "objcrt.m"
 if(aCls->clsSuper)
 {
 initcls(aCls->clsSuper);
 }
-# 1138 "objcrt.m"
+# 1116 "objcrt.m"
 if(initlzd(aCls))
 return;
 markinitlzd(aCls);
 
 if(iscatgry(aCls))
 addMethods(cls,aCls->clsSuper);
-(objcT6=cls,(*_imp(objcT6,selTransTbl[2]))(objcT6,selTransTbl[2]));
+(objcT5=cls,(*_imp(objcT5,selTransTbl[2]))(objcT5,selTransTbl[2]));
 }
 
 static void
@@ -1007,7 +983,7 @@ initcls( *cls);
 }
 }
 
-# 1184 "objcrt.m"
+# 1162 "objcrt.m"
 static void
 msgiods(void)
 {
@@ -1046,9 +1022,13 @@ if(dbgFlag)
 setbuf(msgIOD,NULL);
 }
 }
-# 1226 "objcrt.m"
+# 1204 "objcrt.m"
 }
 
+# 28 "OutOfMem.h"
+extern id  OutOfMemory;
+
+# 1206 "objcrt.m"
 int
 _objcInitNoShared(
 Mentry_t _objcModules,struct objcrt_useDescriptor*OCU_main)
@@ -1061,22 +1041,20 @@ return 1;
 }
 else
 {
-id objcT7,objcT8;
+id objcT6;
 msgiods();
-# 1247 "objcrt.m"
+# 1225 "objcrt.m"
 if( !_objcModules)
 _objcModules=findmods(OCU_main);
 loadobjc(_objcModules);
-# 1257 "objcrt.m"
+# 1235 "objcrt.m"
 for(m=modnodelist;m;m=m->next)
 initsels(m->objcmodules);
 for(m=modnodelist;m;m=m->next)
 initmods(m->objcmodules);
-# 1267 "objcrt.m"
-OC_Malloc_msg=(objcT7=Object,(*(id(*)(id,SEL,STR))_imp(objcT7,selTransTbl[3]))(objcT7,selTransTbl[3],"String"));
-if(OC_Malloc_msg)
-OC_Malloc_msg=(objcT8=OC_Malloc_msg,(*(id(*)(id,SEL,STR))_imp(objcT8,selTransTbl[4]))(objcT8,selTransTbl[4],"Out of memory."));
-# 1275 "objcrt.m"
+# 1245 "objcrt.m"
+outOfMem=(objcT6=OutOfMemory,(*_imp(objcT6,selTransTbl[3]))(objcT6,selTransTbl[3]));
+# 1251 "objcrt.m"
 objcinitflag=(BOOL)1;
 
 
@@ -1084,14 +1062,14 @@ return 0;
 }
 }
 
-# 1287 "objcrt.m"
+# 1263 "objcrt.m"
 int
 oc_objcInit(int debug,BOOL traceInit)
 {
 return _objcInitNoShared(_objcModules,OCU_main);
 }
 
-# 1300 "objcrt.m"
+# 1276 "objcrt.m"
 STR
 selName(SEL sel)
 {
@@ -1172,7 +1150,7 @@ return(id)0;
 id(*oc_cvtToId)(STR)=cvtToId;
 SEL(*oc_cvtToSel)(STR)=cvtToSel;
 
-# 1386 "objcrt.m"
+# 1362 "objcrt.m"
 static BOOL
 issubclass(Cls_t aCls,STR aClassname)
 {
@@ -1206,12 +1184,12 @@ if(morethanone(modPtr->modInfo))
 {
 while( *cls)
 {
-id objcT9;
+id objcT7;
 
-# 1419 "objcrt.m"
+# 1395 "objcrt.m"
 aCls=((Cls_t)( *cls));
 if(issubclass(aCls,aClassname))
-(objcT9=c,(*_imp(objcT9,selTransTbl[5]))(objcT9,selTransTbl[5], *cls));
+(objcT7=c,(*_imp(objcT7,selTransTbl[4]))(objcT7,selTransTbl[4], *cls));
 cls++;
 }
 }
@@ -1219,19 +1197,19 @@ else
 {
 if(cls)
 {
-id objcT10;
+id objcT8;
 
-# 1429 "objcrt.m"
+# 1405 "objcrt.m"
 aCls=((Cls_t)( *cls));
 if(issubclass(aCls,aClassname))
-(objcT10=c,(*_imp(objcT10,selTransTbl[5]))(objcT10,selTransTbl[5], *cls));
+(objcT8=c,(*_imp(objcT8,selTransTbl[4]))(objcT8,selTransTbl[4], *cls));
 }
 }
 }
 }
 }
 
-# 1444 "objcrt.m"
+# 1420 "objcrt.m"
 static id
 newShared(int aSize)
 {
@@ -1392,7 +1370,7 @@ return;
 }
 }
 
-# 1615 "objcrt.m"
+# 1591 "objcrt.m"
 char*
 objcrt_bindError(char*m)
 {
@@ -1423,7 +1401,7 @@ fprintf(f,(isSuper?"%s\t%s%s\tsuper\n":"%s\t%s%s\n"),nam,fac,sel);
 static id
 _errHandler(id self,SEL sel)
 {
-if(sel==selTransTbl[6])
+if(sel==selTransTbl[5])
 {
 char*msg;
 msg="Completely messed up: Object does not recognize -doesNotRecognize:";
@@ -1431,10 +1409,10 @@ return report(self,msg);
 }
 else
 {
-id objcT11;
+id objcT9;
 
-# 1653 "objcrt.m"
-return(objcT11=self,(*(id(*)(id,SEL,SEL))_imp(objcT11,selTransTbl[6]))(objcT11,selTransTbl[6],sel));
+# 1629 "objcrt.m"
+return(objcT9=self,(*(id(*)(id,SEL,SEL))_imp(objcT9,selTransTbl[5]))(objcT9,selTransTbl[5],sel));
 }
 }
 
@@ -1449,7 +1427,7 @@ _freedHandler(id self,SEL sel)
 {
 return report(self,"Message '%s' sent to freed object.",sel);
 }
-# 1672 "objcrt.m"
+# 1648 "objcrt.m"
 BOOL noNilRcvr=(BOOL)0;
 
 id
@@ -1457,7 +1435,7 @@ _nilHandler(id self,SEL sel)
 {
 return(noNilRcvr)?report(self,"Message '%s' sent to nil.",sel):(id)0;
 }
-# 1692 "objcrt.m"
+# 1668 "objcrt.m"
 static id clsCache[1031];
 static SEL selCache[1031];
 static IMP impCache[1031];
@@ -1477,7 +1455,7 @@ BOOL dbgFlag=(BOOL)0;
 BOOL allocFlag=(BOOL)0;
 FILE*dbgIOD;
 
-# 1742 "objcrt.m"
+# 1718 "objcrt.m"
 static IMP
 _getImp(id cls,SEL sel,int index,IMP fwd)
 {
@@ -1526,7 +1504,7 @@ return _errHandler;
 }
 }
 
-# 1797 "objcrt.m"
+# 1773 "objcrt.m"
 IMP
 _imp(id aRecvr,SEL aSel)
 {
@@ -1568,7 +1546,7 @@ return imp;
 }
 
 }
-# 1842 "objcrt.m"
+# 1818 "objcrt.m"
 if(ismeta((wCls=((Cls_t)(shr)))))
 {
 if( !initlzd(wCls))
@@ -1614,11 +1592,11 @@ return _getImp(aClass,aSel,index,fwd);
 # 37 "Message.h"
 extern id  Message;
 
-# 1884 "objcrt.m"
+# 1860 "objcrt.m"
 void
 fwdmsg(id self,SEL sel,void*args,ARGIMP disp)
 {
-if(sel==selTransTbl[7])
+if(sel==selTransTbl[6])
 {
 char*msg;
 msg="Completely messed up: Object does not understand -doesNotUnderstand:";
@@ -1626,12 +1604,12 @@ report(self,msg);
 }
 else
 {
-id objcT12,objcT13,objcT14;
+id objcT10,objcT11,objcT12;
 
-# 1895 "objcrt.m"
-id msg=(objcT12=Message,(*(id(*)(id,SEL,SEL,ARGIMP,void*))_imp(objcT12,selTransTbl[8]))(objcT12,selTransTbl[8],sel,disp,args));
-(objcT13=self,(*_imp(objcT13,selTransTbl[7]))(objcT13,selTransTbl[7],msg));
-msg=(objcT14=msg,(*_imp(objcT14,selTransTbl[9]))(objcT14,selTransTbl[9]));
+# 1871 "objcrt.m"
+id msg=(objcT10=Message,(*(id(*)(id,SEL,SEL,ARGIMP,void*))_imp(objcT10,selTransTbl[7]))(objcT10,selTransTbl[7],sel,disp,args));
+(objcT11=self,(*_imp(objcT11,selTransTbl[6]))(objcT11,selTransTbl[6],msg));
+msg=(objcT12=msg,(*_imp(objcT12,selTransTbl[8]))(objcT12,selTransTbl[8]));
 }
 }
 
@@ -1653,7 +1631,7 @@ fwdmsg(self,sel,p,(ARGIMP)selptrdisp);
 return p[0];
 }
 
-# 1924 "objcrt.m"
+# 1900 "objcrt.m"
 void
 dbg(char*fmt,...)
 {
@@ -1667,7 +1645,7 @@ fflush(dbgIOD);
 }
 }
 
-# 1944 "objcrt.m"
+# 1920 "objcrt.m"
 static struct objcrt_slt*
 newDispTable(int n)
 {
@@ -1713,25 +1691,25 @@ Cls_t dst=((Cls_t)(idst));
 
 if(src==dst)
 return;
-# 1995 "objcrt.m"
+# 1971 "objcrt.m"
 srcName=src->clsName;
 dstName=dst->clsName;
 
 if(src->clsSuper&&((Cls_t)(src->clsSuper))!=dst)
 {
-id objcT15;
+id objcT13;
 
-# 2000 "objcrt.m"
-(objcT15=isrc,(*(id(*)(id,SEL,STR,...))_imp(objcT15,selTransTbl[1]))(objcT15,selTransTbl[1],"addMethods: %s not direct subclass of %s.",
+# 1976 "objcrt.m"
+(objcT13=isrc,(*(id(*)(id,SEL,STR,...))_imp(objcT13,selTransTbl[1]))(objcT13,selTransTbl[1],"addMethods: %s not direct subclass of %s.",
 srcName,dstName));
 }
 
 if(src->clsSizInstance!=dst->clsSizInstance)
 {
-id objcT16;
+id objcT14;
 
-# 2006 "objcrt.m"
-(objcT16=isrc,(*(id(*)(id,SEL,STR,...))_imp(objcT16,selTransTbl[1]))(objcT16,selTransTbl[1],"addMethods: %s adds instance variables to %s.",
+# 1982 "objcrt.m"
+(objcT14=isrc,(*(id(*)(id,SEL,STR,...))_imp(objcT14,selTransTbl[1]))(objcT14,selTransTbl[1],"addMethods: %s adds instance variables to %s.",
 srcName,dstName));
 }
 
@@ -1742,11 +1720,11 @@ addnstmeth(getmeta(src),getmeta(dst));
 flushCache();
 }
 
-# 2023 "objcrt.m"
+# 1999 "objcrt.m"
 id
 swapclass(id self,id other)
 {
-# 2033 "objcrt.m"
+# 2009 "objcrt.m"
 return self;
 }
 
@@ -1762,36 +1740,36 @@ Cls_t target=((Cls_t)(itarget));
 
 if(posing==target)
 return;
-# 2054 "objcrt.m"
+# 2030 "objcrt.m"
 posingName=posing->clsName;
 targetName=target->clsName;
 
 if( !((target)->clsStatus&0x8L))
 {
-id objcT17;
+id objcT15;
 
-# 2059 "objcrt.m"
-(objcT17=itarget,(*(id(*)(id,SEL,STR,...))_imp(objcT17,selTransTbl[1]))(objcT17,selTransTbl[1],"poseAs: %s needs to be recompiled",targetName));
+# 2035 "objcrt.m"
+(objcT15=itarget,(*(id(*)(id,SEL,STR,...))_imp(objcT15,selTransTbl[1]))(objcT15,selTransTbl[1],"poseAs: %s needs to be recompiled",targetName));
 }
 
 if(posing->clsSuper&&((Cls_t)(posing->clsSuper))!=target)
 {
-id objcT18;
+id objcT16;
 
-# 2064 "objcrt.m"
-(objcT18=iposing,(*(id(*)(id,SEL,STR,...))_imp(objcT18,selTransTbl[1]))(objcT18,selTransTbl[1],"poseAs: %s not direct subclass of %s.",
+# 2040 "objcrt.m"
+(objcT16=iposing,(*(id(*)(id,SEL,STR,...))_imp(objcT16,selTransTbl[1]))(objcT16,selTransTbl[1],"poseAs: %s not direct subclass of %s.",
 posingName,targetName));
 }
 
 if(posing->clsSizInstance!=target->clsSizInstance)
 {
-id objcT19;
+id objcT17;
 
-# 2070 "objcrt.m"
-(objcT19=iposing,(*(id(*)(id,SEL,STR,...))_imp(objcT19,selTransTbl[1]))(objcT19,selTransTbl[1],"poseAs: %s adds instance variables to %s.",
+# 2046 "objcrt.m"
+(objcT17=iposing,(*(id(*)(id,SEL,STR,...))_imp(objcT17,selTransTbl[1]))(objcT17,selTransTbl[1],"poseAs: %s adds instance variables to %s.",
 posingName,targetName));
 }
-# 2079 "objcrt.m"
+# 2055 "objcrt.m"
 newName=(char*)OC_Malloc(strlen(targetName)+2+1);
 strcpy(newName,"_%");
 strcpy(newName+2,targetName);
@@ -1800,7 +1778,7 @@ posing->clsName=targetName;
 getmeta(posing)->clsName=getmeta(target)->clsName;
 target->clsName=newName+1;
 getmeta(target)->clsName=newName;
-# 2092 "objcrt.m"
+# 2068 "objcrt.m"
 for(m=modnodelist;m;m=m->next)
 {
 for(modPtr=m->objcmodules;modPtr&&modPtr->modLink;modPtr++)
@@ -1850,7 +1828,7 @@ if(target->clsGlbl) *
 flushCache();
 }
 
-# 2146 "objcrt.m"
+# 2122 "objcrt.m"
 static void
 initobjc(Mentry_t modPtr)
 {
@@ -1865,7 +1843,7 @@ Mentry_t modPtr=(Mentry_t)p;
 
 if( !modPtr)
 report((id)0,"loadobjc with NULL argument");
-# 2170 "objcrt.m"
+# 2146 "objcrt.m"
 modnodelist=newmodnode(modPtr,modnodelist);
 
 if( !objcinitflag)
@@ -1882,9 +1860,9 @@ return;
 void
 unloadobjc(void*p)
 {
-id objcT20;
+id objcT18;
 
-# 2186 "objcrt.m"
+# 2162 "objcrt.m"
 modnode_t m,*n;
 Mentry_t modPtr=(Mentry_t)p;
 
@@ -1905,14 +1883,13 @@ n= &(m->next);
 }
 }
 
-(objcT20=Object,(*(id(*)(id,SEL,STR,...))_imp(objcT20,selTransTbl[1]))(objcT20,selTransTbl[1],"unloadobjc() for module that is not loaded."));
+(objcT18=Object,(*(id(*)(id,SEL,STR,...))_imp(objcT18,selTransTbl[1]))(objcT18,selTransTbl[1],"unloadobjc() for module that is not loaded."));
 }
 static char *_selTransTbl[] ={
-"halt:",
+"signal",
 "error:",
 "initialize",
-"findClass:",
-"str:",
+"new",
 "add:",
 "doesNotRecognize:",
 "doesNotUnderstand:",
@@ -1922,12 +1899,12 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor objcrt_modDesc = {
   "objcrt",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
   0,
-  10,
+  9,
   _selTransTbl,
   0
 };
