@@ -116,7 +116,7 @@ int capacity;
 char*ptr;
 }*
 objstr_t;
-# 33 "ocstring.m"
+# 34 "ocstring.m"
 typedef struct
 {
 # 42 "../../include/objcrt/Object.h"
@@ -128,7 +128,7 @@ unsigned short objID;
 unsigned capacity;
 # 42 "ocstring.h"
 struct objstr value;
-# 36 "ocstring.m"
+# 37 "ocstring.m"
 }
 TFString;
 # 40 "ocstring.h"
@@ -152,7 +152,7 @@ extern struct _SHARED _String;
 extern struct _SHARED __String;
 
 
-# 47 "ocstring.m"
+# 48 "ocstring.m"
 static int
 str_len(char*s)
 {
@@ -201,7 +201,7 @@ static id c_String_new(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT0;
 
-# 93 "ocstring.m"
+# 94 "ocstring.m"
 return(objcT0=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0],(16)));
 }
 
@@ -209,7 +209,7 @@ static id c_String_new_(struct String_PRIVATE *self,SEL _cmd,unsigned nChars)
 {
 id objcT1,objcT2;
 
-# 98 "ocstring.m"
+# 99 "ocstring.m"
 id newObj=(objcT1=__String.clsSuper,(*_impSuper(objcT1,selTransTbl[1]))((id)self,selTransTbl[1]));
 init((objcT2=newObj,(*(objstr_t(*)(id,SEL))_imp(objcT2,selTransTbl[2]))(objcT2,selTransTbl[2])),"",0,nChars);
 return newObj;
@@ -227,10 +227,10 @@ if(aString)
 {
 id objcT3;
 
-# 113 "ocstring.m"
+# 114 "ocstring.m"
 id newObj=(objcT3=__String.clsSuper,(*_impSuper(objcT3,selTransTbl[1]))((id)self,selTransTbl[1]));
 int n=str_len(aString);
-# 120 "ocstring.m"
+# 121 "ocstring.m"
 initstr( &(((TFString*)newObj)->value),aString,n);
 
 return newObj;
@@ -239,7 +239,7 @@ else
 {
 id objcT4;
 
-# 126 "ocstring.m"
+# 127 "ocstring.m"
 return(objcT4=(id)self,(*_imp(objcT4,selTransTbl[1]))(objcT4,selTransTbl[1]));
 }
 }
@@ -250,9 +250,9 @@ if(aString)
 {
 id objcT5;
 
-# 134 "ocstring.m"
+# 135 "ocstring.m"
 id newObj=(objcT5=__String.clsSuper,(*_impSuper(objcT5,selTransTbl[1]))((id)self,selTransTbl[1]));
-# 140 "ocstring.m"
+# 141 "ocstring.m"
 initstr( &(((TFString*)newObj)->value),aString,n);
 
 return newObj;
@@ -261,7 +261,7 @@ else
 {
 id objcT6;
 
-# 146 "ocstring.m"
+# 147 "ocstring.m"
 return(objcT6=(id)self,(*_imp(objcT6,selTransTbl[1]))(objcT6,selTransTbl[1]));
 }
 }
@@ -270,9 +270,9 @@ static id c_String_vsprintf__(struct String_PRIVATE *self,SEL _cmd,STR format,va
 {
 id objcT7;
 
-# 152 "ocstring.m"
+# 153 "ocstring.m"
 char aBuffer[(2048)];
-# 160 "ocstring.m"
+# 162 "ocstring.m"
 vsprintf(aBuffer,format, *ap);
 
 
@@ -283,7 +283,7 @@ static id c_String_sprintf_(struct String_PRIVATE *self,SEL _cmd,STR format,...)
 {
 id objcT8;
 
-# 168 "ocstring.m"
+# 170 "ocstring.m"
 id newString;
 
 
@@ -311,7 +311,7 @@ static id i_String_copy(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT9,objcT10;
 
-# 193 "ocstring.m"
+# 195 "ocstring.m"
 id aCopy=(objcT9=_String.clsSuper,(*_impSuper(objcT9,selTransTbl[5]))((id)self,selTransTbl[5]));
 copy((objcT10=aCopy,(*(objstr_t(*)(id,SEL))_imp(objcT10,selTransTbl[2]))(objcT10,selTransTbl[2])),( &self->value));
 return aCopy;
@@ -321,7 +321,7 @@ static id i_String_deepCopy(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT11;
 
-# 200 "ocstring.m"
+# 202 "ocstring.m"
 return(objcT11=(id)self,(*_imp(objcT11,selTransTbl[5]))(objcT11,selTransTbl[5]));
 }
 
@@ -336,7 +336,7 @@ static id i_String_free(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT12;
 
-# 212 "ocstring.m"
+# 214 "ocstring.m"
 clear(( &self->value));
 return(objcT12=_String.clsSuper,(*_impSuper(objcT12,selTransTbl[6]))((id)self,selTransTbl[6]));
 }
@@ -351,7 +351,7 @@ return(objcT13=(id)self,(*(id(*)(id,SEL,SEL))_imp(objcT13,selTransTbl[7]))(objcT
 
 }
 
-# 232 "ocstring.m"
+# 234 "ocstring.m"
 static int
 str_cmp(char*s1,char*s2)
 {
@@ -383,7 +383,7 @@ static int i_String_compare_(struct String_PRIVATE *self,SEL _cmd,id aStr)
 {
 id objcT14;
 
-# 261 "ocstring.m"
+# 263 "ocstring.m"
 return((id)self==aStr)?0:cmpstr(( &self->value),(objcT14=aStr,(*(STR(*)(id,SEL))_imp(objcT14,selTransTbl[8]))(objcT14,selTransTbl[8])));
 }
 
@@ -468,7 +468,7 @@ static int i_String_dictCompare_(struct String_PRIVATE *self,SEL _cmd,id aStr)
 {
 id objcT15;
 
-# 343 "ocstring.m"
+# 345 "ocstring.m"
 return dictcmp(( &self->value),(objcT15=aStr,(*(objstr_t(*)(id,SEL))_imp(objcT15,selTransTbl[2]))(objcT15,selTransTbl[2])));
 }
 
@@ -476,7 +476,7 @@ static BOOL i_String_isEqual_(struct String_PRIVATE *self,SEL _cmd,id aStr)
 {
 id objcT16;
 
-# 348 "ocstring.m"
+# 350 "ocstring.m"
 return((id)self==aStr)?(BOOL)1:((objcT16=(id)self,(*(int(*)(id,SEL,id))_imp(objcT16,selTransTbl[9]))(objcT16,selTransTbl[9],aStr))==0);
 }
 
@@ -484,11 +484,11 @@ static BOOL i_String_isEqualSTR_(struct String_PRIVATE *self,SEL _cmd,STR aStrin
 {
 id objcT17;
 
-# 353 "ocstring.m"
+# 355 "ocstring.m"
 return(objcT17=(id)self,(*(int(*)(id,SEL,STR))_imp(objcT17,selTransTbl[10]))(objcT17,selTransTbl[10],aString))==0;
 }
 
-# 362 "ocstring.m"
+# 364 "ocstring.m"
 static objstr_t i_String_objstrvalue(struct String_PRIVATE *self,SEL _cmd)
 {
 return &self->value;
@@ -543,12 +543,12 @@ static char i_String_charAt_put_(struct String_PRIVATE *self,SEL _cmd,unsigned a
 return putcharat(( &self->value),anOffset,aChar);
 }
 
-# 422 "ocstring.m"
+# 424 "ocstring.m"
 static STR i_String_strcat_(struct String_PRIVATE *self,SEL _cmd,STR aBuffer)
 {
 id objcT18;
 
-# 424 "ocstring.m"
+# 426 "ocstring.m"
 str_cpy(aBuffer+str_len(aBuffer),(objcT18=(id)self,(*(STR(*)(id,SEL))_imp(objcT18,selTransTbl[8]))(objcT18,selTransTbl[8])));
 return aBuffer;
 }
@@ -575,7 +575,7 @@ static id i_String_concat_(struct String_PRIVATE *self,SEL _cmd,id aString)
 {
 id objcT19,objcT20;
 
-# 448 "ocstring.m"
+# 450 "ocstring.m"
 return(objcT19=(id)self,(*(id(*)(id,SEL,STR))_imp(objcT19,selTransTbl[11]))(objcT19,selTransTbl[11],(objcT20=aString,(*(STR(*)(id,SEL))_imp(objcT20,selTransTbl[8]))(objcT20,selTransTbl[8]))));
 }
 
@@ -589,7 +589,7 @@ static id i_String_concatenateSTR_(struct String_PRIVATE *self,SEL _cmd,STR aStr
 {
 id objcT21;
 
-# 459 "ocstring.m"
+# 461 "ocstring.m"
 return(objcT21=(id)self,(*(id(*)(id,SEL,STR))_imp(objcT21,selTransTbl[11]))(objcT21,selTransTbl[11],aString));
 }
 
@@ -626,7 +626,7 @@ static id i_String_at_insert_(struct String_PRIVATE *self,SEL _cmd,unsigned anOf
 {
 id objcT22,objcT23,objcT24;
 
-# 493 "ocstring.m"
+# 495 "ocstring.m"
 return(objcT22=(id)self,(*(id(*)(id,SEL,unsigned,char*,int))_imp(objcT22,selTransTbl[12]))(objcT22,selTransTbl[12],anOffset,(objcT23=aString,(*(STR(*)(id,SEL))_imp(objcT23,selTransTbl[8]))(objcT23,selTransTbl[8])),(objcT24=aString,(*(unsigned(*)(id,SEL))_imp(objcT24,selTransTbl[13]))(objcT24,selTransTbl[13]))));
 }
 
@@ -647,17 +647,22 @@ self->count-=n;
 (self->ptr)[self->count]='\0';
 }
 
+# 28 "outofbnd.h"
+extern id  OutOfBounds;
+
+# 515 "ocstring.m"
 static id i_String_deleteFrom_to_(struct String_PRIVATE *self,SEL _cmd,unsigned p,unsigned q)
 {
 id objcT25;
 
-# 515 "ocstring.m"
+# 517 "ocstring.m"
 if(q>=(objcT25=(id)self,(*(unsigned(*)(id,SEL))_imp(objcT25,selTransTbl[13]))(objcT25,selTransTbl[13]))||p>q)
 {
 id objcT26;
 
-# 517 "ocstring.m"
-return(objcT26=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT26,selTransTbl[14]))(objcT26,selTransTbl[14],"bounds error"));
+# 519 "ocstring.m"
+(objcT26=OutOfBounds,(*_imp(objcT26,selTransTbl[14]))(objcT26,selTransTbl[14]));
+return(id)self;
 }
 else
 {
@@ -689,12 +694,12 @@ assign(( &self->value),aString,nChars);
 return(id)self;
 }
 
-# 555 "ocstring.m"
+# 558 "ocstring.m"
 static double i_String_asDouble(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT27;
 
-# 557 "ocstring.m"
+# 560 "ocstring.m"
 return atof((objcT27=(id)self,(*(STR(*)(id,SEL))_imp(objcT27,selTransTbl[8]))(objcT27,selTransTbl[8])));
 }
 
@@ -702,7 +707,7 @@ static int i_String_asInt(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT28;
 
-# 562 "ocstring.m"
+# 565 "ocstring.m"
 return atoi((objcT28=(id)self,(*(STR(*)(id,SEL))_imp(objcT28,selTransTbl[8]))(objcT28,selTransTbl[8])));
 }
 
@@ -710,7 +715,7 @@ static long i_String_asLong(struct String_PRIVATE *self,SEL _cmd)
 {
 id objcT29;
 
-# 567 "ocstring.m"
+# 570 "ocstring.m"
 return atol((objcT29=(id)self,(*(STR(*)(id,SEL))_imp(objcT29,selTransTbl[8]))(objcT29,selTransTbl[8])));
 }
 
@@ -718,7 +723,7 @@ static id i_String_asSTR_maxSize_(struct String_PRIVATE *self,SEL _cmd,STR aBuff
 {
 id objcT30;
 
-# 572 "ocstring.m"
+# 575 "ocstring.m"
 str_ncpy(aBuffer,(objcT30=(id)self,(*(STR(*)(id,SEL))_imp(objcT30,selTransTbl[8]))(objcT30,selTransTbl[8])),aSize);
 return(id)self;
 }
@@ -735,7 +740,7 @@ copy( &aCopy,( &self->value));
 return aCopy.ptr;
 }
 
-# 594 "ocstring.m"
+# 597 "ocstring.m"
 static void
 strtolower(char*s)
 {
@@ -780,23 +785,23 @@ objtoupper(( &self->value));
 return(id)self;
 }
 
-# 644 "ocstring.m"
+# 647 "ocstring.m"
 static id i_String_printOn_(struct String_PRIVATE *self,SEL _cmd,IOD aFile)
 {
 id objcT31;
 
-# 646 "ocstring.m"
+# 649 "ocstring.m"
 fprintf(aFile,"%s",(objcT31=(id)self,(*(STR(*)(id,SEL))_imp(objcT31,selTransTbl[8]))(objcT31,selTransTbl[8])));
 return(id)self;
 }
 
-# 657 "ocstring.m"
+# 660 "ocstring.m"
 static void
 fileout(id aFiler,objstr_t self)
 {
 id objcT32,objcT33,objcT34;
 
-# 660 "ocstring.m"
+# 663 "ocstring.m"
 (objcT32=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT32,selTransTbl[15]))(objcT32,selTransTbl[15], &self->count,'i'));
 (objcT33=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT33,selTransTbl[15]))(objcT33,selTransTbl[15], &self->capacity,'i'));
 (objcT34=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT34,selTransTbl[15]))(objcT34,selTransTbl[15], &self->ptr,'*'));
@@ -807,7 +812,7 @@ filein(id aFiler,objstr_t self)
 {
 id objcT35,objcT36,objcT37;
 
-# 668 "ocstring.m"
+# 671 "ocstring.m"
 int c;
 
 (objcT35=aFiler,(*(id(*)(id,SEL,void*,char))_imp(objcT35,selTransTbl[16]))(objcT35,selTransTbl[16], &self->count,'i'));
@@ -821,7 +826,7 @@ static id i_String_fileOutOn_(struct String_PRIVATE *self,SEL _cmd,id aFiler)
 {
 id objcT38;
 
-# 679 "ocstring.m"
+# 682 "ocstring.m"
 (objcT38=_String.clsSuper,(*_impSuper(objcT38,selTransTbl[17]))((id)self,selTransTbl[17],aFiler));
 fileout(aFiler, &self->value);
 return(id)self;
@@ -831,7 +836,7 @@ static id i_String_fileInFrom_(struct String_PRIVATE *self,SEL _cmd,id aFiler)
 {
 id objcT39;
 
-# 686 "ocstring.m"
+# 689 "ocstring.m"
 (objcT39=_String.clsSuper,(*_impSuper(objcT39,selTransTbl[18]))((id)self,selTransTbl[18],aFiler));
 filein(aFiler, &self->value);
 return(id)self;
@@ -937,7 +942,7 @@ static char *_selTransTbl[] ={
 "concatSTR:",
 "at:insert:count:",
 "size",
-"error:",
+"signal",
 "fileOut:type:",
 "fileIn:type:",
 "fileOutOn:",
@@ -946,7 +951,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor ocstring_modDesc = {
   "ocstring",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
