@@ -136,12 +136,12 @@ extern struct _SHARED _Text;
 extern struct _SHARED __Text;
 
 
-# 37 "octext.m"
+# 38 "octext.m"
 static id i_Text_check(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT0;
 
-# 39 "octext.m"
+# 40 "octext.m"
 (objcT0=self->runs,(*_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0]));
 (void)0;
 return(id)self;
@@ -150,12 +150,12 @@ return(id)self;
 # 40 "ocstring.h"
 extern id  String;
 
-# 44 "octext.m"
+# 45 "octext.m"
 static id c_Text_new(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT1,objcT2;
 
-# 46 "octext.m"
+# 47 "octext.m"
 return(objcT1=(id)self,(*_imp(objcT1,selTransTbl[1]))(objcT1,selTransTbl[1],(objcT2=String,(*_imp(objcT2,selTransTbl[2]))(objcT2,selTransTbl[2]))));
 }
 
@@ -163,7 +163,7 @@ static id c_Text_new_(struct Text_PRIVATE *self,SEL _cmd,unsigned nChars)
 {
 id objcT3,objcT4;
 
-# 51 "octext.m"
+# 52 "octext.m"
 return(objcT3=(id)self,(*_imp(objcT3,selTransTbl[1]))(objcT3,selTransTbl[1],(objcT4=String,(*(id(*)(id,SEL,unsigned))_imp(objcT4,selTransTbl[3]))(objcT4,selTransTbl[3],nChars))));
 }
 
@@ -171,9 +171,9 @@ static id c_Text_vsprintf__(struct Text_PRIVATE *self,SEL _cmd,STR format,va_lis
 {
 id objcT5;
 
-# 56 "octext.m"
+# 57 "octext.m"
 char aBuffer[(2048)];
-# 64 "octext.m"
+# 66 "octext.m"
 vsprintf(aBuffer,format, *ap);
 
 
@@ -184,7 +184,7 @@ static id c_Text_str_(struct Text_PRIVATE *self,SEL _cmd,STR aString)
 {
 id objcT6,objcT7;
 
-# 72 "octext.m"
+# 74 "octext.m"
 return(objcT6=(id)self,(*_imp(objcT6,selTransTbl[1]))(objcT6,selTransTbl[1],(objcT7=String,(*(id(*)(id,SEL,STR))_imp(objcT7,selTransTbl[4]))(objcT7,selTransTbl[4],aString))));;
 }
 
@@ -192,7 +192,7 @@ static id c_Text_sprintf_(struct Text_PRIVATE *self,SEL _cmd,STR format,...)
 {
 id objcT8;
 
-# 77 "octext.m"
+# 79 "octext.m"
 id newtext;
 
 
@@ -206,12 +206,12 @@ return newtext;
 # 28 "runarray.h"
 extern id  RunArray;
 
-# 87 "octext.m"
+# 89 "octext.m"
 static id c_Text_fromString_(struct Text_PRIVATE *self,SEL _cmd,id aString)
 {
 id objcT9,objcT10,objcT11;
 
-# 89 "octext.m"
+# 91 "octext.m"
 return(objcT9=(objcT10=__Text.clsSuper,(*_impSuper(objcT10,selTransTbl[2]))((id)self,selTransTbl[2])),(*_imp(objcT9,selTransTbl[6]))(objcT9,selTransTbl[6],aString,(objcT11=RunArray,(*_imp(objcT11,selTransTbl[2]))(objcT11,selTransTbl[2]))));
 }
 
@@ -219,7 +219,7 @@ static id c_Text_string_attribute_(struct Text_PRIVATE *self,SEL _cmd,id aString
 {
 id objcT12,objcT13;
 
-# 94 "octext.m"
+# 96 "octext.m"
 return(objcT12=(objcT13=(id)self,(*_imp(objcT13,selTransTbl[1]))(objcT13,selTransTbl[1],aString)),(*_imp(objcT12,selTransTbl[7]))(objcT12,selTransTbl[7],attrib));
 }
 
@@ -234,7 +234,7 @@ static id i_Text_copy(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT14,objcT15,objcT16,objcT17;
 
-# 106 "octext.m"
+# 108 "octext.m"
 return(objcT14=(objcT15=self->isa,(*_imp(objcT15,selTransTbl[2]))(objcT15,selTransTbl[2])),(*_imp(objcT14,selTransTbl[6]))(objcT14,selTransTbl[6],(objcT16=self->string,(*_imp(objcT16,selTransTbl[8]))(objcT16,selTransTbl[8])),(objcT17=self->runs,(*_imp(objcT17,selTransTbl[8]))(objcT17,selTransTbl[8]))));
 }
 
@@ -242,7 +242,7 @@ static id i_Text_free(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT18,objcT19,objcT20;
 self->
-# 111 "octext.m"
+# 113 "octext.m"
 string=(objcT18=self->string,(*_imp(objcT18,selTransTbl[9]))(objcT18,selTransTbl[9]));self->
 runs=(objcT19=self->runs,(*_imp(objcT19,selTransTbl[9]))(objcT19,selTransTbl[9]));
 return(objcT20=_Text.clsSuper,(*_impSuper(objcT20,selTransTbl[9]))((id)self,selTransTbl[9]));
@@ -253,7 +253,7 @@ static unsigned i_Text_hash(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT21;
 
-# 119 "octext.m"
+# 121 "octext.m"
 return(objcT21=self->string,(*(unsigned(*)(id,SEL))_imp(objcT21,selTransTbl[10]))(objcT21,selTransTbl[10]));
 }
 
@@ -261,7 +261,7 @@ static BOOL i_Text_isEqual_(struct Text_PRIVATE *self,SEL _cmd,id aStr)
 {
 id objcT22,objcT23;
 
-# 124 "octext.m"
+# 126 "octext.m"
 (objcT22=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT22,selTransTbl[11]))(objcT22,selTransTbl[11],(objcT23=self->string,(*(unsigned(*)(id,SEL))_imp(objcT23,selTransTbl[12]))(objcT23,selTransTbl[12]))));
 if((id)self==aStr)
 {
@@ -271,7 +271,7 @@ else
 {
 id objcT24,objcT25,objcT26,objcT27;
 
-# 131 "octext.m"
+# 133 "octext.m"
 return(objcT24=self->string,(*(BOOL(*)(id,SEL,id))_imp(objcT24,selTransTbl[13]))(objcT24,selTransTbl[13],(objcT25=aStr,(*_imp(objcT25,selTransTbl[14]))(objcT25,selTransTbl[14]))))&&(objcT26=self->runs,(*(BOOL(*)(id,SEL,id))_imp(objcT26,selTransTbl[13]))(objcT26,selTransTbl[13],(objcT27=aStr,(*_imp(objcT27,selTransTbl[15]))(objcT27,selTransTbl[15]))));
 }
 }
@@ -286,7 +286,7 @@ static id i_Text_runs(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT28,objcT29;
 
-# 143 "octext.m"
+# 145 "octext.m"
 (objcT28=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT28,selTransTbl[11]))(objcT28,selTransTbl[11],(objcT29=self->string,(*(unsigned(*)(id,SEL))_imp(objcT29,selTransTbl[12]))(objcT29,selTransTbl[12]))));
 return self->runs;
 }
@@ -295,7 +295,7 @@ static STR i_Text_str(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT30;
 
-# 149 "octext.m"
+# 151 "octext.m"
 return(objcT30=self->string,(*(STR(*)(id,SEL))_imp(objcT30,selTransTbl[16]))(objcT30,selTransTbl[16]));
 }
 
@@ -303,7 +303,7 @@ static unsigned i_Text_size(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT31;
 
-# 154 "octext.m"
+# 156 "octext.m"
 return(objcT31=self->string,(*(unsigned(*)(id,SEL))_imp(objcT31,selTransTbl[12]))(objcT31,selTransTbl[12]));
 }
 
@@ -311,7 +311,7 @@ static char i_Text_charAt_(struct Text_PRIVATE *self,SEL _cmd,unsigned anOffset)
 {
 id objcT32;
 
-# 159 "octext.m"
+# 161 "octext.m"
 return(objcT32=self->string,(*(char(*)(id,SEL,unsigned))_imp(objcT32,selTransTbl[17]))(objcT32,selTransTbl[17],anOffset));
 }
 
@@ -319,7 +319,7 @@ static char i_Text_charAt_put_(struct Text_PRIVATE *self,SEL _cmd,unsigned anOff
 {
 id objcT33;
 
-# 164 "octext.m"
+# 166 "octext.m"
 return(objcT33=self->string,(*(char(*)(id,SEL,unsigned,char))_imp(objcT33,selTransTbl[18]))(objcT33,selTransTbl[18],anOffset,aChar));
 }
 
@@ -327,7 +327,7 @@ static id i_Text_at_insert_(struct Text_PRIVATE *self,SEL _cmd,unsigned anOffset
 {
 id objcT34,objcT35,objcT36;
 
-# 169 "octext.m"
+# 171 "octext.m"
 return(objcT34=(id)self,(*(id(*)(id,SEL,unsigned,char*,int))_imp(objcT34,selTransTbl[19]))(objcT34,selTransTbl[19],anOffset,(objcT35=aString,(*(STR(*)(id,SEL))_imp(objcT35,selTransTbl[16]))(objcT35,selTransTbl[16])),(objcT36=aString,(*(unsigned(*)(id,SEL))_imp(objcT36,selTransTbl[12]))(objcT36,selTransTbl[12]))));
 }
 
@@ -335,7 +335,7 @@ static id i_Text_at_insert_count_(struct Text_PRIVATE *self,SEL _cmd,unsigned an
 {
 id objcT37,objcT38;
 
-# 174 "octext.m"
+# 176 "octext.m"
 (objcT37=self->string,(*(id(*)(id,SEL,unsigned,char*,int))_imp(objcT37,selTransTbl[19]))(objcT37,selTransTbl[19],anOffset,aString,size));
 (objcT38=self->runs,(*(id(*)(id,SEL,unsigned,char*,int))_imp(objcT38,selTransTbl[19]))(objcT38,selTransTbl[19],anOffset,aString,size));
 return(id)self;
@@ -345,7 +345,7 @@ static id i_Text_deleteFrom_to_(struct Text_PRIVATE *self,SEL _cmd,unsigned p,un
 {
 id objcT39,objcT40;
 
-# 181 "octext.m"
+# 183 "octext.m"
 (objcT39=self->string,(*(id(*)(id,SEL,unsigned,unsigned))_imp(objcT39,selTransTbl[20]))(objcT39,selTransTbl[20],p,q));
 (objcT40=self->runs,(*(id(*)(id,SEL,unsigned,unsigned))_imp(objcT40,selTransTbl[20]))(objcT40,selTransTbl[20],p,q));
 return(id)self;
@@ -355,7 +355,7 @@ static id i_Text_concat_(struct Text_PRIVATE *self,SEL _cmd,id b)
 {
 id objcT41,objcT42,objcT43,objcT44;
 
-# 188 "octext.m"
+# 190 "octext.m"
 (objcT41=self->string,(*_imp(objcT41,selTransTbl[21]))(objcT41,selTransTbl[21],(objcT42=b,(*_imp(objcT42,selTransTbl[14]))(objcT42,selTransTbl[14]))));
 (objcT43=self->runs,(*_imp(objcT43,selTransTbl[21]))(objcT43,selTransTbl[21],(objcT44=b,(*_imp(objcT44,selTransTbl[15]))(objcT44,selTransTbl[15]))));
 return(id)self;
@@ -365,7 +365,7 @@ static id i_Text_concatSTR_(struct Text_PRIVATE *self,SEL _cmd,STR b)
 {
 id objcT45,objcT46,objcT47;
 
-# 195 "octext.m"
+# 197 "octext.m"
 (objcT45=self->string,(*(id(*)(id,SEL,STR))_imp(objcT45,selTransTbl[22]))(objcT45,selTransTbl[22],b));
 (objcT46=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT46,selTransTbl[11]))(objcT46,selTransTbl[11],(objcT47=self->string,(*(unsigned(*)(id,SEL))_imp(objcT47,selTransTbl[12]))(objcT47,selTransTbl[12]))));
 return(id)self;
@@ -374,12 +374,12 @@ return(id)self;
 # 32 "txtattr.h"
 extern id  TextAttribute;
 
-# 201 "octext.m"
+# 203 "octext.m"
 static id i_Text_allBold(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT48,objcT49;
 
-# 203 "octext.m"
+# 205 "octext.m"
 (objcT48=(id)self,(*_imp(objcT48,selTransTbl[7]))(objcT48,selTransTbl[7],(objcT49=TextAttribute,(*_imp(objcT49,selTransTbl[23]))(objcT49,selTransTbl[23]))));
 return(id)self;
 }
@@ -388,7 +388,7 @@ static id i_Text_makeBoldFrom_to_(struct Text_PRIVATE *self,SEL _cmd,unsigned p,
 {
 id objcT50,objcT51;
 
-# 209 "octext.m"
+# 211 "octext.m"
 (objcT50=(id)self,(*(id(*)(id,SEL,id,unsigned,unsigned))_imp(objcT50,selTransTbl[24]))(objcT50,selTransTbl[24],(objcT51=TextAttribute,(*_imp(objcT51,selTransTbl[23]))(objcT51,selTransTbl[23])),p,q));
 return(id)self;
 }
@@ -397,20 +397,30 @@ static id i_Text_addAttribute_(struct Text_PRIVATE *self,SEL _cmd,id attribute)
 {
 id objcT52,objcT53;
 
-# 215 "octext.m"
+# 217 "octext.m"
 unsigned n=(objcT52=self->string,(*(unsigned(*)(id,SEL))_imp(objcT52,selTransTbl[12]))(objcT52,selTransTbl[12]));
 (objcT53=self->runs,(*(id(*)(id,SEL,id,unsigned,unsigned))_imp(objcT53,selTransTbl[25]))(objcT53,selTransTbl[25],attribute,0,n));
 return(id)self;
 }
 
-static id i_Text_addAttribute_from_to_(struct Text_PRIVATE *self,SEL _cmd,id attribute,unsigned p,unsigned q)
-{
-id objcT54,objcT55,objcT56;
+# 28 "outofbnd.h"
+extern id  OutOfBounds;
 
 # 222 "octext.m"
+static id i_Text_addAttribute_from_to_(struct Text_PRIVATE *self,SEL _cmd,id attribute,unsigned p,unsigned q)
+{
+id objcT54,objcT56;
+
+# 224 "octext.m"
 unsigned n=(objcT54=self->string,(*(unsigned(*)(id,SEL))_imp(objcT54,selTransTbl[12]))(objcT54,selTransTbl[12]));
 if(p>q||q>=n)
-(objcT55=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT55,selTransTbl[26]))(objcT55,selTransTbl[26],"Index out of range."));
+{
+id objcT55;
+
+# 227 "octext.m"
+(objcT55=OutOfBounds,(*_imp(objcT55,selTransTbl[26]))(objcT55,selTransTbl[26]));
+return(id)self;
+}
 (objcT56=self->runs,(*(id(*)(id,SEL,id,unsigned,unsigned))_imp(objcT56,selTransTbl[25]))(objcT56,selTransTbl[25],attribute,p,q-p+1));
 (void)0;
 return(id)self;
@@ -420,7 +430,7 @@ static id i_Text_attributesAt_(struct Text_PRIVATE *self,SEL _cmd,unsigned i)
 {
 id objcT57,objcT58,objcT59;
 
-# 232 "octext.m"
+# 237 "octext.m"
 (objcT57=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT57,selTransTbl[11]))(objcT57,selTransTbl[11],(objcT58=self->string,(*(unsigned(*)(id,SEL))_imp(objcT58,selTransTbl[12]))(objcT58,selTransTbl[12]))));
 return(objcT59=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT59,selTransTbl[27]))(objcT59,selTransTbl[27],i));
 }
@@ -429,7 +439,7 @@ static unsigned i_Text_runLengthFor_(struct Text_PRIVATE *self,SEL _cmd,unsigned
 {
 id objcT60,objcT61,objcT62;
 
-# 238 "octext.m"
+# 243 "octext.m"
 (objcT60=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT60,selTransTbl[11]))(objcT60,selTransTbl[11],(objcT61=self->string,(*(unsigned(*)(id,SEL))_imp(objcT61,selTransTbl[12]))(objcT61,selTransTbl[12]))));
 return(objcT62=self->runs,(*(unsigned(*)(id,SEL,unsigned))_imp(objcT62,selTransTbl[28]))(objcT62,selTransTbl[28],i));
 }
@@ -438,7 +448,7 @@ static unsigned i_Text_fontNumberAt_(struct Text_PRIVATE *self,SEL _cmd,unsigned
 {
 id objcT63,objcT64,objcT65;
 
-# 244 "octext.m"
+# 249 "octext.m"
 (objcT63=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT63,selTransTbl[11]))(objcT63,selTransTbl[11],(objcT64=self->string,(*(unsigned(*)(id,SEL))_imp(objcT64,selTransTbl[12]))(objcT64,selTransTbl[12]))));
 return(objcT65=self->runs,(*(unsigned(*)(id,SEL,unsigned))_imp(objcT65,selTransTbl[29]))(objcT65,selTransTbl[29],i));
 }
@@ -447,7 +457,7 @@ static id i_Text_fontAt_withStyle_(struct Text_PRIVATE *self,SEL _cmd,unsigned i
 {
 id objcT66,objcT67,objcT68;
 
-# 250 "octext.m"
+# 255 "octext.m"
 (objcT66=self->runs,(*(id(*)(id,SEL,unsigned))_imp(objcT66,selTransTbl[11]))(objcT66,selTransTbl[11],(objcT67=self->string,(*(unsigned(*)(id,SEL))_imp(objcT67,selTransTbl[12]))(objcT67,selTransTbl[12]))));
 return(objcT68=self->runs,(*(id(*)(id,SEL,unsigned,id))_imp(objcT68,selTransTbl[30]))(objcT68,selTransTbl[30],i,textStyle));
 }
@@ -466,12 +476,12 @@ return(id)self;
 # 32 "paragrph.h"
 extern id  Paragraph;
 
-# 265 "octext.m"
+# 270 "octext.m"
 static id i_Text_asParagraph(struct Text_PRIVATE *self,SEL _cmd)
 {
 id objcT69;
 
-# 267 "octext.m"
+# 272 "octext.m"
 return(objcT69=Paragraph,(*_imp(objcT69,selTransTbl[31]))(objcT69,selTransTbl[31],(id)self));
 }
 
@@ -480,7 +490,7 @@ static id i_Text_printOn_(struct Text_PRIVATE *self,SEL _cmd,IOD aFile)
 {
 id objcT70;
 
-# 273 "octext.m"
+# 278 "octext.m"
 fprintf(aFile,"Text for ");
 (objcT70=self->string,(*(id(*)(id,SEL,IOD))_imp(objcT70,selTransTbl[32]))(objcT70,selTransTbl[32],aFile));
 return(id)self;
@@ -591,7 +601,7 @@ static char *_selTransTbl[] ={
 "bold",
 "addAttribute:from:to:",
 "addAttribute:from:size:",
-"error:",
+"signal",
 "at:",
 "runLengthAt:",
 "fontNumberAt:",
@@ -602,7 +612,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor octext_modDesc = {
   "octext",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
