@@ -47,6 +47,7 @@ void defoptions(void);
 
 extern int o_warnings;
 extern int o_gnu;
+extern int o_hpux;
 extern int o_vms;
 extern int o_refcnt;
 extern int o_ppi;
@@ -111,6 +112,7 @@ extern int o_stepnext;
 int o_warnings;
 int o_gnu;
 int o_vms;
+int o_hpux;
 int o_refcnt;
 int o_ppi;
 int o_watcom;
@@ -214,6 +216,7 @@ o_msdos=0;
 o_gnu=0;
 o_warnings=1;
 o_vms=0;
+o_hpux=0;
 o_refcnt=0;
 o_cplus=0;
 o_debuginfo=0;
@@ -241,7 +244,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor options_modDesc = {
   "options",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
