@@ -193,7 +193,7 @@ id mkbitfielddecl(id decl,id expr);
 id mkstardecl(id pointer,id decl);
 id mkasmop(id string,id expr);
 id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
-id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
+id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
 id mklist(id c,id s);
 id mklist2(id c,id s,id t);
 id atdefsaddall(id c,id n);
@@ -359,7 +359,7 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor parmlist_modDesc = {
   "parmlist",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
