@@ -147,7 +147,7 @@ extern struct _SHARED _RunArray;
 extern struct _SHARED __RunArray;
 
 
-# 34 "runarray.m"
+# 36 "runarray.m"
 static id i_RunArray_reset(struct RunArray_PRIVATE *self,SEL _cmd)
 {self->
 laststart= -1;
@@ -158,7 +158,7 @@ static id i_RunArray_check(struct RunArray_PRIVATE *self,SEL _cmd)
 {
 id objcT0;
 
-# 42 "runarray.m"
+# 44 "runarray.m"
 int i,n;
 id attrs;
 unsigned s;
@@ -170,7 +170,7 @@ for(i=0,n=(objcT0=self->values,(*(unsigned(*)(id,SEL))_imp(objcT0,selTransTbl[0]
 {
 id objcT1,objcT2;
 
-# 51 "runarray.m"
+# 53 "runarray.m"
 attrs=(objcT1=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT1,selTransTbl[1]))(objcT1,selTransTbl[1],i));
 (void)0;
 s=(objcT2=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT2,selTransTbl[2]))(objcT2,selTransTbl[2],i));
@@ -188,12 +188,12 @@ extern id  IntArray;
 # 39 "ordcltn.h"
 extern id  OrdCltn;
 
-# 62 "runarray.m"
+# 64 "runarray.m"
 static id c_RunArray_new(struct RunArray_PRIVATE *self,SEL _cmd)
 {
 id objcT3,objcT4,objcT5,objcT6;
 
-# 64 "runarray.m"
+# 66 "runarray.m"
 return(objcT3=(objcT4=__RunArray.clsSuper,(*_impSuper(objcT4,selTransTbl[3]))((id)self,selTransTbl[3])),(*_imp(objcT3,selTransTbl[4]))(objcT3,selTransTbl[4],(objcT5=IntArray,(*_imp(objcT5,selTransTbl[3]))(objcT5,selTransTbl[3])),(objcT6=OrdCltn,(*_imp(objcT6,selTransTbl[3]))(objcT6,selTransTbl[3]))));
 }
 
@@ -201,7 +201,7 @@ static id i_RunArray_free(struct RunArray_PRIVATE *self,SEL _cmd)
 {
 id objcT7,objcT8,objcT9,objcT10,objcT11;
 
-# 69 "runarray.m"
+# 71 "runarray.m"
 (objcT7=self->values,(*(id(*)(id,SEL,SEL))_imp(objcT7,selTransTbl[5]))(objcT7,selTransTbl[5],selTransTbl[6]));
 (objcT8=(objcT9=self->values,(*_imp(objcT9,selTransTbl[6]))(objcT9,selTransTbl[6])),(*_imp(objcT8,selTransTbl[7]))(objcT8,selTransTbl[7]));
 (objcT10=self->runs,(*_imp(objcT10,selTransTbl[7]))(objcT10,selTransTbl[7]));
@@ -223,54 +223,67 @@ static id i_RunArray_runs_values_(struct RunArray_PRIVATE *self,SEL _cmd,id r,id
 {
 id objcT12;
 self->
-# 88 "runarray.m"
+# 90 "runarray.m"
 runs=r;self->
 values=v;
 (objcT12=(id)self,(*_imp(objcT12,selTransTbl[8]))(objcT12,selTransTbl[8]));
 return(id)self;
 }
 
-static id i_RunArray_at_(struct RunArray_PRIVATE *self,SEL _cmd,unsigned i)
-{
-id objcT13,objcT17,objcT20;
+# 28 "outofbnd.h"
+extern id  OutOfBounds;
+
+# 28 "notfound.h"
+extern id  NotFound;
 
 # 96 "runarray.m"
+static id i_RunArray_at_(struct RunArray_PRIVATE *self,SEL _cmd,unsigned i)
+{
+id objcT17,objcT20;
+
+# 98 "runarray.m"
 int j,n;
 unsigned p;
 
 if(i>=self->size)
-(objcT13=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT13,selTransTbl[9]))(objcT13,selTransTbl[9],"Bounds error."));
-# 104 "runarray.m"
+{
+id objcT13;
+
+# 103 "runarray.m"
+(objcT13=OutOfBounds,(*_imp(objcT13,selTransTbl[9]))(objcT13,selTransTbl[9]));
+return(id)0;
+}
+# 109 "runarray.m"
 if(self->laststart!= -1)
 {
 id objcT14;
 
-# 106 "runarray.m"
+# 111 "runarray.m"
 if(self->laststart<=i&&i<self->lastend)
 return(objcT14=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT14,selTransTbl[1]))(objcT14,selTransTbl[1],self->lastsegment));
 if(i==self->lastend)
 {
 id objcT15,objcT16;
 self->
-# 110 "runarray.m"
+# 115 "runarray.m"
 lastsegment++;self->
 laststart=self->lastend;self->
 lastend=self->laststart+(objcT15=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT15,selTransTbl[2]))(objcT15,selTransTbl[2],self->lastsegment));
 return(objcT16=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT16,selTransTbl[1]))(objcT16,selTransTbl[1],self->lastsegment));
 }
 }
-# 119 "runarray.m"
+# 124 "runarray.m"
 for(j=0,p=0,n=(objcT17=self->values,(*(unsigned(*)(id,SEL))_imp(objcT17,selTransTbl[0]))(objcT17,selTransTbl[0]));j<n;j++)
 {
 id objcT18;
 
-# 121 "runarray.m"
+# 126 "runarray.m"
 unsigned q=p+(objcT18=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT18,selTransTbl[2]))(objcT18,selTransTbl[2],j));
 if(p<=i&&i<q)
 {
 id objcT19;
 self->
-# 124 "runarray.m"
+# 129 "runarray.m"
 laststart=p;self->
 lastend=q;self->
 lastsegment=j;
@@ -279,20 +292,27 @@ return(objcT19=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT19,selTransTbl[1
 p=q;
 }
 
-return(objcT20=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT20,selTransTbl[9]))(objcT20,selTransTbl[9],"No segment found."));
+(objcT20=NotFound,(*_imp(objcT20,selTransTbl[9]))(objcT20,selTransTbl[9]));
+return(id)0;
 }
 
 static unsigned i_RunArray_runLengthAt_(struct RunArray_PRIVATE *self,SEL _cmd,unsigned i)
 {
-id objcT21,objcT23,objcT25;
+id objcT23,objcT25;
 
-# 137 "runarray.m"
+# 143 "runarray.m"
 int j,n;
 unsigned p;
 
 if(i>=self->size)
-(objcT21=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT21,selTransTbl[9]))(objcT21,selTransTbl[9],"Bounds error."));
-# 145 "runarray.m"
+{
+id objcT21;
+
+# 148 "runarray.m"
+(objcT21=OutOfBounds,(*_imp(objcT21,selTransTbl[9]))(objcT21,selTransTbl[9]));
+return 0;
+}
+# 154 "runarray.m"
 if(self->laststart!= -1)
 {
 if(self->laststart<=i&&i<self->lastend)
@@ -301,19 +321,19 @@ if(i==self->lastend)
 {
 id objcT22;
 self->
-# 151 "runarray.m"
+# 160 "runarray.m"
 lastsegment++;self->
 laststart=self->lastend;self->
 lastend=self->laststart+(objcT22=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT22,selTransTbl[2]))(objcT22,selTransTbl[2],self->lastsegment));
 return self->lastend-i;
 }
 }
-# 160 "runarray.m"
+# 169 "runarray.m"
 for(j=0,p=0,n=(objcT23=self->values,(*(unsigned(*)(id,SEL))_imp(objcT23,selTransTbl[0]))(objcT23,selTransTbl[0]));j<n;j++)
 {
 id objcT24;
 
-# 162 "runarray.m"
+# 171 "runarray.m"
 unsigned q=p+(objcT24=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT24,selTransTbl[2]))(objcT24,selTransTbl[2],j));
 if(p<=i&&i<q)
 {self->
@@ -325,7 +345,7 @@ return self->lastend-i;
 p=q;
 }
 
-(objcT25=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT25,selTransTbl[9]))(objcT25,selTransTbl[9],"No segment found."));
+(objcT25=NotFound,(*_imp(objcT25,selTransTbl[9]))(objcT25,selTransTbl[9]));
 return 0;
 }
 
@@ -339,7 +359,7 @@ static id i_RunArray_calcsize(struct RunArray_PRIVATE *self,SEL _cmd)
 {
 id objcT26;
 
-# 185 "runarray.m"
+# 194 "runarray.m"
 int i,n;
 int totalsize=0;
 
@@ -349,7 +369,7 @@ for(i=0,n=(objcT26=self->values,(*(unsigned(*)(id,SEL))_imp(objcT26,selTransTbl[
 {
 id objcT27;
 
-# 192 "runarray.m"
+# 201 "runarray.m"
 int s=(objcT27=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT27,selTransTbl[2]))(objcT27,selTransTbl[2],i));
 
 totalsize+=s;
@@ -369,7 +389,7 @@ if(self->size<newsize)
 id objcT28,objcT29,objcT30,objcT31,objcT32;
 id objcT33;
 
-# 208 "runarray.m"
+# 217 "runarray.m"
 int n=(objcT28=self->values,(*(unsigned(*)(id,SEL))_imp(objcT28,selTransTbl[0]))(objcT28,selTransTbl[0]));
 int m=(objcT29=self->runs,(*(unsigned(*)(id,SEL))_imp(objcT29,selTransTbl[10]))(objcT29,selTransTbl[10]));
 if(m<(n+1))
@@ -382,7 +402,7 @@ else
 {
 id objcT34;
 
-# 218 "runarray.m"
+# 227 "runarray.m"
 (objcT34=(id)self,(*(id(*)(id,SEL,SEL))_imp(objcT34,selTransTbl[14]))(objcT34,selTransTbl[14],_cmd));
 }
 
@@ -394,7 +414,7 @@ static id i_RunArray_addAttribute_to_(struct RunArray_PRIVATE *self,SEL _cmd,id
 {
 id objcT35,objcT36,objcT41;
 
-# 227 "runarray.m"
+# 236 "runarray.m"
 int n=(objcT35=v,(*(unsigned(*)(id,SEL))_imp(objcT35,selTransTbl[0]))(objcT35,selTransTbl[0]));
 
 (objcT36=attrib,(*_imp(objcT36,selTransTbl[8]))(objcT36,selTransTbl[8]));
@@ -402,12 +422,12 @@ while(n--)
 {
 id objcT37,objcT38;
 
-# 232 "runarray.m"
+# 241 "runarray.m"
 if((objcT37=attrib,(*(BOOL(*)(id,SEL,id))_imp(objcT37,selTransTbl[15]))(objcT37,selTransTbl[15],(objcT38=v,(*(id(*)(id,SEL,unsigned))_imp(objcT38,selTransTbl[1]))(objcT38,selTransTbl[1],n)))))
 {
 id objcT39,objcT40;
 
-# 234 "runarray.m"
+# 243 "runarray.m"
 id atb=(objcT39=v,(*(id(*)(id,SEL,unsigned))_imp(objcT39,selTransTbl[16]))(objcT39,selTransTbl[16],n));
 
 (objcT40=atb,(*_imp(objcT40,selTransTbl[7]))(objcT40,selTransTbl[7]));
@@ -418,7 +438,7 @@ if((objcT41=attrib,(*(BOOL(*)(id,SEL))_imp(objcT41,selTransTbl[17]))(objcT41,sel
 {
 id objcT42;
 
-# 242 "runarray.m"
+# 251 "runarray.m"
 (objcT42=v,(*_imp(objcT42,selTransTbl[12]))(objcT42,selTransTbl[12],attrib));
 
 }
@@ -426,7 +446,7 @@ else
 {
 id objcT43;
 
-# 247 "runarray.m"
+# 256 "runarray.m"
 (objcT43=attrib,(*_imp(objcT43,selTransTbl[7]))(objcT43,selTransTbl[7]));
 
 }
@@ -437,14 +457,14 @@ static id i_RunArray_breakat_(struct RunArray_PRIVATE *self,SEL _cmd,int i)
 {
 id objcT44,objcT55;
 
-# 255 "runarray.m"
+# 264 "runarray.m"
 int j,k,p,n;
 
 for(j=0,p=0,n=(objcT44=self->values,(*(unsigned(*)(id,SEL))_imp(objcT44,selTransTbl[0]))(objcT44,selTransTbl[0]));j<n;j++)
 {
 id objcT45;
 
-# 259 "runarray.m"
+# 268 "runarray.m"
 unsigned q=p+(objcT45=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT45,selTransTbl[2]))(objcT45,selTransTbl[2],j));
 
 if(p==i||q==i)
@@ -454,7 +474,7 @@ if(p<i&&q>i)
 id objcT46,objcT47,objcT48,objcT49,objcT50;
 id objcT51,objcT52,objcT53,objcT54;
 
-# 265 "runarray.m"
+# 274 "runarray.m"
 int m=(objcT46=self->runs,(*(unsigned(*)(id,SEL))_imp(objcT46,selTransTbl[10]))(objcT46,selTransTbl[10]));
 id v=(objcT47=(objcT48=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT48,selTransTbl[1]))(objcT48,selTransTbl[1],j)),(*_imp(objcT47,selTransTbl[18]))(objcT47,selTransTbl[18]));
 
@@ -470,71 +490,71 @@ return(id)self;
 }
 p=q;
 }
-return(objcT55=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT55,selTransTbl[9]))(objcT55,selTransTbl[9],"Error in run computation"));
+return(objcT55=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT55,selTransTbl[20]))(objcT55,selTransTbl[20],"Error in run computation"));
 }
 
 static id i_RunArray_addAttribute_from_size_(struct RunArray_PRIVATE *self,SEL _cmd,id attrib,unsigned p,unsigned s)
 {
 id objcT61,objcT62,objcT69,objcT70,objcT75;
 
-# 285 "runarray.m"
+# 294 "runarray.m"
 int i;
 
 if(s==0)
 return(id)self;
-# 292 "runarray.m"
+# 301 "runarray.m"
 if(p>=self->size)
 {
 id objcT56,objcT57,objcT58,objcT59,objcT60;
 
-# 294 "runarray.m"
+# 303 "runarray.m"
 if(p>self->size)
-(objcT56=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT56,selTransTbl[20]))(objcT56,selTransTbl[20],p));
-(objcT57=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT57,selTransTbl[20]))(objcT57,selTransTbl[20],p+s));
+(objcT56=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT56,selTransTbl[21]))(objcT56,selTransTbl[21],p));
+(objcT57=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT57,selTransTbl[21]))(objcT57,selTransTbl[21],p+s));
 i=(objcT58=self->values,(*(unsigned(*)(id,SEL))_imp(objcT58,selTransTbl[0]))(objcT58,selTransTbl[0]));
 (void)0;
-return(objcT59=(id)self,(*_imp(objcT59,selTransTbl[21]))(objcT59,selTransTbl[21],attrib,(objcT60=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT60,selTransTbl[1]))(objcT60,selTransTbl[1],i-1))));
+return(objcT59=(id)self,(*_imp(objcT59,selTransTbl[22]))(objcT59,selTransTbl[22],attrib,(objcT60=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT60,selTransTbl[1]))(objcT60,selTransTbl[1],i-1))));
 }
-# 304 "runarray.m"
+# 313 "runarray.m"
 i=(objcT61=self->values,(*(unsigned(*)(id,SEL))_imp(objcT61,selTransTbl[0]))(objcT61,selTransTbl[0]));
 if((i!=0)&&(p+s==self->size)&&(s==(objcT62=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT62,selTransTbl[2]))(objcT62,selTransTbl[2],i-1))))
 {
 id objcT63,objcT64;
 
-# 307 "runarray.m"
-return(objcT63=(id)self,(*_imp(objcT63,selTransTbl[21]))(objcT63,selTransTbl[21],attrib,(objcT64=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT64,selTransTbl[1]))(objcT64,selTransTbl[1],i-1))));
+# 316 "runarray.m"
+return(objcT63=(id)self,(*_imp(objcT63,selTransTbl[22]))(objcT63,selTransTbl[22],attrib,(objcT64=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT64,selTransTbl[1]))(objcT64,selTransTbl[1],i-1))));
 }
-# 313 "runarray.m"
+# 322 "runarray.m"
 if(p+s>self->size)
 {
 id objcT65,objcT66;
 
-# 315 "runarray.m"
-(objcT65=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT65,selTransTbl[20]))(objcT65,selTransTbl[20],p+s));
-(objcT66=(id)self,(*(id(*)(id,SEL,int))_imp(objcT66,selTransTbl[22]))(objcT66,selTransTbl[22],p));
+# 324 "runarray.m"
+(objcT65=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT65,selTransTbl[21]))(objcT65,selTransTbl[21],p+s));
+(objcT66=(id)self,(*(id(*)(id,SEL,int))_imp(objcT66,selTransTbl[23]))(objcT66,selTransTbl[23],p));
 }
 else
 {
 id objcT67,objcT68;
 
-# 320 "runarray.m"
-(objcT67=(id)self,(*(id(*)(id,SEL,int))_imp(objcT67,selTransTbl[22]))(objcT67,selTransTbl[22],p));
-(objcT68=(id)self,(*(id(*)(id,SEL,int))_imp(objcT68,selTransTbl[22]))(objcT68,selTransTbl[22],p+s));
+# 329 "runarray.m"
+(objcT67=(id)self,(*(id(*)(id,SEL,int))_imp(objcT67,selTransTbl[23]))(objcT67,selTransTbl[23],p));
+(objcT68=(id)self,(*(id(*)(id,SEL,int))_imp(objcT68,selTransTbl[23]))(objcT68,selTransTbl[23],p+s));
 }
 
 (objcT69=(id)self,(*_imp(objcT69,selTransTbl[8]))(objcT69,selTransTbl[8]));
 
-for(i=0;i<self->size;i+=(objcT70=(id)self,(*(unsigned(*)(id,SEL,unsigned))_imp(objcT70,selTransTbl[23]))(objcT70,selTransTbl[23],i)))
+for(i=0;i<self->size;i+=(objcT70=(id)self,(*(unsigned(*)(id,SEL,unsigned))_imp(objcT70,selTransTbl[24]))(objcT70,selTransTbl[24],i)))
 {
 id objcT71,objcT72,objcT73,objcT74;
 
-# 328 "runarray.m"
+# 337 "runarray.m"
 if(i==p+s)
 break;
 if(i>p+s)
-(objcT71=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT71,selTransTbl[9]))(objcT71,selTransTbl[9],"Error in run computation."));
+(objcT71=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT71,selTransTbl[20]))(objcT71,selTransTbl[20],"Error in run computation."));
 if(i>=p)
-(objcT72=(id)self,(*_imp(objcT72,selTransTbl[21]))(objcT72,selTransTbl[21],(objcT73=attrib,(*_imp(objcT73,selTransTbl[24]))(objcT73,selTransTbl[24])),(objcT74=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT74,selTransTbl[1]))(objcT74,selTransTbl[1],i))));
+(objcT72=(id)self,(*_imp(objcT72,selTransTbl[22]))(objcT72,selTransTbl[22],(objcT73=attrib,(*_imp(objcT73,selTransTbl[25]))(objcT73,selTransTbl[25])),(objcT74=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT74,selTransTbl[1]))(objcT74,selTransTbl[1],i))));
 }
 
 
@@ -545,27 +565,33 @@ return(id)self;
 
 static id i_RunArray_calcinsertsegment_(struct RunArray_PRIVATE *self,SEL _cmd,int i)
 {
-id objcT76,objcT77,objcT79;
+id objcT77,objcT79;
 
-# 344 "runarray.m"
+# 353 "runarray.m"
 int j,n;
 unsigned p;
 
 if(i>=self->size)
-(objcT76=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT76,selTransTbl[9]))(objcT76,selTransTbl[9],"Bounds error."));
-# 352 "runarray.m"
+{
+id objcT76;
+
+# 358 "runarray.m"
+(objcT76=OutOfBounds,(*_imp(objcT76,selTransTbl[9]))(objcT76,selTransTbl[9]));
+return(id)0;
+}
+# 364 "runarray.m"
 if(self->laststart!= -1)
 {
 
 if(self->laststart<i&&i<=self->lastend)
 return(id)self;
 }
-# 361 "runarray.m"
+# 373 "runarray.m"
 for(j=0,p=0,n=(objcT77=self->values,(*(unsigned(*)(id,SEL))_imp(objcT77,selTransTbl[0]))(objcT77,selTransTbl[0]));j<n;j++)
 {
 id objcT78;
 
-# 363 "runarray.m"
+# 375 "runarray.m"
 unsigned q=p+(objcT78=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT78,selTransTbl[2]))(objcT78,selTransTbl[2],j));
 
 if(p<=i&&i<=q)
@@ -578,25 +604,26 @@ return(id)self;
 p=q;
 }
 
-return(objcT79=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT79,selTransTbl[9]))(objcT79,selTransTbl[9],"No segment found."));
+(objcT79=NotFound,(*_imp(objcT79,selTransTbl[9]))(objcT79,selTransTbl[9]));
+return(id)0;
 }
 
 static id i_RunArray_at_insert_count_(struct RunArray_PRIVATE *self,SEL _cmd,unsigned anOffset,char*aString,int n)
 {
 id objcT87;
 
-# 380 "runarray.m"
+# 393 "runarray.m"
 if(anOffset==self->size)
 {
 id objcT80;
 
-# 382 "runarray.m"
+# 395 "runarray.m"
 int s=(objcT80=self->runs,(*(unsigned(*)(id,SEL))_imp(objcT80,selTransTbl[0]))(objcT80,selTransTbl[0]));
 if(s)
 {
 id objcT81,objcT82;
 
-# 385 "runarray.m"
+# 398 "runarray.m"
 (objcT81=self->runs,(*(int(*)(id,SEL,unsigned,int))_imp(objcT81,selTransTbl[13]))(objcT81,selTransTbl[13],s-1,(objcT82=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT82,selTransTbl[2]))(objcT82,selTransTbl[2],s-1))+n));self->
 size+=n;
 }
@@ -604,16 +631,16 @@ else
 {
 id objcT83;
 
-# 390 "runarray.m"
-(objcT83=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT83,selTransTbl[20]))(objcT83,selTransTbl[20],self->size+n));
+# 403 "runarray.m"
+(objcT83=(id)self,(*(id(*)(id,SEL,unsigned))_imp(objcT83,selTransTbl[21]))(objcT83,selTransTbl[21],self->size+n));
 }
 }
 else
 {
 id objcT84,objcT85,objcT86;
 
-# 395 "runarray.m"
-(objcT84=(id)self,(*(id(*)(id,SEL,int))_imp(objcT84,selTransTbl[25]))(objcT84,selTransTbl[25],anOffset));
+# 408 "runarray.m"
+(objcT84=(id)self,(*(id(*)(id,SEL,int))_imp(objcT84,selTransTbl[26]))(objcT84,selTransTbl[26],anOffset));
 (objcT85=self->runs,(*(int(*)(id,SEL,unsigned,int))_imp(objcT85,selTransTbl[13]))(objcT85,selTransTbl[13],self->lastsegment,(objcT86=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT86,selTransTbl[2]))(objcT86,selTransTbl[2],self->lastsegment))+n));self->
 size+=n;
 }
@@ -624,13 +651,19 @@ return(id)self;
 
 static id i_RunArray_deleteFrom_to_(struct RunArray_PRIVATE *self,SEL _cmd,unsigned p,unsigned q)
 {
-id objcT88,objcT89,objcT90,objcT91,objcT111;
+id objcT89,objcT90,objcT91,objcT111;
 
-# 406 "runarray.m"
+# 419 "runarray.m"
 int i,is,j,je,n;
 
 if(p>q)
-(objcT88=(id)self,(*(id(*)(id,SEL,STR,...))_imp(objcT88,selTransTbl[9]))(objcT88,selTransTbl[9],"Bounds error"));
+{
+id objcT88;
+
+# 423 "runarray.m"
+(objcT88=OutOfBounds,(*_imp(objcT88,selTransTbl[9]))(objcT88,selTransTbl[9]));
+return(id)0;
+}
 
 (void)0;
 
@@ -647,7 +680,7 @@ if(i==j)
 {
 id objcT92,objcT93;
 
-# 424 "runarray.m"
+# 440 "runarray.m"
 int m=(objcT92=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT92,selTransTbl[2]))(objcT92,selTransTbl[2],i));
 
 (void)0;
@@ -656,7 +689,7 @@ if(m==n)
 {
 id objcT94,objcT95,objcT96;
 
-# 430 "runarray.m"
+# 446 "runarray.m"
 id atb=(objcT94=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT94,selTransTbl[16]))(objcT94,selTransTbl[16],i));
 
 (objcT95=(objcT96=atb,(*_imp(objcT96,selTransTbl[6]))(objcT96,selTransTbl[6])),(*_imp(objcT95,selTransTbl[7]))(objcT95,selTransTbl[7]));
@@ -667,7 +700,7 @@ else
 {
 id objcT97,objcT98,objcT99,objcT100,objcT101;
 
-# 438 "runarray.m"
+# 454 "runarray.m"
 int m,k,r;
 
 m=(objcT97=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT97,selTransTbl[2]))(objcT97,selTransTbl[2],i));
@@ -684,7 +717,7 @@ if(is==p)
 {
 id objcT102,objcT103,objcT104;
 
-# 452 "runarray.m"
+# 468 "runarray.m"
 id atb=(objcT102=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT102,selTransTbl[16]))(objcT102,selTransTbl[16],r));
 
 (objcT103=(objcT104=atb,(*_imp(objcT104,selTransTbl[6]))(objcT104,selTransTbl[6])),(*_imp(objcT103,selTransTbl[7]))(objcT103,selTransTbl[7]));
@@ -698,7 +731,7 @@ for(k=i+1;k<j;k++)
 {
 id objcT105,objcT106,objcT107;
 
-# 463 "runarray.m"
+# 479 "runarray.m"
 id atb=(objcT105=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT105,selTransTbl[16]))(objcT105,selTransTbl[16],r));
 
 (objcT106=(objcT107=atb,(*_imp(objcT107,selTransTbl[6]))(objcT107,selTransTbl[6])),(*_imp(objcT106,selTransTbl[7]))(objcT106,selTransTbl[7]));
@@ -708,7 +741,7 @@ if(je==q+1)
 {
 id objcT108,objcT109,objcT110;
 
-# 470 "runarray.m"
+# 486 "runarray.m"
 id atb=(objcT108=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT108,selTransTbl[16]))(objcT108,selTransTbl[16],r));
 
 (objcT109=(objcT110=atb,(*_imp(objcT110,selTransTbl[6]))(objcT110,selTransTbl[6])),(*_imp(objcT109,selTransTbl[7]))(objcT109,selTransTbl[7]));
@@ -717,7 +750,7 @@ id atb=(objcT108=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT108,selTransTb
 }self->
 
 size-=n;
-(objcT111=self->runs,(*_imp(objcT111,selTransTbl[26]))(objcT111,selTransTbl[26]));
+(objcT111=self->runs,(*_imp(objcT111,selTransTbl[27]))(objcT111,selTransTbl[27]));
 
 (void)0;
 return(id)self;
@@ -729,17 +762,17 @@ id objcT112,objcT113,objcT114,objcT115,objcT116;
 id objcT117,objcT118,objcT119,objcT120,objcT121;
 id objcT122,objcT123,objcT124;
 
-# 486 "runarray.m"
+# 502 "runarray.m"
 int i,m,n,k;
-id v,r=(objcT112=b,(*_imp(objcT112,selTransTbl[27]))(objcT112,selTransTbl[27]));
+id v,r=(objcT112=b,(*_imp(objcT112,selTransTbl[28]))(objcT112,selTransTbl[28]));
 
 k=(objcT113=self->values,(*(unsigned(*)(id,SEL))_imp(objcT113,selTransTbl[0]))(objcT113,selTransTbl[0]));
-n=(objcT114=(objcT115=b,(*_imp(objcT115,selTransTbl[28]))(objcT115,selTransTbl[28])),(*(unsigned(*)(id,SEL))_imp(objcT114,selTransTbl[0]))(objcT114,selTransTbl[0]));
+n=(objcT114=(objcT115=b,(*_imp(objcT115,selTransTbl[29]))(objcT115,selTransTbl[29])),(*(unsigned(*)(id,SEL))_imp(objcT114,selTransTbl[0]))(objcT114,selTransTbl[0]));
 for(i=0;i<n;i++)
 (objcT116=self->runs,(*(int(*)(id,SEL,unsigned,int))_imp(objcT116,selTransTbl[13]))(objcT116,selTransTbl[13],k+i,(objcT117=r,(*(int(*)(id,SEL,unsigned))_imp(objcT117,selTransTbl[2]))(objcT117,selTransTbl[2],i))));
 
-v=(objcT118=(objcT119=b,(*_imp(objcT119,selTransTbl[28]))(objcT119,selTransTbl[28])),(*_imp(objcT118,selTransTbl[18]))(objcT118,selTransTbl[18]));
-(objcT120=self->values,(*_imp(objcT120,selTransTbl[29]))(objcT120,selTransTbl[29],v));
+v=(objcT118=(objcT119=b,(*_imp(objcT119,selTransTbl[29]))(objcT119,selTransTbl[29])),(*_imp(objcT118,selTransTbl[18]))(objcT118,selTransTbl[18]));
+(objcT120=self->values,(*_imp(objcT120,selTransTbl[30]))(objcT120,selTransTbl[30],v));
 
 (objcT121=v,(*_imp(objcT121,selTransTbl[7]))(objcT121,selTransTbl[7]));
 
@@ -756,25 +789,25 @@ static id i_RunArray_coalesce(struct RunArray_PRIVATE *self,SEL _cmd)
 {
 id objcT125;
 
-# 510 "runarray.m"
+# 526 "runarray.m"
 int n=(objcT125=self->values,(*(unsigned(*)(id,SEL))_imp(objcT125,selTransTbl[0]))(objcT125,selTransTbl[0]));
 
 while(n--)
 {
 id objcT126,objcT127,objcT128;
 
-# 514 "runarray.m"
+# 530 "runarray.m"
 id v,w;
 if(n==0)
 break;
 v=(objcT126=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT126,selTransTbl[1]))(objcT126,selTransTbl[1],n));
 w=(objcT127=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT127,selTransTbl[1]))(objcT127,selTransTbl[1],n-1));
-if((objcT128=v,(*(BOOL(*)(id,SEL,id))_imp(objcT128,selTransTbl[30]))(objcT128,selTransTbl[30],w)))
+if((objcT128=v,(*(BOOL(*)(id,SEL,id))_imp(objcT128,selTransTbl[31]))(objcT128,selTransTbl[31],w)))
 {
 id objcT129,objcT130,objcT131,objcT132,objcT133;
 id objcT134,objcT135,objcT136;
 
-# 521 "runarray.m"
+# 537 "runarray.m"
 id atb;
 unsigned p=(objcT129=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT129,selTransTbl[2]))(objcT129,selTransTbl[2],n));
 unsigned q=(objcT130=self->runs,(*(int(*)(id,SEL,unsigned))_imp(objcT130,selTransTbl[2]))(objcT130,selTransTbl[2],n-1));
@@ -784,7 +817,7 @@ atb=(objcT133=self->values,(*(id(*)(id,SEL,unsigned))_imp(objcT133,selTransTbl[1
 
 (objcT134=(objcT135=atb,(*_imp(objcT135,selTransTbl[6]))(objcT135,selTransTbl[6])),(*_imp(objcT134,selTransTbl[7]))(objcT134,selTransTbl[7]));
 
-(objcT136=self->runs,(*_imp(objcT136,selTransTbl[26]))(objcT136,selTransTbl[26]));
+(objcT136=self->runs,(*_imp(objcT136,selTransTbl[27]))(objcT136,selTransTbl[27]));
 }
 }
 
@@ -796,10 +829,10 @@ static id i_RunArray_printOn_(struct RunArray_PRIVATE *self,SEL _cmd,IOD aFile)
 {
 id objcT137,objcT138;
 
-# 540 "runarray.m"
+# 556 "runarray.m"
 fprintf(aFile,"RunArray runs ");
-(objcT137=self->runs,(*(id(*)(id,SEL,IOD))_imp(objcT137,selTransTbl[31]))(objcT137,selTransTbl[31],aFile));
-(objcT138=self->values,(*(id(*)(id,SEL,IOD))_imp(objcT138,selTransTbl[31]))(objcT138,selTransTbl[31],aFile));
+(objcT137=self->runs,(*(id(*)(id,SEL,IOD))_imp(objcT137,selTransTbl[32]))(objcT137,selTransTbl[32],aFile));
+(objcT138=self->values,(*(id(*)(id,SEL,IOD))_imp(objcT138,selTransTbl[32]))(objcT138,selTransTbl[32],aFile));
 return(id)self;
 }
 extern id  Object;
@@ -879,7 +912,7 @@ static char *_selTransTbl[] ={
 "freeContents",
 "free",
 "reset",
-"error:",
+"signal",
 "capacity",
 "capacity:",
 "add:",
@@ -890,6 +923,7 @@ static char *_selTransTbl[] ={
 "set",
 "deepCopy",
 "at:insert:",
+"error:",
 "setsize:",
 "addAttribute:to:",
 "breakat:",
@@ -906,12 +940,12 @@ static char *_selTransTbl[] ={
 };
 struct modDescriptor runarray_modDesc = {
   "runarray",
-  "objc3.1.32",
+  "objc3.2.8",
   0L,
   0,
   0,
   &RunArray,
-  32,
+  33,
   _selTransTbl,
   0
 };
